//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Web;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Drawing.Imaging;
using System.IO;
using XShan.DotShoppingCart.Common;
using XShan.DotShoppingCart.Common.Object;
using XShan.DotShoppingCart.Common.Configuration;

namespace XShan.DotShoppingCart.HttpHandlers {
    public class DyImageHttpHandler : IHttpHandler {
        public void ProcessRequest(HttpContext ctx) {
            int cornerSize = Utils.GetIntParameter("cornersize", 20);
            string type = Utils.GetParameter("type", "button");
            string gtype = Utils.GetParameter("gtype", null);
            string text = Utils.GetParameter("text", null);
            string color = Utils.GetParameter("color", null);
            string subtype = Utils.GetParameter("subtype", null);
            string textcolor = Utils.GetParameter("textcolor", null);
            string backcolor = Utils.GetParameter("backcolor", null);
            string bordercolor = Utils.GetParameter("bordercolor", null);
            string bkgroundcolor = Utils.GetParameter("bkgroundcolor", null);
            string applyBorder = Utils.GetParameter("border", null); ;

            int height = Utils.GetIntParameter("height", 20);
            if (height <= 0)
                height = 20;
            int width = Utils.GetIntParameter("width", 100);
            if (width <= 0)
                width = 100;


            bool gradient = true;
            bool.TryParse(Utils.GetParameter("gradient", "True"), out gradient);

            float fontSize = 10f;
            float.TryParse(Utils.GetParameter("fontSize", "10"), out fontSize);

            string fontFamily = Utils.GetParameter("fontFamily", "Arial");

            FontStyle fontStyle = (FontStyle)Enum.Parse(typeof(FontStyle), Utils.GetParameter("fontStyle", "Bold"), true);

            string fileSpec = string.Format(@"{0}\{1}_{2}_{3}_{4}_{5}_{6}_{7}_{8}_{9}_{10}_{11}_{12}_{13}_{14}_{15}_{16}_{17}.jpg", 
                WebUtils.GetImagePath(), type, subtype, gtype, width, height, text, color, textcolor, bordercolor, backcolor,
                bkgroundcolor, gradient, cornerSize, fontFamily, fontSize, (int)fontStyle, applyBorder);
            if (!File.Exists(fileSpec)) {
                UIConfigurationSection uiSection = UIConfigurationSection.GetSection();
                DynamicImage.Settings settings = new DynamicImage.Settings();
                settings.CornerSize = cornerSize;
                settings.Width = width;
                settings.Height = height;
                settings.BackGroundColor = ColorTranslator.FromHtml(uiSection.Colors.Get("Background Color").Value);
                settings.Text = text;
                settings.TextFont = new Font(fontFamily, fontSize, fontStyle, GraphicsUnit.Point);
                settings.ApplyInternalFill = true;
                settings.ApplyGradient = gradient;
                if (settings.ApplyGradient && (!string.IsNullOrEmpty(gtype))) {
                    settings.GType = (DynamicImage.GradientType)Enum.Parse(typeof(DynamicImage.GradientType), gtype);
                }

                switch (type) {
                    case "button":
                        settings.CornerPositionMap = (int)(DynamicImage.CornerPosition.TopRight | DynamicImage.CornerPosition.TopLeft |
                            DynamicImage.CornerPosition.BottomLeft | DynamicImage.CornerPosition.BottomRight);
                        // if color is defined, use that instead of accent bk color
                        settings.StartColor = ColorTranslator.FromHtml(string.IsNullOrEmpty(color) ? uiSection.Colors.Get("Accent Background Gradient Start Color").Value : color);
                        settings.BackColor = ColorTranslator.FromHtml(string.IsNullOrEmpty(backcolor) ? uiSection.Colors.Get("Accent Background Color").Value : backcolor);
                        settings.TextColor = ColorTranslator.FromHtml(string.IsNullOrEmpty(textcolor) ? uiSection.Colors.Get("Accent Fore Color").Value : textcolor);
                        settings.BorderColor = ColorTranslator.FromHtml(string.IsNullOrEmpty(bordercolor) ? uiSection.Colors.Get("Border Color").Value : bordercolor);
                        if (!string.IsNullOrEmpty(bkgroundcolor))
                            settings.BackGroundColor = ColorTranslator.FromHtml(bkgroundcolor);
                        settings.ApplyBorder = string.IsNullOrEmpty(applyBorder) ? true : bool.Parse(applyBorder);
                        if (string.IsNullOrEmpty(gtype))
                            settings.GType = DynamicImage.GradientType.Button;
                        break;
                    case "bar":
                        settings.StartColor = ColorTranslator.FromHtml(string.IsNullOrEmpty(backcolor) ? uiSection.Colors.Get("Accent Highlight Background Color").Value : backcolor);
                        settings.BackColor = ColorTranslator.FromHtml(string.IsNullOrEmpty(color) ? uiSection.Colors.Get("Accent Highlight Background Gradient Start").Value : color);
                        settings.TextColor = ColorTranslator.FromHtml(string.IsNullOrEmpty(textcolor) ? uiSection.Colors.Get("Accent Highlight Fore Color").Value : textcolor);
                        settings.ApplyBorder = string.IsNullOrEmpty(applyBorder) ? false : bool.Parse(applyBorder);
                        if (string.IsNullOrEmpty(gtype))
                            settings.GType = DynamicImage.GradientType.Linear;
                        break;
                    case "reverseBoxHeader":
                    case "boxHeader":
                        bool reverse = type == "reverseBoxHeader";
                        settings.CornerPositionMap = reverse ? (int)(DynamicImage.CornerPosition.BottomRight | DynamicImage.CornerPosition.BottomLeft) : 
                            (int)(DynamicImage.CornerPosition.TopRight | DynamicImage.CornerPosition.TopLeft);

                        if (subtype == "highlight") {
                            settings.StartColor = ColorTranslator.FromHtml(string.IsNullOrEmpty(color) ? uiSection.Colors.Get("Accent Highlight Background Gradient Start").Value : color);
                            settings.BackColor = ColorTranslator.FromHtml(string.IsNullOrEmpty(backcolor) ? uiSection.Colors.Get("Accent Highlight Background Color").Value : backcolor);
                            settings.TextColor = ColorTranslator.FromHtml(string.IsNullOrEmpty(textcolor) ? uiSection.Colors.Get("Accent Highlight Fore Color").Value : textcolor);
                        } else {
                            settings.StartColor = ColorTranslator.FromHtml(string.IsNullOrEmpty(color) ? uiSection.Colors.Get("Accent Background Gradient Start Color").Value: color);
                            settings.BackColor = ColorTranslator.FromHtml(string.IsNullOrEmpty(backcolor) ? uiSection.Colors.Get("Accent Background Color").Value : backcolor);
                            settings.TextColor = ColorTranslator.FromHtml(string.IsNullOrEmpty(textcolor) ? uiSection.Colors.Get("Accent Fore Color").Value : textcolor);
                        }
                        if (reverse) {
                            Color temp = settings.StartColor;
                            settings.StartColor = settings.BackColor;
                            settings.BackColor = temp;
                        }
                        settings.BorderColor = ColorTranslator.FromHtml(string.IsNullOrEmpty(bordercolor) ? uiSection.Colors.Get("Accent Highlight Background Color").Value : bordercolor);
                        settings.ApplyBorder = string.IsNullOrEmpty(applyBorder) ? true : bool.Parse(applyBorder);
                        if (string.IsNullOrEmpty(gtype))
                            settings.GType = DynamicImage.GradientType.Linear;
                        break;
                }

                Bitmap bm = DynamicImage.GetRoundedRectangle(settings);
                //set some encoder parameters to give us the best quality image possible
                ImageCodecInfo[] Info = ImageCodecInfo.GetImageEncoders();
                EncoderParameters Params = new EncoderParameters(1);
                Params.Param[0] = new EncoderParameter(Encoder.Quality, 100L);
                bm.Save(fileSpec, Info[1], Params);
            }
            ctx.Response.ContentType = "image/jpeg";
            WebUtils.SetCacheable(ctx.Response.Cache);
            ctx.Response.TransmitFile(fileSpec);
        }

        public bool IsReusable {
            get { return false; }
        }
    }
}
