//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Collections.Generic;
using System.Collections.Specialized;
using XShan.DotShoppingCart.Common.Object;
using XShan.DotShoppingCart.Common;
using XShan.DotShoppingCart.Payment;

namespace XShan.DotShoppingCart.OrderPipeline {
    public class CreditCardProcessorProvider : OrderProcessorProvider {
        private string action;

        #region Provider Specific Behaviors
        public override void Initialize(string name, NameValueCollection config) {
            base.Initialize(name, config);

            action = config["action"];
        }
        #endregion

        protected override void ProcessOrder(string host, Order order) {
            CreditCardPaymentProvider provider = CreditCardPaymentService.GetProvider(host);
            PaymentTransaction transaction = null;
            switch(action) {
                case "Authorization" :
                    transaction = provider.Authorize(order);
                    break;
                case "Capture" :
                    if (order.OrderTotalAmount > 0)
                        transaction = provider.Capture(order);
                    else
                        SkipCapture(host, order);
                    break;
                case "Sale" :
                    if (order.OrderTotalAmount > 0)
                        transaction = provider.Sale(order);
                    else
                        SkipCapture(host, order);
                    break;
                default:
                    throw new OrderProcessorExecption(string.Format("Credit card processor configuration issue. Action ({0}) is not recognized", action));
            }
            if (null != transaction) {
                transaction.Add(host, order.OrderNumber);
                if (!transaction.Success)
                    throw new PaymentExecption("Payment transaction failed");
            }
        }

        private void SkipCapture(string host, Order order) {
            Order.AddNote(host, order.OrderId,
                string.Format("Total order amount is {0:C}. Skip capturing.", order.OrderTotalAmount));
        }
    }
}
