//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Collections.Generic;
using System.Threading;
using System.Configuration;
using System.Web.Configuration;

using XShan.DotShoppingCart.Common.Configuration;

namespace XShan.DotShoppingCart.OrderPipeline {
    public static class OrderPipelineController {
        private static Dictionary<RunnableProvider, Thread> providers = new Dictionary<RunnableProvider, Thread>();

        public static void Start() {
            OrderPipelineServiceConfigurationSection orderPipelineSection = (OrderPipelineServiceConfigurationSection)ConfigurationController.GetSection(OrderPipelineServiceConfigurationSection.SectionName);
            Start(orderPipelineSection.Providers);

            TaskConfigurationSection taskSection = (TaskConfigurationSection)ConfigurationController.GetSection(TaskConfigurationSection.SectionName);
            Start(taskSection.Providers);
        }

        public static void Stop() {
            foreach (RunnableProvider p in providers.Keys) {
                p.Stop = true;
            }
            foreach (Thread t in providers.Values) {
                t.Join();
            }
        }

        private static void Start(ProviderSettingsCollection psc) {
            foreach (ProviderSettings ps in psc) {
                RunnableProvider p = (RunnableProvider)ProvidersHelper.InstantiateProvider(ps, typeof(RunnableProvider));
                Thread thread = new Thread(p.StartRun);
                providers.Add(p, thread);
                thread.Start();
            }
        }
    }
}
