//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Collections.Generic;
using Microsoft.Practices.EnterpriseLibrary.ExceptionHandling;
using XShan.DotShoppingCart.Common.Object;
using XShan.DotShoppingCart.Common;
using XShan.DotShoppingCart.Common.Configuration;
using System.Collections.Specialized;

namespace XShan.DotShoppingCart.OrderPipeline {
    public abstract class OrderProcessorProvider : ProcessorProvider {
        protected override int Proccess(string host) {
            try {
                int orderProccessed = 0;
                foreach (OrderPipelineProcessor processor in OrderPipelineProcessor.GetAllConfiguredProcessors(host)) {
                    if (0 == string.Compare(this.Name, processor.Name, true)) {
                        orderProccessed += ProcessOrders(host, processor.OrderStatusIdSource);
                        break;
                    }
                }
                return orderProccessed;
            } catch (Exception e) {
                e.Data.Add("host", host);
                throw;
            }
        }

        /// <summary>
        /// Process orders for this site
        /// </summary>
        /// <param name="host"></param>
        /// <returns>the number of orders that were processed</returns>
        private int ProcessOrders(string host, int orderStatusIdSource) {
            int processed = 0;
            foreach (Order order in Order.GetByStatus(host, orderStatusIdSource)) {
                try {
                    ProcessOrder(host, order);
                    order.SetToNextStatusInPipeline(host, string.Format("Order Processor ({0}) completed successfully.", Name));
                    processed++;
                } catch (OrderProcessorExecption) {
                    throw; //something is wrong with this order processor. Let this to be killed.
                } catch (Exception e) {
                    Order.SetStatus(host, order.OrderId, OrderStatus.OrderUnderReviewStatus, string.Format("Order Processor ({0}) failed due to {1}.", Name, e.Message));
                    if (IsPaymentProccessors()) {
                        StoreConfigurationSection storeSection = StoreConfigurationSection.GetSection();
                        NameValueCollection tokens = new NameValueCollection();
                        tokens.Add("Order.OrderNumber", order.OrderNumber);
                        EmailManager.Send(host, "PaymentFailure", tokens, storeSection.SaleEmailAddress, new string[] { storeSection.SaleEmailAddress }, null);
                    } else {
                        ExceptionPolicy.HandleException(e, "Unhandled Policy");
                    }
                }
            }
            return processed;
        }

        private bool IsPaymentProccessors() {
            return (this is CreditCardProcessorProvider) ||
                (this is PaypalExpressProcessorProvider) ||
                (this is GoogleCheckoutProcessorProvider);
        }

        protected abstract void ProcessOrder(string host, Order order);

    }
}
