//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Collections.Generic;
using System.Collections.Specialized;
using System.Configuration.Provider;
using System.Threading;
using Microsoft.Practices.EnterpriseLibrary.ExceptionHandling;

namespace XShan.DotShoppingCart.OrderPipeline {
    public abstract class RunnableProvider : ProviderBase {
        public bool Stop = false;
        private int interval = 1;

        #region Provider Specific Behaviors
        public override void Initialize(string name, NameValueCollection config) {
            base.Initialize(name, config);

            if (null != config["interval"])
                interval = int.Parse(config["interval"]);
        }
        #endregion

        public void StartRun() {
            while (!Stop) {
                try {
                    Run();
                    Thread.Sleep(new TimeSpan(0, interval, 0)); //Sleep when idle
                } catch (Exception e) {
                    bool rethrow = ExceptionPolicy.HandleException(e, "Unhandled Policy");
                    if (rethrow)
                        throw;
                }
            }
        }

        protected abstract void Run();
    }
}
