//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Collections.Generic;
using System.Collections.Specialized;
using XShan.DotShoppingCart.Common.Object;

namespace XShan.DotShoppingCart.OrderPipeline {
    public abstract class TaskProvider : ProcessorProvider {
        private int taskRunInterval = 120; //minutes
        private double? startat = null; //start time: minutes from 12am in the morning. E.g. 160 is 2:40am.

        #region Provider Specific Behaviors
        public override void Initialize(string name, NameValueCollection config) {
            base.Initialize(name, config);

            if (null != config["taskRunInterval"])
                taskRunInterval = int.Parse(config["taskRunInterval"]);

            if (null != config["startat"])
                startat = double.Parse(config["startat"]);
        }
        #endregion

        protected override int Proccess(string host) {
            try {
                DateTime? startAtTime = null;
                if (null != startat) {
                    startAtTime = DateTime.Today.AddMinutes((double)startat);
                }

                if (Task.IsScheduledToRun(host, this.Name, taskRunInterval, startAtTime))
                    RunTask(host);
                return 1;
            } catch (Exception e) {
                e.Data.Add("host", host);
                throw;
            }
        }

        protected abstract void RunTask(string host);
    }
}
