//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Collections.Generic;
using System.Configuration;
using System.Web.Configuration;

using XShan.DotShoppingCart.Common;
using XShan.DotShoppingCart.Common.Object;
using XShan.DotShoppingCart.Common.Configuration;

namespace XShan.DotShoppingCart.Shipping {
    public static class ShippingService {
        public static List<ShippingMethod> GetShippingMethods(ShippingPackage package) {
            List<ShippingMethod> methods = new List<ShippingMethod>();
            if (package.IsDownloadable) {
                methods.Add(new ShippingMethod(Constant.Shipping.DownloadMethodName, 0));
                return methods;
            }

            SortedList<int, ShippingProvider> providers = GetProviders();
            if (null == providers)
                return null;
            
            foreach (ShippingProvider provider in providers.Values) {
                methods.AddRange(provider.GetShippingMethods(package));
            }
            return methods;
        }

        public static List<ShippingMethod> GetAllShippingMethods(Cart cart) {
            List<ShippingMethod> methods = new List<ShippingMethod>();
            if (cart.IsDownloadable) {
                methods.Add(new ShippingMethod(Constant.Shipping.DownloadMethodName, 0));
                return methods;
            }

            SortedList<int, ShippingProvider> providers = GetProviders();
            if (null == providers)
                return null;

            foreach (ShippingProvider provider in providers.Values) {
                methods.AddRange(provider.GetAllShippingMethods());
            }
            return methods;
        }

        private static SortedList<int, ShippingProvider> GetProviders() {
            ShippingServiceConfigurationSection scs = (ShippingServiceConfigurationSection)SqlConfigurationController.GetSection(ShippingServiceConfigurationSection.SectionName);
            if (null == scs)
                return null;

            SortedList<int, ShippingProvider> providers = new SortedList<int, ShippingProvider>();
            foreach (ProviderSettings ps in scs.Providers) {
                if (bool.Parse(ps.Parameters["enabled"])) {
                    ShippingProvider provider = (ShippingProvider)ProvidersHelper.InstantiateProvider(ps, typeof(ShippingProvider));
                    providers.Add(int.Parse(ps.Parameters["sortOrder"]), provider);
                }
            }
            return providers;
        }
    }
}
