//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;

namespace XShan.DotShoppingCart.WebControls {

    [ToolboxData("<{0}:DSCGridView runat=\"server\"></{0}:DSCGridView>")]
    public class DSCGridView : GridView {

        [DefaultValue("10,25,50,100")]
        public string PageSizeList {
            get {
                object o = ViewState["PageSizeList"];
                if (null == o)
                    return "10,25,50,100";
                return (string)o;
            }
            set { ViewState["PageSizeList"] = value; }
        }

        [DefaultValue(false)]
        public bool ShowRowNumber {
            get {
                object o = ViewState["ShowRowNumber"];
                if (null == o)
                    return false;
                return (bool)o;
            }
            set { ViewState["ShowRowNumber"] = value; }
        }

        protected override void OnInit(EventArgs e) {
            base.OnInit(e);
            if (this.AllowPaging) {
                this.PagerTemplate = new DSCPagerTemplate(this);
                if (ShowRowNumber) {
                    TemplateField field = new TemplateField();
                    field.ItemStyle.HorizontalAlign = HorizontalAlign.Center;
                    field.ItemStyle.Width = new Unit(30);
                    field.ItemTemplate = new RowNumberTemplate();
                    this.Columns.Insert(0, field); 
                }
            }
            this.RowDataBound += new GridViewRowEventHandler(gvw_RowDataBound);
        }

        public void ddlPageSize_SelectedIndexChanged(object sender, EventArgs e) {
            DropDownList dropDown = (DropDownList)sender;
            this.PageSize = int.Parse(dropDown.SelectedValue);
            this.PageIndex = 0;
        }

        public void txtGoToPage_TextChanged(object sender, EventArgs e) {
            TextBox txtGoToPage = (TextBox)sender;

            int pageNumber;
            if (int.TryParse(txtGoToPage.Text.Trim(), out pageNumber) && pageNumber > 0 && pageNumber <= this.PageCount) {
                this.PageIndex = pageNumber - 1;
            } else {
                this.PageIndex = 0;
            }
        }

        protected void gvw_RowDataBound(object sender, GridViewRowEventArgs e) {
            GridView gridView = (GridView)sender;

            if (!string.IsNullOrEmpty(gridView.SortExpression)) {
                int cellIndex = -1;
                foreach (DataControlField field in gridView.Columns) {
                    if (field.SortExpression == gridView.SortExpression) {
                        cellIndex = gridView.Columns.IndexOf(field);
                        break;
                    }
                }

                if (cellIndex > -1) {
                    if (e.Row.RowType == DataControlRowType.Header) {
                        //  this is a header row, set the sort style
                        e.Row.Cells[cellIndex].CssClass = gridView.SortDirection == SortDirection.Ascending ? "sortascheaderstyle" : "sortdescheaderstyle";
                    } else if (e.Row.RowType == DataControlRowType.DataRow) {
                        //  this is an alternating row
                        e.Row.Cells[cellIndex].CssClass = e.Row.RowIndex % 2 == 0 ? "sortalternatingrowstyle" : "sortrowstyle";
                    }
                }
            }

            if (e.Row.RowType == DataControlRowType.Pager) {
                Label lblTotalNumberOfPages = (Label)e.Row.FindControl("lblTotalNumberOfPages");
                lblTotalNumberOfPages.Text = gridView.PageCount.ToString();

                TextBox txtGoToPage = (TextBox)e.Row.FindControl("txtGoToPage");
                txtGoToPage.Text = (gridView.PageIndex + 1).ToString();

                DropDownList ddlPageSize = (DropDownList)e.Row.FindControl("ddlPageSize");
                ddlPageSize.SelectedValue = gridView.PageSize.ToString();
            }
        }

        public class RowNumberTemplate : ITemplate {
            public void InstantiateIn(Control container) {
                Label l = new Label();
                l.DataBinding += new EventHandler(BindRowNumber);
                container.Controls.Add(l);
            }

            private void BindRowNumber(object sender, EventArgs e) {
                Label rowNumber = (Label)sender;
                GridViewRow container = (GridViewRow)rowNumber.NamingContainer;
                object data = DataBinder.Eval(container, "DataItemIndex");
                GridView gv = (GridView)container.NamingContainer;
                rowNumber.Text = string.Format("{0}.", gv.PageSize * gv.PageIndex + Convert.ToInt32(data) + 1);
            }
        }

        public class DSCPagerTemplate : ITemplate {
            private DSCGridView gv;

            public DSCPagerTemplate(DSCGridView gv) {
                this.gv = gv;
            }

            public void InstantiateIn(Control container) {
                Literal l = new Literal();
                l.Text = "Show rows:";
                container.Controls.Add(l);

                DropDownList ddlPageSize = new DropDownList();
                ddlPageSize.ID = "ddlPageSize";
                ddlPageSize.AutoPostBack = true;
                foreach (string value in gv.PageSizeList.Split(',')) {
                    ddlPageSize.Items.Add(value);
                }
                ddlPageSize.SelectedIndexChanged += new EventHandler(gv.ddlPageSize_SelectedIndexChanged);
                container.Controls.Add(ddlPageSize);

                l = new Literal();
                l.Text = "&nbsp;Page";
                container.Controls.Add(l);

                TextBox txtGoToPage = new TextBox();
                txtGoToPage.ID = "txtGoToPage";
                txtGoToPage.AutoPostBack = true;
                txtGoToPage.CssClass = "gotopage";
                txtGoToPage.TextChanged += new EventHandler(gv.txtGoToPage_TextChanged);
                container.Controls.Add(txtGoToPage);

                l = new Literal();
                l.Text = "of";
                container.Controls.Add(l);

                Label lblTotalNumberOfPages = new Label();
                lblTotalNumberOfPages.ID = "lblTotalNumberOfPages";
                container.Controls.Add(lblTotalNumberOfPages);

                Button b = new Button();
                b.CommandName = "Page";
                b.ToolTip = "Previous Page";
                b.CommandArgument = "Prev";
                b.CssClass = "previous";
                container.Controls.Add(b);

                b = new Button();
                b.CommandName = "Page";
                b.ToolTip = "Next Page";
                b.CommandArgument = "Next";
                b.CssClass = "next";
                container.Controls.Add(b);
            }
        }
    }
}
