//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;

[assembly: System.Web.UI.WebResource("XShan.DotShoppingCart.WebControls.TabStrip.TabStrip.css", "text/css")]
[assembly: System.Web.UI.WebResource("XShan.DotShoppingCart.WebControls.TabStrip.Tab.js", "text/javascript")]
namespace XShan.DotShoppingCart.WebControls {

    [ParseChildren(false)]
    [ToolboxData("<{0}:Tab runat=\"server\"></{0}:Tab>")]
    public class Tab : Panel {

        public string TabTitle {
            get {
                object o = ViewState["TabTitle"];
                if (null == o)
                    return string.Empty;
                return (string)o;
            }
            set { ViewState["TabTitle"] = value; }
        }

        public bool Active {
            get {
                object o = ViewState["TabActive"];
                if (null == o)
                    return false;
                return (bool)o;
            }
            set { ViewState["TabActive"] = value; }
        }
    }

    public enum TabStripContentMode {
        RenderAllTabs, //default
        MultiView
    }

    [ParseChildren(true, "Tabs")]
    [ToolboxData("<{0}:TabStrip runat=\"server\"></{0}:TabStrip>")]
    public class TabStrip : CompositeControl {

        private const string JSINCLUDE_NAME = "__TabStrip__Javascript";
        private const string STYLESHEET_NAME = "__TabStrip__Stylesheet";
        private TabCollection tabs;

        public string TabActiveBackColor {
            get {
                object o = ViewState["TabActiveBackColor"];
                if (null == o)
                    return "white";
                return (string)o;
            }
            set { ViewState["TabActiveBackColor"] = value; }
        }
        
        public string TabInactiveBackColor {
            get {
                object o = ViewState["TabInactiveBackColor"];
                if (null == o)
                    return "#F2F2ED";
                return (string)o;
            }
            set { ViewState["TabInactiveBackColor"] = value; }
        }

        public string TabHoverBackColor {
            get {
                object o = ViewState["TabHoverBackColor"];
                if (null == o)
                    return "yellow";
                return (string)o;
            }
            set { ViewState["TabHoverBackColor"] = value; }
        }

        public string TabBorderColor {
            get {
                object o = ViewState["TabBorderColor"];
                if (null == o)
                    return "#879293";
                return (string)o;
            }
            set { ViewState["TabBorderColor"] = value; }
        }

        public TabStripContentMode ContentMode {
            get {
                object o = ViewState["ContentMode"];
                if (null == o)
                    return TabStripContentMode.RenderAllTabs;
                return (TabStripContentMode)o;
            }
            set { ViewState["ContentMode"] = value; }
        }

        public int ActiveTabIndex {
            get {
                if ((null != Page) && (Page.IsPostBack)) {
                    HiddenField hidActive = (HiddenField)this.FindControl("hidActive");
                    int index = 0;
                    if (int.TryParse(hidActive.Value, out index))
                        return index;
                }

                for (int i = 0; i < tabs.Count; i++) {
                    Tab tab = tabs[i];
                    if (tab.Active)
                        return i;
                }
                // no tab is set to active. Default to 0.
                if (tabs.Count > 0) {
                    tabs[0].Active = true;
                }
                return 0;
            }
        }

        [PersistenceMode(PersistenceMode.InnerDefaultProperty)]
        public TabCollection Tabs {
            get { return tabs; }
            set { tabs = value; }
        }

        protected override void OnInit(EventArgs e) {
            base.OnInit(e);
            IncludeCSSLink();
            if (!Page.ClientScript.IsClientScriptIncludeRegistered(JSINCLUDE_NAME))
                Page.ClientScript.RegisterClientScriptInclude(JSINCLUDE_NAME, Page.ClientScript.GetWebResourceUrl(this.GetType(), "XShan.DotShoppingCart.WebControls.TabStrip.Tab.js"));
        }

        protected override void CreateChildControls() {
            base.CreateChildControls();
            CreateControlHierarchy();
        }

        private void CreateControlHierarchy() {

            Table tabTable = new Table();
            tabTable.ID = "TabHeader";

            TableRow row = new TableRow();
            tabTable.Rows.Add(row);
            for (int i = 0; i < tabs.Count; i++) {
                //Add a dummy cell in between tabs
                row.Cells.Add(CreateDummyCell());

                //Add a tab cell 
                Tab tab = tabs[i];
                TableCell tabCell = new TableCell();

                if (TabStripContentMode.RenderAllTabs != ContentMode) {
                    //Create a linkbutton that triggers postback
                    LinkButton lb = new LinkButton();
                    lb.ID = string.Format("TabLink_{0}", i);
                    lb.CssClass = "NoDecorationText";
                    lb.Text = tab.TabTitle;
                    lb.Click += new EventHandler(Tab_Click);
                    tabCell.Controls.Add(lb);
                } else {
                    Label l = new Label();
                    l.Text = tab.TabTitle;
                    tabCell.Controls.Add(l);
                }
                row.Cells.Add(tabCell);
            }
            TableCell dummyCell = CreateDummyCell();
            dummyCell.Width = Unit.Percentage(100);
            row.Cells.Add(dummyCell);

            Panel p = new Panel();
            p.ID = "ContentPanel";
            if (TabStripContentMode.RenderAllTabs == ContentMode) {
                Table contentTable = new Table();
                contentTable.ID = "ContentTable";
                TableRow contentTableRow = new TableRow();
                contentTable.Rows.Add(contentTableRow);

                for (int i = 0; i < tabs.Count; i++) {
                    TableCell contentTableCell = new TableCell();
                    contentTableCell.Controls.Add(tabs[i]);
                    contentTableRow.Cells.Add(contentTableCell);
                }
                p.Controls.Add(contentTable);
            } else {
                MultiView mv = new MultiView();
                mv.ID = "TabContentMuiltView";
                for (int i = 0; i < tabs.Count; i++) {
                    View v = new View();
                    v.Controls.Add(tabs[i]);
                    mv.Controls.Add(v);
                    if (tabs[i].Active) {
                        mv.ActiveViewIndex = i;
                    }
                }
                p.Controls.Add(mv);
            }

            Controls.Add(tabTable);
            Controls.Add(p);
            
            HiddenField hidActive = new HiddenField();
            hidActive.ID = "hidActive";
            Controls.Add(hidActive);
        }

        void Tab_Click(object sender, EventArgs e)
        {
            MultiView mv = (MultiView)Controls[1].Controls[0];
            LinkButton lb = (LinkButton)sender;
            for (int i = 0; i < tabs.Count; i++) {
                Tab tab = tabs[i];
                if (lb.Text == tab.TabTitle) {
                    tab.Active = true;
                    mv.ActiveViewIndex = i;
                } else {
                    tab.Active = false;
                }
            }
        }

        private TableCell CreateDummyCell() {
            TableCell dummyCell = new TableCell();
            dummyCell.Text = "&nbsp;";
            return dummyCell;
        }

        protected override void OnPreRender(EventArgs e) {
            HiddenField hidActive = (HiddenField)FindControl("hidActive");

            string script = string.Format("TabHelper.MouseOverColor='{0}';\n TabHelper.InactiveColor='{1}';\n TabHelper.ActiveColor='{2}';\n",
                TabHoverBackColor, TabInactiveBackColor, TabActiveBackColor);

            script += "TabHelper.setActiveIndex = function(tabIndex) {\n" +
                      string.Format("var hidActive = document.getElementById('{0}');\n", hidActive.ClientID) +
                      "hidActive.value = tabIndex;\n" +
                      "}\n";
            Page.ClientScript.RegisterClientScriptBlock(typeof(Page), "TabScript_Dynamic", script, true);
        }

        protected override void Render(HtmlTextWriter writer) {

            Table tabTable = (Table)Controls[0];
            tabTable.CellSpacing = 0;
            tabTable.CellPadding = 0;
            tabTable.CssClass = "Tabs";

            int index = 0;
            for (int i = 0; i < tabTable.Rows[0].Cells.Count; i++) {
                TableCell cell = (TableCell)tabTable.Rows[0].Cells[i];
                if (i % 2 == 1) {
                    if (ActiveTabIndex == index) {
                        cell.CssClass = "TabActive";
                        cell.Style.Add("background-color", TabActiveBackColor);
                    } else {
                        cell.CssClass = "TabInactive";
                        cell.Style.Add("background-color", TabInactiveBackColor);
                    }
                    cell.Attributes.Add("onmouseover", "TabHelper.mouseOver(this)");
                    cell.Attributes.Add("onmouseout", "TabHelper.mouseOut(this)");

                    cell.Attributes.Add("onclick", TabStripContentMode.RenderAllTabs == ContentMode ? 
                        string.Format("TabHelper.onTabClick(this,{0})", index) :
                        Page.ClientScript.GetPostBackEventReference((LinkButton)cell.Controls[0], ""));

                    index++;
                } else {
                    cell.CssClass = "TabDummy";
                }
                cell.Style.Add("border-color", TabBorderColor);
            }            
            Panel p = (Panel)Controls[1];
            p.CssClass = "TabCanvas";
            p.Style.Add("border-color", TabBorderColor);
            p.Style.Add("background-color", TabActiveBackColor);

            if (TabStripContentMode.RenderAllTabs == ContentMode) {
                Table contentTable = (Table)p.Controls[0];
                TableRow contentTableRow = contentTable.Rows[0];
                for (int i = 0; i < contentTableRow.Cells.Count; i++) {
                    contentTableRow.Cells[i].Style.Add("display", ActiveTabIndex == i ? "inline" : "none");
                }
            }
            base.Render(writer);
        }

        private void IncludeCSSLink() {
            if (Page.Header == null)
                throw new ArgumentException("TabStrip requires Page.Header to be not null. Please add runat=server attribute to <head> element.");

            //Check whether we have already added the reference to the css.
            if (Page.Header.FindControl(STYLESHEET_NAME) == null) {
                LiteralControl styleSheetInclude = new LiteralControl(string.Format("<link href='{0}' rel='stylesheet' type='text/css'>", Page.ClientScript.GetWebResourceUrl(this.GetType(), "XShan.DotShoppingCart.WebControls.TabStrip.TabStrip.css")));
                styleSheetInclude.ID = STYLESHEET_NAME;
                Page.Header.Controls.AddAt(0, styleSheetInclude);
            }
        }

        public class TabCollection : List<Tab> {
        }

    }
}
