//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System.Configuration;
using Microsoft.Practices.EnterpriseLibrary.Common.Configuration;

namespace XShan.DotShoppingCart.Common.Configuration {
    public class StoreConfigurationSection : SerializableConfigurationSection {
        public const string SectionName = "storeConfiguration";
        private const string storeNameProperty = "storeName";
        private const string storeURLProperty = "storeURL";
        private const string storeOwnSSLProperty = "ownSSL";
        private const string enableRichHtmlEditorProperty = "enableRichHtmlEditor";
        private const string storeLocationAddressProperty = "storeLocationAddresss";
        private const string storeLocationCityProperty = "storeLocationCity";
        private const string storeLocationCountryProperty = "storeLocationCountry";
        private const string storeLocationStateProperty = "storeLocationState";
        private const string storeLocationZipcodeProperty = "storeLocationZipcode";
        private const string storeLocationPhoneProperty = "storeLocationTelephone";
        private const string storeLocationPhoneExtProperty = "storeLocationPhoneExt";
        private const string storeLocationFaxProperty = "storeLocationFax";
        private const string storeLocationFaxExtProperty = "storeLocationFaxExt";
        private const string saleEmailAddressesProperty = "saleEmailAddress";
        private const string orderConfirmationEmailAddressesProperty = "orderConfirmationEmailAddresses";
        private const string homepageTitleProperty = "homepageTitle";
        private const string metaTagDescriptionProperty = "metaTagDescription";
        private const string metaTagKeywordsProperty = "metaTagKeywords";
        private const string productWeightUnitProperty = "productWeightUnit";
        private const string migrationProperty = "migration";
        private const string showStockProperty = "showStock";
        private const string wholesaleRoleNameProperty = "wholesaleRoleName";

        [ConfigurationProperty(storeNameProperty, IsRequired = true)]
        public string Name {
            get { return (string)this[storeNameProperty]; }
            set { this[storeNameProperty] = value; }
        }

        [ConfigurationProperty(storeURLProperty, IsRequired = true)]
        public string URL {
            get { return (string)this[storeURLProperty]; }
            set { this[storeURLProperty] = value; }
        }

        [ConfigurationProperty(storeOwnSSLProperty, IsRequired = false, DefaultValue = false)]
        public bool OwnSSL {
            get { return (bool)this[storeOwnSSLProperty]; }
            set { this[storeOwnSSLProperty] = value; }
        }

        [ConfigurationProperty(enableRichHtmlEditorProperty, IsRequired = false, DefaultValue = true)]
        public bool EnableRichHtmlEditor {
            get { return (bool)this[enableRichHtmlEditorProperty]; }
            set { this[enableRichHtmlEditorProperty] = value; }
        }

        [ConfigurationProperty(storeLocationAddressProperty, IsRequired = true)]
        public string LocationAddress {
            get { return (string)this[storeLocationAddressProperty]; }
            set { this[storeLocationAddressProperty] = value; }
        }

        [ConfigurationProperty(storeLocationCityProperty, IsRequired = true)]
        public string LocationCity {
            get { return (string)this[storeLocationCityProperty]; }
            set { this[storeLocationCityProperty] = value; }
        }

        [ConfigurationProperty(storeLocationCountryProperty, IsRequired = true)]
        public string LocationCountry
        {
            get { return (string)this[storeLocationCountryProperty]; }
            set { this[storeLocationCountryProperty] = value; }
        }

        [ConfigurationProperty(storeLocationStateProperty, IsRequired = true)]
        public string LocationState
        {
            get { return (string)this[storeLocationStateProperty]; }
            set { this[storeLocationStateProperty] = value; }
        }

        [ConfigurationProperty(storeLocationZipcodeProperty, IsRequired = true)]
        public string LocationZipcode
        {
            get { return (string)this[storeLocationZipcodeProperty]; }
            set { this[storeLocationZipcodeProperty] = value; }
        }

        [ConfigurationProperty(storeLocationPhoneProperty, IsRequired = true, DefaultValue = "")]
        public string Phone {
            get { return (string)this[storeLocationPhoneProperty]; }
            set { this[storeLocationPhoneProperty] = value; }
        }

        [ConfigurationProperty(storeLocationPhoneExtProperty, IsRequired = false, DefaultValue = "")]
        public string PhoneExt {
            get { return (string)this[storeLocationPhoneExtProperty]; }
            set { this[storeLocationPhoneExtProperty] = value; }
        }

        [ConfigurationProperty(storeLocationFaxProperty, IsRequired = false, DefaultValue = "")]
        public string Fax {
            get { return (string)this[storeLocationFaxProperty]; }
            set { this[storeLocationFaxProperty] = value; }
        }

        [ConfigurationProperty(storeLocationFaxExtProperty, IsRequired = false, DefaultValue = "")]
        public string FaxExt {
            get { return (string)this[storeLocationFaxExtProperty]; }
            set { this[storeLocationFaxExtProperty] = value; }
        }

        [ConfigurationProperty(saleEmailAddressesProperty, IsRequired = true)]
        public string SaleEmailAddress {
            get { return (string)this[saleEmailAddressesProperty]; }
            set { this[saleEmailAddressesProperty] = value; }
        }

        [ConfigurationProperty(orderConfirmationEmailAddressesProperty, IsRequired = true)]
        public NamedElementCollection<NamedConfigurationElement> OrderConfirmationEmailAddresses {
            get { return (NamedElementCollection<NamedConfigurationElement>)this[orderConfirmationEmailAddressesProperty]; }
        }

        [ConfigurationProperty(homepageTitleProperty, IsRequired = false, DefaultValue = "" )]
        public string HomepageTitle {
            get { return (string)this[homepageTitleProperty]; }
            set { this[homepageTitleProperty] = value; }
        }

        [ConfigurationProperty(metaTagDescriptionProperty, IsRequired = true)]
        public string MetaTagDescription {
            get { return (string)this[metaTagDescriptionProperty]; }
            set { this[metaTagDescriptionProperty] = value; }
        }

        [ConfigurationProperty(metaTagKeywordsProperty, IsRequired = true)]
        public string MetaTagKeywords {
            get { return (string)this[metaTagKeywordsProperty]; }
            set { this[metaTagKeywordsProperty] = value; }
        }

        [ConfigurationProperty(productWeightUnitProperty, IsRequired = false, DefaultValue = "lb")]
        public string ProductWeightUnit {
            get { return (string)this[productWeightUnitProperty]; }
            set { this[productWeightUnitProperty] = value; }
        }

        [ConfigurationProperty(migrationProperty, IsRequired = true)]
        public bool Migration {
            get { return (bool)this[migrationProperty]; }
            set { this[migrationProperty] = value; }
        }

        [ConfigurationProperty(showStockProperty, IsRequired = false, DefaultValue = false)]
        public bool ShowStock {
            get { return (bool)this[showStockProperty]; }
            set { this[showStockProperty] = value; }
        }

        [ConfigurationProperty(wholesaleRoleNameProperty, IsRequired = false, DefaultValue = "")]
        public string WholesaleRoleName {
            get { return (string)this[wholesaleRoleNameProperty]; }
            set { this[wholesaleRoleNameProperty] = value; }
        }

        private const string creditCardCleanupDaysProperty = "creditCardCleanupDays";
        [ConfigurationProperty(creditCardCleanupDaysProperty, IsRequired = false, DefaultValue = 30)]
        public int CreditCardCleanupDays {
            get { return (int)this[creditCardCleanupDaysProperty]; }
            set { this[creditCardCleanupDaysProperty] = value; }
        }

        public static StoreConfigurationSection GetSection() {
            return (StoreConfigurationSection)SqlConfigurationController.GetSection(SectionName);
        }

    }
}
