//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System.Configuration;
using Microsoft.Practices.EnterpriseLibrary.Common.Configuration;

namespace XShan.DotShoppingCart.Common.Configuration {
    public class UIConfigurationSection : SerializableConfigurationSection {
        public const string SectionName = "uiConfiguration";

        private const string layoutPanelProperty = "LayoutPanels";
        [ConfigurationProperty(layoutPanelProperty, IsRequired = true)]
        public NamedElementCollection<LayoutPanelConfigurationElement> LayoutPanels {
            get { return (NamedElementCollection<LayoutPanelConfigurationElement>)this[layoutPanelProperty]; }
        }

        private const string themesOverrideTypeProperty = "themesOverrideType";
        [ConfigurationProperty(themesOverrideTypeProperty, IsRequired = false, DefaultValue = ThemesOverrideType.PartialOverride)]
        public ThemesOverrideType ThemesOverride {
            get { return (ThemesOverrideType)this[themesOverrideTypeProperty]; }
            set { this[themesOverrideTypeProperty] = value; }
        }

        private const string parentThemesProperty = "parentThemes";
        [ConfigurationProperty(parentThemesProperty, IsRequired = false, DefaultValue = "Default")]
        public string ParentThemes {
            get { return (string)this[parentThemesProperty]; }
            set { this[parentThemesProperty] = value; }
        }

        private const string logoFilenameProperty = "logoFilename";
        [ConfigurationProperty(logoFilenameProperty, IsRequired = false, DefaultValue = "logo_horizontal.png")]
        public string LogoFilename {
            get { return (string)this[logoFilenameProperty]; }
            set { this[logoFilenameProperty] = value; }
        }

        private const string showProductCountInCategoryListProperty = "showProductCountInCategoryList";
        [ConfigurationProperty(showProductCountInCategoryListProperty, IsRequired = false, DefaultValue = true)]
        public bool ShowProductCountInCategoryList {
            get { return (bool)this[showProductCountInCategoryListProperty]; }
            set { this[showProductCountInCategoryListProperty] = value; }
        }

        private const string featuredProductCountInHomepageProperty = "featuredProductCountInHomepage";
        [ConfigurationProperty(featuredProductCountInHomepageProperty, IsRequired = false, DefaultValue = 15)]
        public int FeaturedProductCountInHomepage {
            get { return (int)this[featuredProductCountInHomepageProperty]; }
            set { this[featuredProductCountInHomepageProperty] = value; }
        }

        private const string categoryProductCountProperty = "categoryProductCount";
        [ConfigurationProperty(categoryProductCountProperty, IsRequired = false, DefaultValue = 24)]
        public int CategoryProductCount {
            get { return (int)this[categoryProductCountProperty]; }
            set { this[categoryProductCountProperty] = value; }
        }

        private const string featuredProductCountInOverviewPageProperty = "featuredProductCountInOverviewPage";
        [ConfigurationProperty(featuredProductCountInOverviewPageProperty, IsRequired = false, DefaultValue = 6)]
        public int FeaturedProductCountInOverviewPage {
            get { return (int)this[featuredProductCountInOverviewPageProperty]; }
            set { this[featuredProductCountInOverviewPageProperty] = value; }
        }

        private const string newProductCountInOverviewPageProperty = "newProductCountInOverviewPage";
        [ConfigurationProperty(newProductCountInOverviewPageProperty, IsRequired = false, DefaultValue = 6)]
        public int NewProductCountInOverviewPage {
            get { return (int)this[newProductCountInOverviewPageProperty]; }
            set { this[newProductCountInOverviewPageProperty] = value; }
        }

        private const string saleProductCountInOverviewPageProperty = "saleProductCountInOverviewPage";
        [ConfigurationProperty(saleProductCountInOverviewPageProperty, IsRequired = false, DefaultValue = 3)]
        public int SaleProductCountInOverviewPage {
            get { return (int)this[saleProductCountInOverviewPageProperty]; }
            set { this[saleProductCountInOverviewPageProperty] = value; }
        }

        private const string colorsProperty = "colors";
        [ConfigurationProperty(colorsProperty, IsRequired = true)]
        public NamedElementCollection<ColorConfigurationElement> Colors {
            get { return (NamedElementCollection<ColorConfigurationElement>)this[colorsProperty]; }
        }

        private const string productSummaryImageWidthProperty = "productSummaryImageWidth";
        [ConfigurationProperty(productSummaryImageWidthProperty, IsRequired = false, DefaultValue = 240)]
        public int ProductSummaryImageWidth {
            get { return (int)this[productSummaryImageWidthProperty]; }
            set { this[productSummaryImageWidthProperty] = value; }
        }

        private const string productSummaryImageHeightProperty = "productSummaryImageHeight";
        [ConfigurationProperty(productSummaryImageHeightProperty, IsRequired = false, DefaultValue = 180)]
        public int ProductSummaryImageHeight {
            get { return (int)this[productSummaryImageHeightProperty]; }
            set { this[productSummaryImageHeightProperty] = value; }
        }

        private const string productSummaryGridWidthProperty = "productSummaryGridWidth";
        [ConfigurationProperty(productSummaryGridWidthProperty, IsRequired = false, DefaultValue = 250)]
        public int ProductSummaryGridWidth {
            get { return (int)this[productSummaryGridWidthProperty]; }
            set { this[productSummaryGridWidthProperty] = value; }
        }

        private const string productSummaryGridHeightProperty = "productSummaryGridHeight";
        [ConfigurationProperty(productSummaryGridHeightProperty, IsRequired = false, DefaultValue = 250)]
        public int ProductSummaryGridHeight {
            get { return (int)this[productSummaryGridHeightProperty]; }
            set { this[productSummaryGridHeightProperty] = value; }
        }

        private const string productListColumnsProperty = "productListColumns";
        [ConfigurationProperty(productListColumnsProperty, IsRequired = false, DefaultValue = 3)]
        public int ProductListColumns {
            get { return (int)this[productListColumnsProperty]; }
            set { this[productListColumnsProperty] = value; }
        }

        private const string topSellerProductCountProperty = "topSellerProductCount";
        [ConfigurationProperty(topSellerProductCountProperty, IsRequired = false, DefaultValue = 5)]
        public int TopSellerProductCount {
            get { return (int)this[topSellerProductCountProperty]; }
            set { this[topSellerProductCountProperty] = value; }
        }

        public static UIConfigurationSection GetSection() {
            return (UIConfigurationSection)SqlConfigurationController.GetSection(SectionName);
        }
    }
    public enum ThemesOverrideType {
        PartialOverride = 0,
        FullOverride = 1
    }
}
