//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Collections.Generic;
using System.Data.SqlClient;
using System.Web.Caching;
using Microsoft.Practices.EnterpriseLibrary.Data;

using XShan.DotShoppingCart.Common.Object;
using XShan.DotShoppingCart.Common.Configuration;

namespace XShan.DotShoppingCart.Common {
    public static class DBController {
        private static Dictionary<string, bool> startedSqlDependency = new Dictionary<string, bool>(StringComparer.OrdinalIgnoreCase);

        public static Database CreateDatabase() {
            return CreateDatabase(SiteNavigation.GetHost());
        }
        
        public static Database CreateDatabase(string connectionStringName) {
            return DatabaseFactory.CreateDatabase(connectionStringName); 
        }

        public static SqlCacheDependency GetSqlCacheDependency(SqlCommand cmd) {
            return GetSqlCacheDependency(SiteNavigation.GetHost(), cmd);
        }

        public static SqlCacheDependency GetSqlCacheDependency(string host, SqlCommand cmd) {
            string connectionString = ConfigurationController.GetSiteConnectionString(host);

            if (!startedSqlDependency.ContainsKey(connectionString)) {
                SqlDependency.Start(connectionString);
                lock (startedSqlDependency) { //Use the late lock to improve performance
                    if (!startedSqlDependency.ContainsKey(connectionString))
                        startedSqlDependency.Add(connectionString, true);
                }
            }
            return new SqlCacheDependency(cmd);
        }

        public static Database CreateRootDatabase() {
            return DatabaseFactory.CreateDatabase(Constant.DB.RootConnectionStringName);
        }
    }
}
