//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.IO;
using System.Collections.Generic;
using System.Web.UI;

using XShan.DotShoppingCart.Common.Configuration;
using XShan.DotShoppingCart.Common.Object;

namespace XShan.DotShoppingCart.Common {
    public abstract class DSCPage : System.Web.UI.Page {
        private string parentThemes;

        protected override void OnPreInit(EventArgs e) {
            base.OnPreInit(e);

            if ((null != MasterPageFile) && MasterPageFile.Contains("Admin")) {
                this.Theme = "admin";
            } else {
                UIConfigurationSection uiSection = UIConfigurationSection.GetSection();

                string theme = null;
                switch (uiSection.ThemesOverride) {
                    case ThemesOverrideType.FullOverride:
                        theme = SiteNavigation.GetHost();
                        new DbTemplate("App_Themes").GetFile(SiteNavigation.GetHost(), Constant.UI.OverrideThemeStypeSheetTemplateName);
                        new DbTemplate("App_Themes").GetFile(SiteNavigation.GetHost(), Constant.UI.OverrideThemeSkinTemplateName);
                        break;
                    case ThemesOverrideType.PartialOverride:
                    default:
                        theme = SiteNavigation.GetHost();
                        parentThemes = uiSection.ParentThemes;
                        new DbTemplate("App_Themes", WriteThemeContent).GetFile(SiteNavigation.GetHost(), Constant.UI.OverrideThemeStypeSheetTemplateName);
                        new DbTemplate("App_Themes", WriteThemeContent).GetFile(SiteNavigation.GetHost(), Constant.UI.OverrideThemeSkinTemplateName);
                        break;
                }
                this.Theme = theme;
            }
            Response.Expires = 0;
        }

        private void WriteThemeContent(string fileSpec, string templateContent) {
            string filename = Path.GetFileName(fileSpec);
            string fileSpecInParentThemes = Path.Combine(WebUtils.GetThemesTemplatePath(parentThemes), filename);
            if (File.Exists(fileSpecInParentThemes)) {
                templateContent = ReplaceConfigurationSettings(File.ReadAllText(fileSpecInParentThemes) + "\n" + templateContent);
            }
            File.WriteAllText(fileSpec, templateContent);
        }

        private string ReplaceConfigurationSettings(string template) {
            UIConfigurationSection uiSection = UIConfigurationSection.GetSection();
            Dictionary<string, string> tokens = new Dictionary<string,string>();

            // add UI tokens
            LayoutPanelConfigurationElement leftPanel = uiSection.LayoutPanels.Get("leftPanel");
            LayoutPanelConfigurationElement rightPanel = uiSection.LayoutPanels.Get("rightPanel");
            tokens.Add("LeftPanelWidth", null == leftPanel ? "0" : leftPanel.Width);
            tokens.Add("RightPanelWidth", null == rightPanel ? "0" : rightPanel.Width);
            
            tokens.Add("ProductSummaryGridWidth", uiSection.ProductSummaryGridWidth.ToString());
            tokens.Add("ProductSummaryGridHeight", uiSection.ProductSummaryGridHeight.ToString());
            tokens.Add("ProductSummaryImageWidth", uiSection.ProductSummaryImageWidth.ToString());
            tokens.Add("ProductSummaryImageHeight", uiSection.ProductSummaryImageHeight.ToString());

            foreach (string colorName in Constant.UI.ColorNames) {
                tokens.Add(colorName, uiSection.Colors.Get(colorName).Value);
                tokens.Add(string.Format("UrlEncoded_{0}", colorName), Server.UrlEncode(uiSection.Colors.Get(colorName).Value));
            }

            foreach (string token in tokens.Keys) {
                template = template.Replace("%" + token + "%", tokens[token]);
            }
            return template;
        }
    }
}
