//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Collections.Generic;
using System.Collections.Specialized;
using System.Net.Mail;
using System.IO;
using System.Text.RegularExpressions;

using XShan.DotShoppingCart.Common.Object;

namespace XShan.DotShoppingCart.Common {
    public class EmailManager {
        public static void Send(string templateName, NameValueCollection tokensToReplace, string from,
            ICollection<string> to) {
            Send(SiteNavigation.GetHost(), templateName, tokensToReplace, from, to, null);
        }

        public static void Send(string host, string templateName, NameValueCollection tokensToReplace, string from,
            ICollection<string> to, ICollection<string> bcc) {
            string templateFile = new DbTemplate().GetFile(host, templateName);
            string templateContent = File.ReadAllText(templateFile);
            string subject, content;
            SplitSubjectAndContent(templateContent, out subject, out content);

            SendEmail(subject, content, tokensToReplace, from, to, bcc);
        }

        public static void SendEmail(string subject, string content, NameValueCollection tokensToReplace, string from,
            ICollection<string> to, ICollection<string> bcc) {

            MailMessage message = new MailMessage();
            message.From = new MailAddress(from);
            foreach (string address in to)
                message.To.Add(address);
            if (null != bcc)
                foreach (string address in bcc) {
                    message.Bcc.Add(address);
                }

            message.Subject = Utils.ReplaceTokens(subject, tokensToReplace);
            message.Body = Utils.ReplaceTokens(content, tokensToReplace);
            message.IsBodyHtml = true;
            new SmtpClient(null).Send(message);
        }

        public static void LoadEmailCampaignTemplate(string host, string templateName, out string subject, out string content) {
            string templateFile = new DbTemplate().GetFile(host, templateName);
            string templateContent = File.ReadAllText(templateFile);

            SplitSubjectAndContent(templateContent, out subject, out content);

            NameValueCollection tokens = Utils.GetStoreTokens(host);
            content = Utils.ReplaceTokens(content, tokens);
            content = Utils.ReplaceSKUTokens(host, content);
        }

        public static void SplitSubjectAndContent(string template, out string subject, out string content) {
            Match m = Regex.Match(template, "<subject>(?<subject>[^<>]*)</subject>(?<content>.*)", RegexOptions.Singleline);
            if (m.Success) {
                subject = m.Groups["subject"].Value;
                content = m.Groups["content"].Value;
            } else { // use default value for subject
                subject = "Your %Store.Name% Order#  %Order.OrderNumber%";
                content = template;
            }
        }

        public static string MergeSubjectAndContent(string subject, string content) {
            return string.Format("<subject>{0}</subject>\n{1}", subject, content);
        }
    }
}
