//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Collections.Generic;
using System.Web;
using System.Configuration;

using XShan.DotShoppingCart.Common.Object;
using XShan.DotShoppingCart.Common.Configuration;

namespace XShan.DotShoppingCart.Common
{
    public static class FileController
    {
        public static string GetImageUrl(int? imageId) {
            return GetImageUrl(imageId, 0, 0);
        }

        public static string GetImageUrl(int? imageId, int width, int height) {
            return GetImageUrl(imageId, width, height, false);
        }

        public static string GetImageUrl(int? imageId, int width, int height, bool noTimeStampCheck) {
            if (null == imageId)
                return SiteNavigation.ResolveUrl(DbImage.ImageDirectory + "/noimage.gif");

            string localFilename = DbImage.GetFile(SiteNavigation.GetHost(), (int)imageId, width, height, noTimeStampCheck);
            return SiteNavigation.ResolveUrl(DbImage.ImageDirectory + "/" + SiteNavigation.GetHost() + "/" + localFilename);
        }

        public static string GetDbImageHttpHandlerUrl(int? imageId) {
            return GetImageUrl(imageId, 0, 0);
        }

        public static string GetDbImageHttpHandlerUrl(int? imageId, int width, int height) {
            if (null == imageId)
                return SiteNavigation.ResolveUrl(DbImage.ImageDirectory + "/noimage.gif");

            string relativeUrl = string.Format("dbimage.axd?id={0}", (int)imageId);
            if (width > 0)
                relativeUrl += string.Format("&width={0}", width);
            if (height > 0)
                relativeUrl += string.Format("&height={0}", height);
            return SiteNavigation.ResolveUrl(relativeUrl);
        }

        public static string GetDbImageHttpHandlerUrl(string host, int? imageId, int width, int height) {
            if (null == imageId)
                return SiteNavigation.ResolveAbsoluteUrl(host, DbImage.ImageDirectory, "noimage.gif");

            string relativeUrl = string.Format("dbimage.axd?id={0}", (int)imageId);
            if (width > 0)
                relativeUrl += string.Format("&width={0}", width);
            if (height > 0)
                relativeUrl += string.Format("&height={0}", height);
            return SiteNavigation.ResolveAbsoluteUrl(host, relativeUrl);
        }

        public static string GetFileUrl(string name) {
            string filespec = new DbFile().GetFile(SiteNavigation.GetHost(), name);
            if (string.IsNullOrEmpty(filespec))
                return null;
            return SiteNavigation.UnMapPath(filespec);
        }

        public static string GetStoreLogoUrl() {
            UIConfigurationSection section = UIConfigurationSection.GetSection();
            if (string.IsNullOrEmpty(section.LogoFilename))
                return null;
            return FileController.GetFileUrl(section.LogoFilename);
        }
    }
}
