//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Data.Common;
using Microsoft.Practices.EnterpriseLibrary.Data;

namespace XShan.DotShoppingCart.Common.Object {
    [Serializable]
    public class Address : ILoadFromDataRow {
        private int addressId;
        private string firstName, lastName, companyName, address1, address2, city, state, zipcode, phone, phoneExt;
        private int countryId;
        private Country country;
        private bool isBilling = false, isDefaultShipping;
        
        public int AddressId {
            get { return addressId; }
        }

        public string FirstName {
            get { return firstName; }
            set { firstName = value; }
        }

        public string LastName {
            get { return lastName; }
            set { lastName = value; }
        }

        public string CompanyName {
            get { return companyName; }
            set { companyName = value; }
        }

        public string Address1 {
            get { return address1; }
            set { address1 = value; }
        }

        public string Address2 {
            get { return address2; }
            set { address2 = value; }
        }

        public string City {
            get { return city; }
            set { city = value; }
        }

        public string State {
            get { return state; }
            set { state = value; }
        }

        public string Zipcode {
            get { return zipcode; }
            set { zipcode = value; }
        }

        public string Phone {
            get { return phone; }
            set { phone = value; }
        }

        public string PhoneExt {
            get { return phoneExt; }
            set { phoneExt = value; }
        }
        
        public int CountryId {
            get { return countryId; }
        }

        public Country Country {
            get { return country; }
            set { 
                country = value;
                if (null != country)
                    countryId = country.CountryId;
            }
        }

        public bool IsDefaultShipping {
            get { return isDefaultShipping; }
        }

        public bool IsBilling {
            get { return isBilling; }
            set { isBilling = value; }
        }

        public Address() {
        }

        public Address(string firstName, string lastName, string companyName, string address1, string address2, string city, string state, 
            string zipcode, int countryId, string phone, string phoneExt) {
            this.firstName = firstName;
            this.lastName = lastName;
            this.companyName = companyName;
            this.address1 = address1;
            this.address2 = address2;
            this.city = city;
            this.state = state;
            this.zipcode = zipcode;
            this.countryId = countryId;
            this.phone = phone;
            this.phoneExt = phoneExt;
        }

        public bool LoadFromDataRow(DataRow row) {
            addressId = (int)row["addressId"];
            if (row.Table.Columns.Contains("isBilling"))
                isBilling = (bool)row["isBilling"];
            if (row.Table.Columns.Contains("isDefaultShipping"))
                isDefaultShipping = (bool)row["isDefaultShipping"];
            firstName = row["firstName"] as string;
            lastName = row["lastName"] as string;
            companyName = row["companyName"] as string;
            address1 = row["address"] as string;
            address2 = row["address2"] as string;
            city = row["city"] as string;
            state = row["state"] as string;
            zipcode = row["zipcode"] as string;
            countryId = (int)row["countryId"];
            phone = row["phone"] as string;
            phoneExt = row["phoneExt"] as string;

            //Country
            if (row.Table.DataSet.Relations.Contains(Constant.DBRelation.COUNTRY_ADDRESS)) {
                // expect only one record
                country = new RecordList<Country>(row.GetParentRows(Constant.DBRelation.COUNTRY_ADDRESS))[0];
            } else {
                throw new ApplicationException("Country data is expected when loading Address.");
            }
            return true;
        }

        public override string ToString() {
            string[] all = new string[] {
                firstName, lastName, companyName, address1, address2, city, state, zipcode, countryId.ToString(), phone, phoneExt
            };
            return string.Join("\n", all);
        }

        public static int AddShippingAddress(string firstName, string lastName, string companyName, string address,
            string address2, string city, string state, string zipcode, int countryId, string phone, string phoneExt) {
            return AddShippingAddress(Utils.GetUserName(), firstName, lastName, companyName, address, address2, city, state, zipcode, countryId, phone, phoneExt);
        }

        public static int AddShippingAddress(string userName, string firstName, string lastName, string companyName, string address,
            string address2, string city, string state, string zipcode, int countryId, string phone, string phoneExt) {
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_Address_Add", userName, 0 /* isBilling */, firstName, lastName, companyName,
                address, address2, city, state, zipcode, countryId, phone, phoneExt);
            object output = db.ExecuteScalar(cmd);
            return int.Parse(output.ToString());
        }

        public static Address[] GetShippingAddresses() {
            return GetShippingAddresses(Utils.GetUserName());
        }

        public static Address[] GetShippingAddresses(string userName) {
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_Address_GetShipping", userName);
            DataSet ds = db.ExecuteDataSet(cmd);

            SetTableRelations(ds, 0);

            RecordList<Address> addresses = new RecordList<Address>(ds.Tables[0]);
            return addresses.ToArray();
        }

        public static int SetTableRelations(DataSet ds, int startTableIndex) {
            int index = startTableIndex;
            ds.Tables[index++].TableName = "Address";
            ds.Tables[index++].TableName = "Country";

            ds.Relations.Add(Constant.DBRelation.COUNTRY_ADDRESS, ds.Tables["Country"].Columns["CountryId"], ds.Tables["Address"].Columns["CountryId"]);

            return index; 
        }

        public static void Delete(int addressId) {
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_Address_Delete", addressId);
            db.ExecuteNonQuery(cmd);
        }

        public static void Update(int addressId, bool isDefaultShipping, string firstName, string lastName, string companyName, string address,
            string address2, string city, string state, string zipcode, int countryId, string phone, string phoneExt) {
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_Address_Update", addressId, isDefaultShipping, firstName, lastName, companyName,
                address, address2, city, state, zipcode, countryId, phone, phoneExt);
            db.ExecuteNonQuery(cmd);
        }

        public static void SetDefault(int addressId) {
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_Address_SetDefault", addressId);
            db.ExecuteNonQuery(cmd);
        }

        public static string GetStandardStateName(Address address) {
            return GetStandardStateName(address.State, address.CountryId);
        }

        public static string GetStandardStateName(string state, int countryId) {
            switch (countryId) {
                case 1: //US
                    switch (state.ToLower()) {
                        case "aa":
                            return "AA";
                        case "ap":
                            return "AP";
                        case "ae":
                            return "AE";
                        case "alabama":
                        case "al":
                            return "AL";
                        case "alaska":
                        case "ak":
                            return "AK";
                        case "arkansas":
                        case "ar":
                            return "AR";
                        case "american samoa":
                            return "AS";
                        case "arizona":
                        case "az":
                            return "AZ";
                        case "california":
                        case "ca":
                            return "CA";
                        case "colorado":
                        case "co":
                            return "CO";
                        case "connecticut":
                        case "ct":
                            return "CT";
                        case "district of columbia":
                        case "dc":
                            return "DC";
                        case "delaware":
                        case "de":
                            return "DE";
                        case "federated states of micronesia":
                            return "FM";
                        case "florida":
                        case "fl":
                            return "FL";
                        case "georgia":
                        case "ga":
                            return "GA";
                        case "guam":
                            return "GU";
                        case "hawaii":
                        case "hi":
                            return "HI";
                        case "iowa":
                        case "ia":
                            return "IA";
                        case "idaho":
                        case "id":
                            return "ID";
                        case "illinois":
                        case "il":
                            return "IL";
                        case "indiana":
                        case "in":
                            return "IN";
                        case "kansas":
                        case "ks":
                            return "KS";
                        case "kentucky":
                        case "ky":
                            return "KY";
                        case "louisiana":
                        case "la":
                            return "LA";
                        case "maine":
                        case "me":
                            return "ME";
                        case "marshall islands":
                            return "MH";
                        case "maryland":
                        case "md":
                            return "MD";
                        case "massachusetts":
                        case "ma":
                            return "MA";
                        case "michigan":
                        case "mi":
                            return "MI";
                        case "minnesota":
                        case "mn":
                            return "MN";
                        case "mississippi":
                        case "ms":
                            return "MS";
                        case "missouri":
                        case "mo":
                            return "MO";
                        case "montana":
                        case "mt":
                            return "MT";
                        case "nebraska":
                        case "ne":
                            return "NE";
                        case "nevada":
                        case "nv":
                            return "NV";
                        case "new hampshire":
                        case "nh":
                            return "NH";
                        case "new jersey":
                        case "nj":
                            return "NJ";
                        case "new mexico":
                        case "nm":
                            return "NM";
                        case "new york":
                        case "ny":
                            return "NY";
                        case "north carolina":
                        case "nc":
                            return "NC";
                        case "north dakota":
                        case "nd":
                            return "ND";
                        case "northern mariana islands":
                            return "MP";
                        case "ohio":
                        case "oh":
                            return "OH";
                        case "oklahoma":
                        case "ok":
                            return "OK";
                        case "oregon":
                        case "or":
                            return "OR";
                        case "palau":
                            return "PW";
                        case "pennsylvania":
                        case "pa":
                            return "PA";
                        case "puerto rico":
                        case "pr":
                            return "PR";
                        case "rhode island":
                        case "ri":
                            return "RI";
                        case "south carolina":
                        case "sc":
                            return "SC";
                        case "south dakota":
                        case "sd":
                            return "SD";
                        case "tennessee":
                        case "tn":
                            return "TN";
                        case "texas":
                        case "tx":
                            return "TX";
                        case "utah":
                        case "ut":
                            return "UT";
                        case "vermont":
                        case "vt":
                            return "VT";
                        case "virgin islands":
                            return "VI";
                        case "virginia":
                        case "va":
                            return "VA";
                        case "washington":
                        case "wa":
                            return "WA";
                        case "west virginia":
                        case "wv":
                            return "WV";
                        case "wisconsin":
                        case "wi":
                            return "WI";
                        case "wyoming":
                        case "wy":
                            return "WY";
                    }
                    throw new ApplicationException("Bad state code");
                case 11: //CA
                    switch (state.ToLower()) {
                        case "alberta":
                        case "ab":
                            return "AB";
                        case "british columbia":
                        case "bc":
                            return "BC";
                        case "manitoba":
                        case "mb":
                            return "MB";
                        case "new brunswick":
                        case "nb":
                            return "NB";
                        case "newfoundland and labrador":
                        case "nl":
                            return "NL";
                        case "northwest territories":
                        case "nt":
                            return "NT";
                        case "nova scotia":
                        case "ns":
                            return "NS";
                        case "nunavut":
                        case "nu":
                            return "NU";
                        case "ontario":
                        case "on":
                            return "ON";
                        case "prince edward island":
                        case "pe":
                            return "PE";
                        case "quebec":
                        case "qc":
                            return "QC";
                        case "saskatchewan":
                        case "sk":
                            return "SK";
                        case "yukon":
                        case "yukon territory":
                        case "yt":
                            return "YT";
                    }
                    throw new ApplicationException("Bad state code");
            }
            return state;
        }
    }
}
