//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.IO;
using System.Data;
using System.Data.Common;
using System.Collections.Generic;
using Microsoft.Practices.EnterpriseLibrary.Data;

namespace XShan.DotShoppingCart.Common.Object {
    public class Binary : DbFileBase {
        private int binaryId;
        private string name;
        private DateTime timeUpdated;
        private byte[] data;

        public int BinaryId {
            get { return binaryId; }
        }
        public string Name {
            get { return name; }
        }
        public DateTime TimeUpdated {
            get { return timeUpdated; }
        }
        public byte[] Data {
            get { return data; }
        }

        protected override string TimeStampProc {
            get { return "DSC_Binary_GetTimeStamp"; }
        }

        protected override string GetFilePath(string host) {
            return Utils.GetAppDataPath(host);
        }

        protected override void CreateFile(string host, object key, string localFileSpec) {
            Binary b = Get(host, (int)key);
            File.WriteAllBytes(localFileSpec, b.Data);
        }

        public Binary() {
        }

        public Binary(int binaryId, byte[] data, string name, DateTime timeUpdated) {
            this.binaryId = binaryId;
            this.data = data;
            this.name = name;
            this.timeUpdated = timeUpdated;
        }

        public static Binary Get(string host, int binaryId) {
            Database db = DBController.CreateDatabase(host);
            DbCommand cmd = db.GetStoredProcCommand("DSC_Binary_Get", binaryId);
            Binary binary = null;
            using (IDataReader dataReader = db.ExecuteReader(cmd)) {
                dataReader.Read();
                binary = new Binary((int)dataReader["binaryId"],
                    (byte[])dataReader["data"],
                    (string)dataReader["name"],
                    (DateTime)dataReader["timeUpdated"]);
            }
            return binary;
        }

        public static int Add(byte[] data, string name) {
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_Binary_Add", data, name);
            return Convert.ToInt32(db.ExecuteScalar(cmd));
        }

        public static void Delete(int binaryId) {
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_Binary_Delete", binaryId);
            db.ExecuteScalar(cmd);
        }
    }
}
