//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Common;
using Microsoft.Practices.EnterpriseLibrary.Data;

namespace XShan.DotShoppingCart.Common.Object {
    [Serializable]
    public class Country : ILoadFromDataRow {
        private int countryId;
        private string name, codeISO3166;
        private int sortOrder;

        public int CountryId {
            get { return countryId; }
        }
        public string Name {
            get { return name; }
            set { name = value; }
        }
        public string CodeISO3166 {
            get { return codeISO3166; }
            set { codeISO3166 = value; }
        }
        public int SortOrder {
            get { return sortOrder; }
            set { sortOrder = value; }
        }

        public Country() {
        }

        public bool LoadFromDataRow(DataRow row) {
            countryId = (int)row["countryId"];
            name = (string)row["name"];
            codeISO3166 = (string)row["codeISO3166"];
            sortOrder = (int)row["sortOrder"];
            return true;
        }

        public static List<Country> GetAll() {
            return GetAll(SiteNavigation.GetHost());
        }

        public static List<Country> GetAll(string host) {
            Database db = DBController.CreateDatabase(host);
            DbCommand cmd = db.GetStoredProcCommand("DSC_Country_GetAll");
            DataSet ds = db.ExecuteDataSet(cmd);
            return new RecordList<Country>(ds.Tables[0]);
        }

        public static Country Get(int countryId) {
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_Country_Get", countryId);
            DataSet ds = db.ExecuteDataSet(cmd);
            List<Country> countries = new RecordList<Country>(ds.Tables[0]);
            if ((null != countries) && (countries.Count > 0))
                return countries[0];
            return null;
        }

        public static Country GetFromCodeISO3166(string codeISO3166) {
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_Country_GetFromCodeISO3166", codeISO3166);
            DataSet ds = db.ExecuteDataSet(cmd);

            RecordList<Country> countries = new RecordList<Country>(ds.Tables[0]);
            if ((null == countries) || (0 == countries.Count))
                return null;

            return countries[0];
        }
    }
}
