//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Collections.Generic;
using System.Data.Common;
using Microsoft.Practices.EnterpriseLibrary.Data;

namespace XShan.DotShoppingCart.Common.Object {
    [Serializable]
    public class CreditCardType : ILoadFromDataRow {
        #region Member Variables
        private int creditCardTypeId;
        private string type, shortType;
        private bool enabled;
        #endregion

        #region Properties
        public int CreditCardTypeId {
            get { return creditCardTypeId; }
        }
        public string Type {
            get { return type; }
        }
        public string ShortType {
            get { return shortType; }
        }
        public bool Enabled {
            get { return enabled; }
        }
        #endregion

        #region Constructors
        public CreditCardType() {
        }

        public bool LoadFromDataRow(DataRow row) {
            creditCardTypeId = (int)row["creditCardTypeId"];
            type = (string)row["type"];
            shortType = (string)row["shortType"];
            enabled = (bool)row["enabled"];
            return true;
        }
        #endregion

        public static List<CreditCardType> GetAll() {
            return GetAll(true);
        }

        public static List<CreditCardType> GetAll(bool enabledOnly) {
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_CreditCard_Type_GetAll", enabledOnly);
            DataSet ds = db.ExecuteDataSet(cmd);

            RecordList<CreditCardType> creditCardTypes = new RecordList<CreditCardType>(ds.Tables[0]);
            return creditCardTypes;
        }

        public static CreditCardType Get(int creditCardTypeId) {
            foreach (CreditCardType cardType in GetAll()) {
                if (cardType.creditCardTypeId == creditCardTypeId)
                    return cardType;
            }
            return null;
        }

        public static void Update(int creditCardTypeId, bool enabled) {
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_CreditCard_Type_Update", creditCardTypeId, enabled);
            db.ExecuteNonQuery(cmd);
        }
    }

    public enum CreditCartTypeEnum {
        Visa = 1,
        MasterCard = 2,
        Amex = 3,
        Discover = 4
    }
}
