//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Common;
using Microsoft.Practices.EnterpriseLibrary.Data;

namespace XShan.DotShoppingCart.Common.Object {
    [Serializable]
    public class DSCAttribute : ILoadFromDataRow {
        private int attributeId, sortOrder;
        private string name, description;
        private bool isRequired;
        private SelectionType selectionType;
        private DisplayControl displayControl;

        public int AttributeId {
            get { return attributeId; }
        }
        public string Name {
            get { return name; }
            set { name = value; }
        }
        public string Description {
            get { return description; }
            set { description = value; }
        }
        public bool IsRequired {
            get { return isRequired; }
            set { isRequired = value; }
        }
        public int SortOrder {
            get { return sortOrder; }
        }
        public SelectionType SelectionType {
            get { return selectionType; }
            set { selectionType = value; }
        }
        public DisplayControl DisplayControl {
            get { return displayControl; }
            set { displayControl = value; }
        }

        public DSCAttribute() {
        }

        public bool LoadFromDataRow(DataRow row) {
            attributeId = (int)row["attributeId"];
            name = (string)row["name"];
            description = row["description"] as string;
            isRequired = (bool)row["isRequired"];
            sortOrder = (int)row["sortOrder"];

            // SelectionTypeDisplayControl
            if (row.Table.DataSet.Relations.Contains(Constant.DBRelation.ATTRIBUTE_SELECTIONTYPEDISPLAYCONTROL)) {
                // just one record only
                DataRow rowSelectionTypeDisplayControl = row.GetParentRow(Constant.DBRelation.ATTRIBUTE_SELECTIONTYPEDISPLAYCONTROL);

                //SelectionType
                if (rowSelectionTypeDisplayControl.Table.DataSet.Relations.Contains(Constant.DBRelation.SELECTIONTYPEDISPLAYCONTROL_SELECTIONTYPE)) {
                    selectionType = new RecordList<SelectionType>(rowSelectionTypeDisplayControl.GetParentRows(Constant.DBRelation.SELECTIONTYPEDISPLAYCONTROL_SELECTIONTYPE))[0];
                } else {
                    throw new ApplicationException("SelectionType data is expected when loading ProductAttributeSelection.");
                }

                //DisplayControl
                if (rowSelectionTypeDisplayControl.Table.DataSet.Relations.Contains(Constant.DBRelation.SELECTIONTYPEDISPLAYCONTROL_DISPLAYCONTROL)) {
                    displayControl = new RecordList<DisplayControl>(rowSelectionTypeDisplayControl.GetParentRows(Constant.DBRelation.SELECTIONTYPEDISPLAYCONTROL_DISPLAYCONTROL))[0];
                } else {
                    throw new ApplicationException("DisplayControl data is expected when loading ProductAttributeSelection.");
                }
            } else {
                throw new ApplicationException("SelectionTypeDisplayControl data is expected when loading ProductAttributeSelection.");
            }
            return true;
        }

        public static List<DSCAttribute> GetAll() {
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_Attribute_GetAll");
            DataSet ds = db.ExecuteDataSet(cmd);
            SetAttributeTableRelations(ds, 0);
            return new RecordList<DSCAttribute>(ds.Tables[0]);
        }

        public static DSCAttribute Get(int attributeId) {
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_Attribute_Get", attributeId);
            DataSet ds = db.ExecuteDataSet(cmd);
            SetAttributeTableRelations(ds, 0);
            List<DSCAttribute> attributes = new RecordList<DSCAttribute>(ds.Tables[0]);
            if ((null != attributes) && (attributes.Count > 0))
                return attributes[0];
            return null;
        }

        public static int Add(string name, string description, bool required, int selectionTypeId, int displayControlTypeId) {
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_Attribute_Add", name, description, required, selectionTypeId, displayControlTypeId, 0); //Todo: need to deal with sortOrder better
            object output = db.ExecuteScalar(cmd);
            return int.Parse(output.ToString());
        }

        public static void Update(int attributeId, string name, string description, bool required, int selectionTypeId, int displayControlTypeId) {
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_Attribute_Update", attributeId, name, description, required, selectionTypeId, displayControlTypeId, 0); //Todo: need to deal with sortOrder better
            db.ExecuteNonQuery(cmd);
        }

        public static void Delete(int attributeId) {
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_Attribute_Delete", attributeId);
            db.ExecuteNonQuery(cmd);
        }

        public static int SetAttributeTableRelations(DataSet ds, int startTableIndex) {
            int i = startTableIndex;
            ds.Tables[i++].TableName = "Attribute";
            ds.Tables[i++].TableName = "SelectionTypeDisplayControl";
            ds.Tables[i++].TableName = "SelectionType";
            ds.Tables[i++].TableName = "DisplayControl";

            ds.Relations.Add(Constant.DBRelation.ATTRIBUTE_SELECTIONTYPEDISPLAYCONTROL, ds.Tables["SelectionTypeDisplayControl"].Columns["selectionTypeDisplayControlId"], ds.Tables["Attribute"].Columns["selectionTypeDisplayControlId"]);
            ds.Relations.Add(Constant.DBRelation.SELECTIONTYPEDISPLAYCONTROL_SELECTIONTYPE, ds.Tables["SelectionType"].Columns["selectionTypeId"], ds.Tables["SelectionTypeDisplayControl"].Columns["selectionTypeId"]);
            ds.Relations.Add(Constant.DBRelation.SELECTIONTYPEDISPLAYCONTROL_DISPLAYCONTROL, ds.Tables["DisplayControl"].Columns["displayControlId"], ds.Tables["SelectionTypeDisplayControl"].Columns["displayControlId"]);

            return i;
        }
    }
}
