//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Data.Common;
using System.Collections.Generic;
using System.Web;
using System.Web.Security;
using Microsoft.Practices.EnterpriseLibrary.Data;

namespace XShan.DotShoppingCart.Common.Object {
    public class DSCRole : ILoadFromDataRow {
        private int roleId;
        private string name;
        private decimal discountRate, minOrderAmount;

        public int RoleId {
            get { return roleId; }
        }
        public decimal DiscountRate {
            get { return discountRate; }
        }
        public decimal MinOrderAmount {
            get { return minOrderAmount; }
        }
        public string Name {
            get { return name; }
        }

        public DSCRole() {
        }

        public bool LoadFromDataRow(DataRow row) {
            roleId = (int)row["roleId"];
            name = (string)row["name"];
            discountRate = (decimal)row["discountRate"];
            minOrderAmount = (decimal)row["minOrderAmount"];
            return true;
        }

        public static List<DSCRole> GetAll() {
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_Role_GetAll");
            DataSet ds = db.ExecuteDataSet(cmd);

            return new RecordList<DSCRole>(ds.Tables[0]);
        }

        public static DSCRole Get(string name) {
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_Role_Get", name);
            DataSet ds = db.ExecuteDataSet(cmd);

            RecordList<DSCRole> roles = new RecordList<DSCRole>(ds.Tables[0]);
            if ((null == roles) || (roles.Count == 0))
                return null;
            return roles[0];
        }

        public static int Add(string name, decimal discountRate, decimal minOrderAmount) {
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_Role_Add", name, discountRate, minOrderAmount);
            return Convert.ToInt32(db.ExecuteScalar(cmd));
        }

        public static void Update(string name, decimal discountRate, decimal minOrderAmount) {
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_Role_Update", name, discountRate, minOrderAmount);
            db.ExecuteNonQuery(cmd);
        }

        public static void Delete(string name) {
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_Role_Delete", name);
            db.ExecuteNonQuery(cmd);
        }
    }
}
