//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Data.SqlClient;
using System.Data.Common;
using System.Web;
using System.Web.Caching;
using System.Drawing;
using System.Drawing.Imaging;
using System.IO;
using System.Collections.Generic;
using Microsoft.Practices.EnterpriseLibrary.Data;


namespace XShan.DotShoppingCart.Common.Object {
    public class DbFile : DbFileBase {
        private int fileId;
        private string name, mime;
        private DateTime timeUpdated;
        private byte[] bits;

        public int FileId {
            get { return fileId; }
        }
        public string Name {
            get { return name; }
        }
        public string MIME {
            get { return mime; }
        }
        public DateTime TimeUpdated {
            get { return timeUpdated; }
        }
        public byte[] Bits {
            get { return bits; }
        }

        protected override string TimeStampProc {
            get { return "DSC_File_GetTimeStamp"; }
        }

        protected override string GetFilePath(string host) {
            return HttpContext.Current.Request.PhysicalApplicationPath + Path.Combine("Files", SiteNavigation.GetHost());
        }

        protected override void CreateFile(string host, object key, string localFileSpec) {
            DbFile b = Get(host, (string)key);
            File.WriteAllBytes(localFileSpec, b.Bits);
        }

        public DbFile() {
        }

        public DbFile(int fileId, string name, byte[] bits, string mime, DateTime timeUpdated) {
            this.fileId = fileId;
            this.name = name;
            this.bits = bits;
            this.mime = mime;
            this.timeUpdated = timeUpdated;
        }

        public static DbFile Get(string host, string name) {
            Database db = DBController.CreateDatabase(host);
            DbCommand cmd = db.GetStoredProcCommand("DSC_File_Get", name);
            DbFile file = null;
            using (IDataReader dataReader = db.ExecuteReader(cmd)) {
                if (dataReader.Read()) {
                    file = new DbFile((int)dataReader["fileId"],
                        (string)dataReader["name"],
                        (byte[])dataReader["bits"],
                        (string)dataReader["mime"],
                        (DateTime)dataReader["timeUpdated"]);
                }
            }
            return file;
        }

        public static List<DbFile> GetAllWithoutContent() {
            return GetAllWithoutContent(SiteNavigation.GetHost());
        }

        public static List<DbFile> GetAllWithoutContent(string host) {
            Database db = DBController.CreateDatabase(host);
            DbCommand cmd = db.GetStoredProcCommand("DSC_File_GetAll_NoBits");
            List<DbFile> files = new List<DbFile>();
            using (IDataReader dataReader = db.ExecuteReader(cmd)) {
                while (dataReader.Read()) {
                    files.Add(new DbFile((int)dataReader["fileId"],
                        (string)dataReader["name"],
                        DBNull.Value == dataReader["bits"] ? null : (byte[])dataReader["bits"],
                        (string)dataReader["mime"],
                        (DateTime)dataReader["timeUpdated"]));
                }
            }
            return files;
        }

        /// <summary>
        /// Add a new file into DB if not exist, otherwise update the existing one
        /// </summary>
        /// <param name="bits"></param>
        /// <param name="name"></param>
        /// <param name="mime"></param>
        /// <returns>file Id</returns>
        public static int Set(string name, byte[] bits, string mime) {
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_File_Set", name, bits, mime);
            return Convert.ToInt32(db.ExecuteScalar(cmd));
        }
    }
}
