//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.IO;
using System.Data;
using System.Data.SqlClient;
using System.Data.Common;
using System.Collections.Generic;
using System.Collections.Specialized;
using System.Web.Caching;
using Microsoft.Practices.EnterpriseLibrary.Data;

namespace XShan.DotShoppingCart.Common.Object {
    public abstract class DbFileBase {
        public DbFileBase() {
        }

        /// <summary>
        /// This sproc return 2 columns. The 1st is filename, and 2nd is timeUpdated.
        /// </summary>
        protected abstract string TimeStampProc {
            get;
        }

        /// <summary>
        /// The path where file will be created.
        /// </summary>
        /// <param name="host"></param>
        /// <returns></returns>
        protected abstract string GetFilePath(string host);

        /// <summary>
        /// Need to create this file because the cached file is outdated.
        /// </summary>
        /// <param name="host"></param>
        /// <param name="key"></param>
        /// <param name="localFileSpec"></param>
        protected abstract void CreateFile(string host, object key, string localFileSpec);

        public string GetFile(object key) {
            return GetFile(SiteNavigation.GetHost(), key);
        }

        public string GetFile(string host, object key) {
            string path = GetFilePath(host);
            if (!Directory.Exists(path))
                Directory.CreateDirectory(path);

            NamedTimeStamp timeStamp;
            string cacheKey = string.Format("{0}_{1}_{2}", host, this.GetType(), key.ToString());
            object o = Utils.Cache.Get(cacheKey);
            if (null == o) {
                // get timestamp from DB
                SqlCacheDependency dep;
                timeStamp = GetTimeStamp(host, key.ToString(), out dep);
                if (null == timeStamp) //no file found
                    return null;
                Utils.Cache.Insert(cacheKey, timeStamp, dep);
            } else {
                timeStamp = (NamedTimeStamp)o;
            }

            string localFileSpec = Path.Combine(path, timeStamp.Name);
            if (File.Exists(localFileSpec)) {
                DateTime localFileTimeStamp = File.GetLastWriteTime(localFileSpec);
                if (localFileTimeStamp >= timeStamp.TimeStamp)
                    return localFileSpec;
                else
                    File.Delete(localFileSpec); // delete outdated file
            }

            CreateFile(host, key, localFileSpec);
            return localFileSpec;
        }

        private NamedTimeStamp GetTimeStamp(string host, object key, out SqlCacheDependency dep) {
            NamedTimeStamp timeStamp = null;
            Database db = DBController.CreateDatabase(host);
            DbCommand cmd = db.GetStoredProcCommand(TimeStampProc, key);
            dep = DBController.GetSqlCacheDependency(host, (SqlCommand)cmd);
            using (IDataReader dataReader = db.ExecuteReader(cmd)) {
                if (dataReader.Read())
                    timeStamp = new NamedTimeStamp(dataReader[0].ToString(), (DateTime)dataReader["timeUpdated"]);
            }
            return timeStamp;
        }

        private class NamedTimeStamp {
            public string Name;
            public DateTime TimeStamp;

            public NamedTimeStamp(string name, DateTime timeStamp) {
                this.Name = name;
                this.TimeStamp = timeStamp;
            }
        }
    }
}
