//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Common;
using System.Data.SqlClient;
using System.Web;
using System.Web.Caching;
using Microsoft.Practices.EnterpriseLibrary.Data;

namespace XShan.DotShoppingCart.Common.Object {
    public class DbPage : ILoadFromDataRow {
        private int pageId;
        private string name;
        private bool deletable;
        private List<Paragraph> paragraphs;

        public int PageId {
            get { return pageId; }
        }
        public string Name {
            get { return name; }
        }
        public bool Deletable {
            get { return deletable; }
        }

        public List<Paragraph> Paragraphs {
            get { return paragraphs; }
        }

        public DbPage() {
        }

        public bool LoadFromDataRow(DataRow row) {
            pageId = (int)row["pageId"];
            name = (string)row["name"];
            deletable = (bool)row["deletable"];

            // Paragraph
            if (row.Table.DataSet.Relations.Contains(Constant.DBRelation.PAGE_PARAGRAPH)) {
                paragraphs = new RecordList<Paragraph>(row.GetChildRows(Constant.DBRelation.PAGE_PARAGRAPH));
            } else {
                throw new ApplicationException("Paragraph data is expected when loading Page.");
            }

            return true;
        }

        public static List<DbPage> GetAll(int rowsPerPage, int rowIndex, string sortBy) {
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_Page_GetAll");
            db.AddInParameter(cmd, "@rowsPerPage", DbType.Int32, rowsPerPage);
            db.AddInParameter(cmd, "@rowIndex", DbType.Int32, rowIndex);

            if (!string.IsNullOrEmpty(sortBy)) {
                bool asc = true;
                if (sortBy.EndsWith(" DESC")) {
                    sortBy = sortBy.Substring(0, sortBy.Length - 5);
                    asc = false;
                }
                db.AddInParameter(cmd, "@orderBy", DbType.String, sortBy);
                db.AddInParameter(cmd, "@asc", DbType.Boolean, asc);
            }
            db.AddOutParameter(cmd, "@total", DbType.Int32, sizeof(Int32));

            DataSet ds = db.ExecuteDataSet(cmd);
            int totalNumber = (int)db.GetParameterValue(cmd, "@total");

            SetDBRelations(ds);
            RecordList<DbPage> pages = new RecordList<DbPage>(ds.Tables["Page"]);

            if (null != HttpContext.Current)
                HttpContext.Current.Items[GetAllCountCacheKey()] = totalNumber;

            return pages;
        }

        public static int GetAllCount() {
            int count = 0;
            if ((null != HttpContext.Current) &&
                (null != HttpContext.Current.Items[GetAllCountCacheKey()]))
                count = (int)HttpContext.Current.Items[GetAllCountCacheKey()];
            return count;
        }

        private static string GetAllCountCacheKey() {
            return string.Format("DbPageGetAll_{0}", SiteNavigation.GetHost());
        }
        
        public static DbPage Load(string name) {
            DbPage dbPage = null;
            string cacheKey = string.Format("{0}_DbPage_name_{1}", SiteNavigation.GetHost(), name);
            object o = Utils.Cache.Get(cacheKey);
            if (null == o) {
                Database db = DBController.CreateDatabase();
                DbCommand cmd = db.GetStoredProcCommand("DSC_Page_GetByName", name);
                SqlCacheDependency dep = DBController.GetSqlCacheDependency((SqlCommand)cmd);
                DataSet ds = db.ExecuteDataSet(cmd);
                SetDBRelations(ds);
                List<DbPage> pages = new RecordList<DbPage>(ds.Tables[0]);
                if ((null != pages) && (pages.Count > 0))
                    dbPage = pages[0];
                else
                    return null;
                Utils.Cache.Insert(cacheKey, dbPage, dep);
            } else {
                dbPage = (DbPage)o;
            }

            return dbPage;
        }

        public static int Add(string name) {
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_Page_Add", name);
            return Convert.ToInt32(db.ExecuteScalar(cmd));
        }

        public static void Delete(int pageId) {
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_Page_Delete", pageId);
            db.ExecuteNonQuery(cmd);
        }

        private static void SetDBRelations(DataSet ds) {
            int index = 0;
            ds.Tables[index++].TableName = "Page";
            ds.Tables[index++].TableName = "Paragraph";

            ds.Relations.Add(Constant.DBRelation.PAGE_PARAGRAPH, ds.Tables["Page"].Columns["pageId"],
                ds.Tables["Paragraph"].Columns["pageId"]);
        }

    }
}
