//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Data.Common;
using System.Collections.Generic;
using System.IO;
using System.Web;
using Microsoft.Practices.EnterpriseLibrary.Data;

namespace XShan.DotShoppingCart.Common.Object {
    public delegate void WriteTemplateFile(string fileSpec, string templateContent);

    public class DbTemplate : DbFileBase, ILoadFromDataRow {
        private int templateId;
        private string name;
        private string template;
        private DateTime timeUpdated;

        private string templatePath = "Templates";
        private WriteTemplateFile wtf = WriteTemplateContent;

        public int TemplateId {
            get { return templateId; }
        }
        public string Name {
            get { return name; }
        }
        public string Template {
            get { return template; }
        }
        public DateTime TimeUpdated {
            get { return timeUpdated; }
        }

        protected override string TimeStampProc {
            get { return "DSC_Template_GetTimeStampByName"; }
        }

        protected override string GetFilePath(string host) {
            string path;
            HttpContext ctx = HttpContext.Current;
            if (null == ctx) {
                path = Path.Combine(Path.Combine(Utils.GetTemplatePath(), this.templatePath), host);
            } else {
                path = ctx.Request.PhysicalApplicationPath + Path.Combine(this.templatePath, host);
            }
            return path;
        }

        protected override void CreateFile(string host, object key, string localFileSpec) {
            DbTemplate t = Get(host, (string)key);
            wtf(localFileSpec, t.Template);
        }

        public DbTemplate() {
        }

        public DbTemplate(string templatePath) {
            this.templatePath = templatePath;
        }

        public DbTemplate(string templatePath, WriteTemplateFile wtf) {
            this.templatePath = templatePath;
            this.wtf = wtf;
        }

        public DbTemplate(int templateId, string name, string template, DateTime timeUpdated) {
            this.templateId = templateId;
            this.name = name;
            this.template = template;
            this.timeUpdated = timeUpdated;
        }

        public bool LoadFromDataRow(DataRow row) {
            templateId = (int)row["templateId"];
            name = (string)row["name"];
            template = (string)row["template"];
            timeUpdated = (DateTime)row["timeUpdated"];
            return true;
        }

        public static DbTemplate Get(string name) {
            return Get(SiteNavigation.GetHost(), name);
        }

        public static DbTemplate Get(string host, string name) {
            Database db = DBController.CreateDatabase(host);
            DbCommand cmd = db.GetStoredProcCommand("DSC_Template_GetByName", name);

            DbTemplate t = null;
            using (IDataReader dataReader = db.ExecuteReader(cmd)) {
                dataReader.Read();
                t = new DbTemplate((int)dataReader["templateId"],
                    (string)dataReader["name"],
                    (string)dataReader["template"],
                    (DateTime)dataReader["timeUpdated"]);
            }
            return t;
        }

        private static void WriteTemplateContent(string fileSpec, string templateContent) {
            File.WriteAllText(fileSpec, templateContent);
        }

        public static List<DbTemplate> GetAll() {
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_Template_GetAll");
            DataSet ds = db.ExecuteDataSet(cmd);
            return new RecordList<DbTemplate>(ds.Tables[0]);
        }

        public static int Add(string name, string template) {
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_Template_Add", name, template);
            return Convert.ToInt32(db.ExecuteScalar(cmd));
        }

        public static void Update(string name, string template) {
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_Template_Update", name, template);
            db.ExecuteNonQuery(cmd);
        }

        public static void Delete(string name) {
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_Template_Delete", name);
            db.ExecuteNonQuery(cmd);
        }
    }
}
