//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Data.Common;
using Microsoft.Practices.EnterpriseLibrary.Data;

namespace XShan.DotShoppingCart.Common.Object {
    public class Manufacturer : ILoadFromDataRow {
        private int manufacturerId;
        private string name, url;
        private int? imageId;

        public int ManufacturerId {
            get { return manufacturerId; }
        }
        public string Name {
            get { return name; }
        }
        public string Url {
            get { return url; }
        }
        public int? ImageId {
            get { return imageId; }
        }

        public Manufacturer() {
        }

        public bool LoadFromDataRow(DataRow row) {
            manufacturerId = (int)row["manufacturerId"];
            name = (string)row["name"];
            imageId = DBHelper.ToNullableInt(row["imageId"]);
            url = row["url"] as string;
            return true;
        }

        public static Manufacturer[] GetAll() {
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_Manufacturer_GetAll");
            DataSet ds = db.ExecuteDataSet(cmd);

            RecordList<Manufacturer> manufacturers = new RecordList<Manufacturer>(ds.Tables[0]);
            return manufacturers.ToArray();
        }

        public static Manufacturer Get(int manufacturerId) {
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_Manufacturer_Get", manufacturerId);
            DataSet ds = db.ExecuteDataSet(cmd);
            RecordList<Manufacturer> manufacturers = new RecordList<Manufacturer>(ds.Tables[0]);
            if ((null != manufacturers) && (manufacturers.Count > 0))
                return manufacturers[0];
            return null;
        }

        public static int Add(string name, int? imageId, string url) {
            return Add(SiteNavigation.GetHost(), name, imageId, url);
        }

        public static int Add(string host, string name, int? imageId, string url) {
            Database db = DBController.CreateDatabase(host);
            DbCommand cmd = db.GetStoredProcCommand("DSC_Manufacturer_Add", name, imageId, url);
            object output = db.ExecuteScalar(cmd);
            return int.Parse(output.ToString());
        }

        public static void Update(int manufacturerId, string name, int? imageId, string url) {
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_Manufacturer_Update", manufacturerId, name, imageId, url);
            db.ExecuteNonQuery(cmd);
        }

        public static void Delete(int manufacturerId) {
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_Manufacturer_Delete", manufacturerId);
            db.ExecuteNonQuery(cmd);
        }

    }
}
