//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Collections.Generic;
using System.Data.Common;
using System.Web;
using Microsoft.Practices.EnterpriseLibrary.Data;

namespace XShan.DotShoppingCart.Common.Object {
    public class OrderItem : ILoadFromDataRow {
        #region Member Variables
        private int orderItemId, productId, quantity, productTypeId;
        private int? imageId, userId = null;
        private string sku, productName, shipEstimate, customField, attributesString, attributeValueIds;
        private decimal price, originalPrice;
        private List<KeyValuePair<string, string>> attributes = null;
        private ShipTracking shipTracking;
        #endregion

        #region Properties
        public int OrderItemId {
            get { return orderItemId; }
        }
        public int ProductId {
            get { return productId; }
        }
        public int? ImageId {
            get { return imageId; }
        }
        public int Quantity {
            get { return quantity; }
        }
        public string SKU {
            get { return sku; }
        }
        public string ProductName {
            get { return productName; }
        }
        public ProductTypeEnum ProductType {
            get { return (ProductTypeEnum)productTypeId; }
        }
        public List<KeyValuePair<string, string>> Attributes {
            get { return attributes; }
        }
        public string AttributesString {
            get { return attributesString; }
        }
        public string AttributeValueIds {
            get { return attributeValueIds; }
        }
        public ShipTracking ShipTracking {
            get { return shipTracking; }
        }
        public string ShipEstimate {
            get { return shipEstimate; }
        }
        public decimal Price {
            get { return price; }
        }
        public decimal OriginalPrice {
            get { return originalPrice; }
        }
        public decimal TotalPrice {
            get { return price * quantity; }
        }
        public string CustomField {
            get { return customField; }
        }
        public int? UserId {
            get { return userId; }
        }
        #endregion
        
        #region Constructors
        public OrderItem() {
        }

        public OrderItem(int orderItemId, int productId, string attributesString, string attributeValueIds, int? imageId, string sku, string productName,
            decimal price, int quantity) {
            this.orderItemId = orderItemId;
            this.productId = productId;
            this.attributesString = attributesString;
            this.attributeValueIds = attributeValueIds;
            this.attributes = GetAttributesFromString(attributesString);
            this.price = price;
            this.quantity = quantity;
            this.imageId = imageId;
            this.sku = sku;
            this.productName = productName;
        }

        public virtual bool LoadFromDataRow(DataRow row) {
            orderItemId = (int)row["orderItemId"];
            productId = (int)row["productId"];
            imageId = DBHelper.ToNullableInt(row["imageId"]);
            quantity = (int)row["quantity"];
            sku = (string)row["sku"];
            productName = (string)row["productName"];
            productTypeId = (int)row["productTypeId"];
            shipEstimate = row["shipEstimate"] as string;
            price = (decimal)row["price"];
            originalPrice = (decimal)row["originalPrice"];
            customField = row["customField"] as string;
            if (row.Table.Columns.Contains("userId"))
                userId = (int)row["userId"];

            attributesString = row["attributes"] as string;
            attributes = GetAttributesFromString(attributesString);

            if (row.Table.DataSet.Relations.Contains(Constant.DBRelation.ORDERITEM_SHIPTRACKING)) {
                RecordList<ShipTracking> shipTrackings = new RecordList<ShipTracking>(row.GetParentRows(Constant.DBRelation.ORDERITEM_SHIPTRACKING));
                if ((null == shipTrackings) || (0 == shipTrackings.Count))
                    shipTracking = null;
                else
                    shipTracking = shipTrackings[0];
            } 
            
            return true;
        }
        #endregion

        #region Public Method
        public void UpdateCustomerField(string host, string value) {
            Database db = DBController.CreateDatabase(host);
            DbCommand cmd = db.GetStoredProcCommand("DSC_Order_Item_UpdateCustomField", this.orderItemId, value);
            db.ExecuteNonQuery(cmd);
        }
        #endregion

        #region Public Static Method
        public static List<KeyValuePair<string, string>> GetAttributesFromString(string attributesString) {
            List<KeyValuePair<string, string>> attributes = null;
            if (!string.IsNullOrEmpty(attributesString)) {
                attributes = new List<KeyValuePair<string, string>>();
                foreach (string attributePair in attributesString.Split(Constant.DB.ListSeparator)) {
                    string[] pair = attributePair.Split(':');
                    if (2 == pair.Length)
                        attributes.Add(new KeyValuePair<string, string>(pair[0], pair[1]));
                }
            }
            return attributes;
        }

        public static void Update(int orderItemId, decimal price, int quantity) {
            //
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_Order_Item_Update", orderItemId, price, quantity);
            db.ExecuteNonQuery(cmd);
        }

        public static void Delete(int orderItemId) {
            // Need to deal with quantity
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_Order_Item_Delete", orderItemId, 0);
            db.ExecuteNonQuery(cmd);
        }

        public static void Restock(int orderItemId) {
            // Need to deal with quantity
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_Order_Item_Delete", orderItemId, 1);
            db.ExecuteNonQuery(cmd);
        }

        public static void Add(int orderId, int productId, string attributeValueIds, decimal price, int quantity, string customField) {
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_Order_Item_Add", orderId, productId, attributeValueIds, price, quantity, customField);
            db.ExecuteNonQuery(cmd);
        }

        #endregion
        #region Private Method
        private static string GetRecurringOrderItemCountCacheKey(string userName) {
            return string.Format("RecurringOrderItemCount_{0}_{1}", SiteNavigation.GetHost(), userName);
        }
        #endregion
    }

}
