//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Common;
using System.Data.SqlClient;
using System.Web.Caching;
using Microsoft.Practices.EnterpriseLibrary.Data;
using XShan.DotShoppingCart.Common.Configuration;
using Microsoft.Practices.EnterpriseLibrary.Common.Configuration;

namespace XShan.DotShoppingCart.Common.Object {
    public class OrderPipelineProcessor : ILoadFromDataRow {
        private int orderPipelineProcessorId, orderStatusIdSource;
        private string name, displayName;
        private bool isDownloadBypass, isWebDriven;

        public int OrderPipelineProcessorId {
            get { return orderPipelineProcessorId; }
        }
        public string Name {
            get { return name; }
        }
        public int OrderStatusIdSource {
            get { return orderStatusIdSource; }
        }
        public bool IsDownloadBypass {
            get { return isDownloadBypass; }
        }
        public bool IsWebDriven {
            get { return isWebDriven; }
        }
        public string DisplayName {
            get { return displayName; }
        }

        public OrderPipelineProcessor() {
        }

        public bool LoadFromDataRow(DataRow row) {
            orderPipelineProcessorId = (int)row["orderPipelineProcessorId"];
            name = (string)row["name"];
            orderStatusIdSource = (int)row["orderStatusIdSource"];
            isDownloadBypass = (bool)row["isDownloadBypass"];
            isWebDriven = (bool)row["isWebDriven"];
            displayName = row["displayName"] as string;
            return true;
        }

        public static Dictionary<string, OrderPipelineProcessor> GetAll() {
            return GetAll(SiteNavigation.GetHost());
        }

        public static Dictionary<string, OrderPipelineProcessor> GetAll(string host) {
            Dictionary<string, OrderPipelineProcessor> processors = null;
            string cacheKey = string.Format("OrderPipelineProcessor_GetAll_{0}", host);
            object o = Utils.Cache.Get(cacheKey);
            if (null == o) {
                Database db = DBController.CreateDatabase(host);
                DbCommand cmd = db.GetStoredProcCommand("DSC_OrderPipeline_Processor_GetAll");
                SqlCacheDependency dep = DBController.GetSqlCacheDependency(host, (SqlCommand)cmd);
                DataSet ds = db.ExecuteDataSet(cmd);

                processors = new Dictionary<string, OrderPipelineProcessor>();
                foreach (OrderPipelineProcessor processor in new RecordList<OrderPipelineProcessor>(ds.Tables[0])) {
                    processors.Add(processor.Name, processor);
                }

                Utils.Cache.Insert(cacheKey, processors, dep);
            } else {
                processors = (Dictionary<string, OrderPipelineProcessor>)o;
            }
            return processors;
        }

        public static List<OrderPipelineProcessor> GetConfiguredProcessors(string orderPipeline) {
            return GetConfiguredProcessors(SiteNavigation.GetHost(), orderPipeline);
        }

        public static List<OrderPipelineProcessor> GetConfiguredProcessors(string host, string orderPipeline) {
            List<OrderPipelineProcessor> configured = new List<OrderPipelineProcessor>();
            Dictionary<string, OrderPipelineProcessor> allProcessors = GetAll(host);
            OrderPipelineConfigurationSection orderPipelineSection = 
                (OrderPipelineConfigurationSection)SqlConfigurationController.GetSection(host, OrderPipelineConfigurationSection.SectionName);
            foreach (OrderPipelineConfigurationElement pipelineConfiguraton in orderPipelineSection.ProcessorConfigurations) {
                if (orderPipeline.Equals(pipelineConfiguraton.Name, StringComparison.OrdinalIgnoreCase)) {
                    NamedElementCollection<NamedConfigurationElement> configuredProcessors = pipelineConfiguraton.Processors;
                    for (int i = 0; i < configuredProcessors.Count; i++) {
                        NamedConfigurationElement elm = configuredProcessors.Get(i);
                        string processorName = elm.Name;
                        configured.Add(allProcessors[processorName]);
                    }

                    return configured;
                }
            }
            return configured;
        }

        public static List<OrderPipelineProcessor> GetAllConfiguredProcessors(string host) {
            List<OrderPipelineProcessor> processors = new List<OrderPipelineProcessor>();
            Dictionary<int, bool> inListProcessorIds = new Dictionary<int, bool>();
            foreach (string orderPipeline in Utils.GetAllOrderPipelines())
                foreach (OrderPipelineProcessor processor in GetConfiguredProcessors(host, orderPipeline)) {
                    if (!inListProcessorIds.ContainsKey(processor.OrderPipelineProcessorId)) {
                        processors.Add(processor);
                        inListProcessorIds.Add(processor.OrderPipelineProcessorId, true);
                    }
                }

            return processors;
        }
    }
}
