//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Common;
using Microsoft.Practices.EnterpriseLibrary.Data;


namespace XShan.DotShoppingCart.Common.Object {
    [Serializable]
    public class OrderStatus : ILoadFromDataRow {
        public const int OrderUnderReviewStatus = 99;

        private int statusId;
        private string status;

        public int StatusId {
            get { return statusId; }
        }
        public string Status {
            get { return status; }
        }

        public OrderStatus() {
        }

        public bool LoadFromDataRow(DataRow row) {
            statusId = (int)row["orderStatusId"];
            status = (string)row["status"];
            return true;
        }

        public bool IsCompleted {
            get { return statusId == 7; }
        }

        public static Dictionary<int, OrderStatus> GetAll() {
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_OrderStatus_GetAll");
            DataSet ds = db.ExecuteDataSet(cmd);

            Dictionary<int, OrderStatus> allStatus = new Dictionary<int, OrderStatus>();
            foreach (OrderStatus status in new RecordList<OrderStatus>(ds.Tables[0])) {
                allStatus.Add(status.StatusId, status);
            }
            return allStatus;
        }
        
        public static List<OrderStatus> GetAllAvailableOrderStatus() {
            List<OrderStatus> allStatus = new List<OrderStatus>();
            Dictionary<int, bool> inListStatusIds = new Dictionary<int, bool>();
            foreach (string orderPipeline in Utils.GetAllOrderPipelines()) {
                foreach (OrderStatus os in GetAvailableOrderStatus(orderPipeline)) {
                    if (!inListStatusIds.ContainsKey(os.StatusId)) {
                        allStatus.Add(os);
                        inListStatusIds.Add(os.StatusId, true);
                    }
                }
            }
            return allStatus;
        }

        public static List<OrderStatus> GetAvailableOrderStatus(string orderPipeline) {
            List<int> inUseStatusIds = new List<int>();
            foreach (OrderPipelineProcessor processor in OrderPipelineProcessor.GetConfiguredProcessors(orderPipeline)) {
                inUseStatusIds.Add(processor.OrderStatusIdSource);
            }
            //Need to add non dynamic status ids
            inUseStatusIds.Add(Constant.DB.OrderStatusCompleteId);
            inUseStatusIds.Add(Constant.DB.OrderStatusCanceledId);
            inUseStatusIds.Add(Constant.DB.OrderStatusUnderReview);

            Dictionary<int, OrderStatus> allStatus = OrderStatus.GetAll();
            List<OrderStatus> inUseStatus = new List<OrderStatus>();
            foreach (int statusId in inUseStatusIds) {
                inUseStatus.Add(allStatus[statusId]);
            }
            return inUseStatus;
        }

    }
}
