//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Collections.Generic;
using System.Data.Common;
using Microsoft.Practices.EnterpriseLibrary.Data;

namespace XShan.DotShoppingCart.Common.Object {
    [Serializable]
    public class OrderTotal : ILoadFromDataRow {
        #region Member Variables
        private int orderTotalId, sortOrder;
        private decimal amount;
        private string name, note;
        #endregion

        #region Properties
        public int OrderTotalId {
            get { return orderTotalId; }
        }
        public int SortOrder {
            get { return sortOrder; }
        }
        public decimal Amount {
            get { return amount; }
            set { amount = value; }
        }
        public string Name {
            get { return name; }
        }
        public string Note {
            get { return note; }
            set { note = value; }
        }

        #endregion
        
        #region Constructors
        public OrderTotal() {
        }

        public OrderTotal(string name, decimal amount)
            : this(name, amount, null) {
        }

        public OrderTotal(string name, decimal amount, string note)
            : this(name, amount, note, 0) {
        }

        public OrderTotal(string name, decimal amount, string note, int sortOrder) 
            : this(0, name, amount, note, sortOrder) {
        }

        public OrderTotal(int orderTotalId, string name, decimal amount, string note, int sortOrder) {
            this.orderTotalId = orderTotalId;
            this.name = name;
            this.amount = amount;
            this.note = note;
            this.sortOrder = sortOrder;
        }

        public bool LoadFromDataRow(DataRow row) {
            orderTotalId = (int)row["orderTotalId"];
            amount = (decimal)row["amount"];
            name = (string)row["name"];
            note = row["note"] as string;
            sortOrder = (int)row["sortOrder"];

            return true;
        }
        #endregion

        public bool Equal(OrderTotal ot) {
            return (this.name == ot.Name) &&
                (this.note == ot.Note) &&
                (this.amount == ot.Amount);
        }

        public static void Update(int orderTotalId, string name, decimal amount, string note, int sortOrder) {
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_Order_Total_Update", orderTotalId, name, amount, note, sortOrder);
            db.ExecuteNonQuery(cmd);
        }

        public static void Delete(int orderTotalId) {
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_Order_Total_Delete", orderTotalId);
            db.ExecuteNonQuery(cmd);
        }

        public static int Add(int orderId, string name, decimal amount, string note, int sortOrder) {
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_Order_Total_Add", orderId, name, amount, note, sortOrder);
            object output = db.ExecuteScalar(cmd);
            return Convert.ToInt32(output);
        }

    }
}
