//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Common;
using System.Data.SqlClient;
using System.Web;
using System.Web.Caching;
using Microsoft.Practices.EnterpriseLibrary.Data;
using XShan.DotShoppingCart.Common;

namespace XShan.DotShoppingCart.Common.Object {
    public class Paragraph : ILoadFromDataRow {
        private int paragraphId, sortOrder;
        private string name, conditions, text;

        public int ParagraphId {
            get { return paragraphId; }
        }
        public int SortOrder {
            get { return sortOrder; }
        }
        public string Name {
            get { return name; }
        }
        public string Conditions {
            get { return conditions; }
        }
        public string Text {
            get { return text; }
        }
        public string ResolvedText {
            get { return CheckCondition() ? ReplaceTokens(SiteNavigation.ResolveUrlInText(text)) : null; }
        }

        private bool CheckCondition() {
            // Todo: standardize conditions
            // currently it supports discountgroup=True discountgroup=False and 
            // https=True https=False
            // both condition can seperated by ,
            if (!string.IsNullOrEmpty(conditions)) {
                foreach (string condition in conditions.Split(Constant.DB.ListSeparator)) {
                    string[] parts = condition.Split('=');
                    if (2 == parts.Length) { //ignore bad condition format
                        switch (parts[0].ToLower()) {
                            case "discountgroup":
                                if (WebUtils.IsDiscountGroup() != GetBoolean(parts[1]))
                                    return false;
                                break;
                            case "https":
                                bool secureConnection = false;
                                if (null != HttpContext.Current)
                                    secureConnection = HttpContext.Current.Request.IsSecureConnection;
                                if (secureConnection != GetBoolean(parts[1]))
                                    return false;
                                break;
                        }
                    }
                }
            }
            return true;
        }

        private string ReplaceTokens(string text) {
            Dictionary<string, string> tokens = new Dictionary<string, string>();
            tokens.Add("%HTTP_SSL%", HttpContext.Current.Request.IsSecureConnection ? "https://ssl" : "http://www");

            foreach (string key in tokens.Keys) {
                text = text.Replace(key, tokens[key]);
            }
            return text;
        }

        private bool GetBoolean(string value) {
            bool b = true;
            bool.TryParse(value, out b);
            return b;
        }

        
        public Paragraph() {
        }

        public bool LoadFromDataRow(DataRow row) {
            paragraphId = (int)row["paragraphId"];
            name = row["name"] as string;
            conditions = row["conditions"] as string;
            text = (string)row["text"];
            sortOrder = (int)row["sortOrder"];
            return true;
        }

        public static Paragraph Load(int paragraphId) {
            Paragraph paragraph = null;
            string cacheKey = string.Format("{0}_Paragraph_id_{1}", SiteNavigation.GetHost(), paragraphId);
            object o = Utils.Cache.Get(cacheKey);
            if (null == o) {
                Database db = DBController.CreateDatabase();
                DbCommand cmd = db.GetStoredProcCommand("DSC_Paragraph_Get", paragraphId);
                SqlCacheDependency dep = DBController.GetSqlCacheDependency((SqlCommand)cmd);
                DataSet ds = db.ExecuteDataSet(cmd);
                RecordList<Paragraph> paragraphs = new RecordList<Paragraph>(ds.Tables[0]);
                if ((null == paragraphs) || (paragraphs.Count == 0))
                    return null;
                else
                    paragraph = paragraphs[0];
                Utils.Cache.Insert(cacheKey, paragraph, dep);
            } else {
                paragraph = (Paragraph)o;
            }
            return paragraph;
        }

        public static Paragraph Load(string name) {
            Paragraph paragraph = null;
            string cacheKey = string.Format("{0}_Paragraph_name_{1}", SiteNavigation.GetHost(), name);
            object o = Utils.Cache.Get(cacheKey);
            if (null == o) {
                Database db = DBController.CreateDatabase();
                DbCommand cmd = db.GetStoredProcCommand("DSC_Paragraph_GetByName", name);
                SqlCacheDependency dep = DBController.GetSqlCacheDependency((SqlCommand)cmd);
                DataSet ds = db.ExecuteDataSet(cmd);
                RecordList<Paragraph> paragraphs = new RecordList<Paragraph>(ds.Tables[0]);
                if ((null == paragraphs) || (paragraphs.Count == 0))
                    return null;
                else
                    paragraph = paragraphs[0];
                Utils.Cache.Insert(cacheKey, paragraph, dep);
            } else {
                paragraph = (Paragraph)o;
            }
            return paragraph;
        }

        public static int Add(string pageName, string content) {
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_Paragraph_Add", pageName, content);
            return Convert.ToInt32(db.ExecuteScalar(cmd));
        }

        public static void Update(int paragraphId, string content, int sortOrder) {
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_Paragraph_Update", paragraphId, content, sortOrder);
            db.ExecuteNonQuery(cmd);
        }

        public static void Update(string name, string content) {
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_Paragraph_UpdateByName", name, content);
            db.ExecuteNonQuery(cmd);
        }

        public static void Delete(int paragraphId) {
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_Paragraph_Delete", paragraphId);
            db.ExecuteNonQuery(cmd);
        }

    }
}
