//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Data.Common;
using System.Collections.Generic;
using Microsoft.Practices.EnterpriseLibrary.Data;

namespace XShan.DotShoppingCart.Common.Object {
    public enum PaymentGatewayType {
        Paypal_DirectPay = 1, // need to keep this sync with DSC_PaymentGateway_Type_lkp
        Paypal_Express_Checkout = 2,
        CyberSource = 3,
        AuthorizeNet = 4,
        Check_OR_Money_Order = 5,
        Google_Checkout = 6,
        Paypal_Standard = 7,
    }
    public enum PaymentTransactionType {
        Authorize = 1, // need to keep this sync with DSC_PaymentTransaction_Type_lkp
        Sale = 2,
        Capture = 3,
        Refund = 4,
        Void = 5
    }

    public class PaymentTransaction : ILoadFromDataRow {
        #region Member Variables
        private int transactionId;
        private PaymentGatewayType paymentGatewayType;
        private PaymentTransactionType transactionType;
        private string authorizationCode, response, avs, cvv, error, debug;
        private decimal amount;
        private DateTime transactionDate = DateTime.Now;
        private bool success;
        #endregion

        #region Properties
        public int TransactionId {
            get { return transactionId; }
        }
        public PaymentGatewayType PaymentGatewayType {
            get { return paymentGatewayType; }
            set { paymentGatewayType = value; }
        }
        public PaymentTransactionType PaymentTransactionType {
            get { return transactionType; }
            set { transactionType = value; }
        }
        public decimal Amount {
            get { return amount; }
            set { amount = value; }
        }
        public string AuthorizationCode {
            get { return authorizationCode; }
            set { authorizationCode = value; }
        }
        public string Response {
            get { return response; }
            set { response = value; }
        }
        public string AVS {
            get { return avs; }
            set { avs = value; }
        }
        public string CVV {
            get { return cvv; }
            set { cvv = value; }
        }
        public string Error {
            get { return error; }
            set { error = value; }
        }
        public string Debug {
            get { return debug; }
            set { debug = value; }
        }
        public DateTime TransactionDate {
            get { return transactionDate; }
            set { transactionDate = value; }
        }
        public bool Success {
            get { return success; }
            set { success = value; }
        }

        #endregion

        #region Constructors
        public PaymentTransaction() {
        }

        public bool LoadFromDataRow(DataRow row) {
            transactionId = (int)row["transactionId"];
            paymentGatewayType = (PaymentGatewayType)row["paymentGatewayTypeId"];
            transactionType = (PaymentTransactionType)row["paymentTransactionTypeId"];
            transactionDate = (DateTime)row["transactionDate"];
            amount = (Decimal)row["amount"];
            response = row["response"] as string;
            authorizationCode = row["authorizationCode"] as string;
            avs = row["avs"] as string;
            cvv = row["cvv"] as string;
            error = row["error"] as string;
            debug = row["debug"] as string;
            success = (bool)row["success"];

            return true;
        }

        public int Add(string orderNumber) {
            return Add(SiteNavigation.GetHost(), orderNumber);
        }

        public int Add(string host, string orderNumber) {
            Database db = DBController.CreateDatabase(host);
            DbCommand cmd = db.GetStoredProcCommand("DSC_PaymentTransaction_Add", orderNumber, (int)paymentGatewayType, (int)transactionType, transactionDate,
                amount, response, authorizationCode, avs, cvv, success, error, debug);
            object output = db.ExecuteScalar(cmd);
            return int.Parse(output.ToString());
        }

        #endregion
    }
}
