//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Common;
using Microsoft.Practices.EnterpriseLibrary.Data;

namespace XShan.DotShoppingCart.Common.Object {
    [Serializable]
    public class ProductAttribute : ILoadFromDataRow {
        private int productAttributeId;
        private DSCAttribute attribute;
        private List<ProductAttributeValue> values;

        public int ProductAttributeId {
            get { return productAttributeId; }
        }
        public DSCAttribute Attribute {
            get { return attribute; }
            set { attribute = value; }
        }
        public List<ProductAttributeValue> Values {
            get { return values; }
            set { values = value; }
        }

        public ProductAttribute() {
        }

        public ProductAttribute(DSCAttribute attribute, List<ProductAttributeValue> values) {
            this.attribute = attribute;
            this.values = values;
        }

        public bool LoadFromDataRow(DataRow row) {
            productAttributeId = (int)row["productAttributeId"];

            // Attribute
            if (row.Table.DataSet.Relations.Contains(Constant.DBRelation.PRODUCTATTRIBUTE_ATTRIBUTE)) {
                attribute = new RecordList<DSCAttribute>(row.GetParentRows(Constant.DBRelation.PRODUCTATTRIBUTE_ATTRIBUTE))[0];
            } else {
                throw new ApplicationException("Attribute data is expected when loading ProductAttribute.");
            }
            
            // ProductAttributeValue
            if (row.Table.DataSet.Relations.Contains(Constant.DBRelation.PRODUCT_ATTRIBUTEVALUE)) {
                values = new RecordList<ProductAttributeValue>(row.GetChildRows(Constant.DBRelation.PRODUCT_ATTRIBUTEVALUE));
            } else {
                throw new ApplicationException("ProductAttributeValue data is expected when loading ProductAttribute.");
            }

            return true;
        }

        public List<ProductAttributeValue> GetAvailableValues(bool showOutofStock) {
            List<ProductAttributeValue> availableValues = new List<ProductAttributeValue>();
            foreach (ProductAttributeValue value in values) {
                if (showOutofStock || (null == value.Quantity) || ((int)value.Quantity > 0)) {
                    availableValues.Add(value);
                }
            }
            return availableValues;
        }
    }
}
