//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Data.Common;
using System.Web;
using System.Collections.Generic;
using Microsoft.Practices.EnterpriseLibrary.Data;

namespace XShan.DotShoppingCart.Common.Object {
    public class ProductReview : ILoadFromDataRow {
        #region Member Variables
        private int productReviewId, productReviewStatusId, userId, rating;
        private string nickname, title, comments;
        private DateTime created;
        private Product product;
        #endregion

        #region Properties
        public int ProductReviewId {
            get { return productReviewId; }
        }
        public int ProductReviewStatusId {
            get { return productReviewStatusId; }
        }
        public int UserId {
            get { return userId; }
        }
        public string Nickname {
            get { return nickname; }
        }
        public string Title {
            get { return title; }
        }
        public string Comments {
            get { return comments; }
        }
        public int Rating {
            get { return rating; }
        }
        public DateTime Created {
            get { return created; }
        }
        public Product Product {
            get { return product; }
        }

        #endregion
        
        #region Constructors
        public ProductReview() {
        }

        public bool LoadFromDataRow(DataRow row) {
            productReviewId = (int)row["productReviewId"];
            productReviewStatusId = (int)row["productReviewStatusId"];
            userId = (int)row["userId"];
            rating = (int)row["rating"];
            nickname = row["nickname"] as string;
            title = row["title"] as string;
            comments = (string)row["comments"];
            created = (DateTime)row["created"];

            // ProductImage
            // ProductAttribute
            if (row.Table.DataSet.Relations.Contains(Constant.DBRelation.PRODUCTREVIEW_PRODUCT)) {
                product = new RecordList<Product>(row.GetParentRows(Constant.DBRelation.PRODUCTREVIEW_PRODUCT))[0];
            }

            return true;
        }
        #endregion

        public static List<ProductReview> GetByProductId(int productId) {
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_Product_Review_Get", productId);
            DataSet ds = db.ExecuteDataSet(cmd);

            SetProductTableRelations(ds);

            return new RecordList<ProductReview>(ds.Tables["ProductReview"]);
        }

        public static ProductReview GetByCategoryPath(string categoryPath, bool? showOutofStock) {
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_Product_Review_GetByCategory", categoryPath, showOutofStock);
            DataSet ds = db.ExecuteDataSet(cmd);

            SetProductTableRelations(ds);

            List<ProductReview> reviews = new RecordList<ProductReview>(ds.Tables["ProductReview"]);
            if ((null != reviews) && (reviews.Count > 0))
                return reviews[0];

            return null;
        }

        public static void Add(string username, int productId, string title, int rating, string comments, 
            string nickname, DateTime created) {
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_Product_Review_Add", username, productId, title, 
                rating, comments, nickname, created);
            db.ExecuteNonQuery(cmd);
        }
        
        public static void Update(int productReviewId, int productReviewStatusId) {
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_Product_Review_UpdateStatus", productReviewId,
                productReviewStatusId);
            db.ExecuteNonQuery(cmd);
        }

        public static void Update(int productReviewId, int productReviewStatusId, string title, int rating, 
            string comments, string nickname) {
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_Product_Review_Update", productReviewId,
                productReviewStatusId, title, rating, comments, nickname);
            db.ExecuteNonQuery(cmd);
        }

        public static void Delete(int productReviewId) {
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_Product_Review_Delete", productReviewId);
            db.ExecuteNonQuery(cmd);
        }

        public static List<ProductReview> GetAll(int productReviewStatusId, int rowsPerPage, int rowIndex, string sortBy,
            bool? showOutofStock) {
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_Product_Review_GetAll");
            db.AddInParameter(cmd, "@productReviewStatusId", DbType.Int32, productReviewStatusId);
            db.AddInParameter(cmd, "@rowsPerPage", DbType.Int32, rowsPerPage);
            db.AddInParameter(cmd, "@rowIndex", DbType.Int32, rowIndex);
            db.AddInParameter(cmd, "@showOutofStock", DbType.Boolean, showOutofStock);

            if (!string.IsNullOrEmpty(sortBy)) {
                bool asc = true;
                if (sortBy.EndsWith(" DESC")) {
                    sortBy = sortBy.Substring(0, sortBy.Length - 5);
                    asc = false;
                }
                db.AddInParameter(cmd, "@orderBy", DbType.String, sortBy);
                db.AddInParameter(cmd, "@asc", DbType.Boolean, asc);
            }
            db.AddOutParameter(cmd, "@total", DbType.Int32, sizeof(Int32));

            DataSet ds = db.ExecuteDataSet(cmd);
            int totalNumber = (int)db.GetParameterValue(cmd, "@total");

            SetProductTableRelations(ds);

            RecordList<ProductReview> reviews = new RecordList<ProductReview>(ds.Tables["ProductReview"]);

            if (null != HttpContext.Current)
                HttpContext.Current.Items[GetAllCountCacheKey(productReviewStatusId, showOutofStock)] = totalNumber;

            return reviews;
        }

        public static int GetAllCount(int productReviewStatusId, bool? showOutofStock) {
            int count = 0;
            if ((null != HttpContext.Current) &&
                (null != HttpContext.Current.Items[GetAllCountCacheKey(productReviewStatusId, showOutofStock)]))
                count = (int)HttpContext.Current.Items[GetAllCountCacheKey(productReviewStatusId, showOutofStock)];
            return count;
        }

        private static string GetAllCountCacheKey(int productReviewStatusId, bool? showOutofStock) {
            return string.Format("ReviewGetAll_{0}_{1}_{2}", SiteNavigation.GetHost(), productReviewStatusId, showOutofStock);
        }

        private static void SetProductTableRelations(DataSet ds) {
            int i = 0;
            ds.Tables[i++].TableName = "ProductReview";

            if (ds.Tables.Count > i) {
                Product.SetProductTableRelations(ds, i);
                ds.Relations.Add(Constant.DBRelation.PRODUCTREVIEW_PRODUCT, ds.Tables["Product"].Columns["productId"], ds.Tables["ProductReview"].Columns["productId"]);
            }
        }
    }
}
