//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Data.Common;
using Microsoft.Practices.EnterpriseLibrary.Data;

namespace XShan.DotShoppingCart.Common.Object {
    public class ShipEstimate : ILoadFromDataRow {
        private int shipEstimateId;
        private int? leadTimeDays;
        private string estimate;

        public int ShipEstimateId {
            get { return shipEstimateId; }
        }
        public string Estimate {
            get { return estimate; }
        }
        public int? LeadTimeDays {
            get { return leadTimeDays; }
        }

        public ShipEstimate() {
        }

        public bool LoadFromDataRow(DataRow row) {
            shipEstimateId = (int)row["shipEstimateId"];
            estimate = (string)row["estimate"];
            leadTimeDays = DBHelper.ToNullableInt(row["leadTimeDays"]);
            return true;
        }

        public static ShipEstimate[] GetAll() {
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_ShipEstimate_GetAll");
            DataSet ds = db.ExecuteDataSet(cmd);

            RecordList<ShipEstimate> shipEstimates = new RecordList<ShipEstimate>(ds.Tables[0]);
            return shipEstimates.ToArray();
        }

        public static int Add(string estimate, int? leadTimeDays) {
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_ShipEstimate_Add", estimate, leadTimeDays);
            object output = db.ExecuteScalar(cmd);
            return int.Parse(output.ToString());
        }

        public static void Update(int estimateId, string estimate, int? leadTimeDays) {
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_ShipEstimate_Update", estimateId, estimate, leadTimeDays);
            db.ExecuteNonQuery(cmd);
        }

        public static void Delete(int estimateId) {
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_ShipEstimate_Delete", estimateId);
            db.ExecuteNonQuery(cmd);
        }
    }
}
