//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Common;
using Microsoft.Practices.EnterpriseLibrary.Data;

namespace XShan.DotShoppingCart.Common.Object {
    public class ShipTracking : ILoadFromDataRow {
        private int shipTrackingId, carrierId;
        private string trackingNumber;
        private DateTime shipDate;
        private ShipCarrier carrier;

        public int ShipTrackingId {
            get { return shipTrackingId; }
        }
        public int CarrierId {
            get { return carrierId; }
        }
        public string TrackingNumber {
            get { return trackingNumber; }
        }
        public DateTime ShipDate {
            get { return shipDate; }
        }
        public ShipCarrier Carrier {
            get { return carrier; }
        }
        public string TrackingUrl {
            get { return string.Format(carrier.TrackingUrlFormat, trackingNumber); }
        }

        public ShipTracking() {
        }

        public bool LoadFromDataRow(DataRow row) {
            shipTrackingId = (int)row["shipTrackingId"];
            carrierId = (int)row["carrierId"];
            trackingNumber = (string)row["trackingNumber"];
            shipDate = (DateTime)row["shipDate"];

            if (row.Table.DataSet.Relations.Contains(Constant.DBRelation.SHIPTRACKING_SHIPCARRIER)) {
                carrier = new RecordList<ShipCarrier>(row.GetParentRows(Constant.DBRelation.SHIPTRACKING_SHIPCARRIER))[0];
            } else {
                throw new ApplicationException("Ship Carrier data is expected when loading ShipTracking.");
            }

            return true;
        }

        public static void Delete(int shipTrackingId) {
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_ShipTracking_Delete", shipTrackingId);
            db.ExecuteNonQuery(cmd);
        }

        public static void Add(int carrierId, string trackingNumber, DateTime shipDate, List<int> orderItemids) {
            if (orderItemids.Count > 0) {
                Database db = DBController.CreateDatabase();
                DbCommand cmd = db.GetStoredProcCommand("DSC_ShipTracking_Add", carrierId, trackingNumber, shipDate,
                    Utils.ConvertIdsToSting(orderItemids));
                db.ExecuteNonQuery(cmd);
            }
        }

        public static void Update(int shipTrackingId, int carrierId, string trackingNumber, DateTime shipDate, List<int> orderItemids) {
            if (orderItemids.Count > 0) {
                Database db = DBController.CreateDatabase();
                DbCommand cmd = db.GetStoredProcCommand("DSC_ShipTracking_Update", shipTrackingId, carrierId, trackingNumber, shipDate,
                    Utils.ConvertIdsToSting(orderItemids));
                db.ExecuteNonQuery(cmd);
            }
        }
    }
}
