//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Collections.Generic;

namespace XShan.DotShoppingCart.Common.Object {
    public class ShippingPackage {
        private bool isDownloadable;
        private string fromCountryCode, fromState, fromZipcode, toCountryCode, toState, toZipcode;
        private decimal subTotal, weight, width, height, length;
        private string weightDimensionUnit, sizeDimemsionUnit;

        public bool IsDownloadable {
            get { return isDownloadable; }
        }
        public string FromCountryCode {
            get { return fromCountryCode; }
        }
        public string FromState {
            get { return fromState; }
        }
        public string FromZipcode {
            get { return fromZipcode; }
        }
        public string ToCountryCode {
            get { return toCountryCode; }
        }
        public string ToState {
            get { return toState; }
        }
        public string ToZipcode {
            get { return toZipcode; }
        }

        public decimal SubTotal {
            get { return subTotal; }
        }
        public decimal Weight {
            get { return weight; }
        }
        public decimal Width {
            get { return width; }
        }
        public decimal Height {
            get { return height; }
        }
        public decimal Length {
            get { return length; }
        }

        public string WeightDimensionUnit {
            get { return weightDimensionUnit; }
        }
        public string SizeDimemsionUnit {
            get { return sizeDimemsionUnit; }
        }

        public ShippingPackage(bool isDownloadable, string fromCountryCode, string fromState, string fromZipcode,
            string toCountryCode, string toState, string toZipcode, decimal subTotal, 
            decimal weight, decimal width, decimal height, decimal length, string weightDimensionUnit, string sizeDimemsionUnit) {
            this.isDownloadable = isDownloadable;
            this.fromZipcode = fromZipcode;
            this.fromState = fromState;
            this.fromCountryCode = fromCountryCode;
            this.toZipcode = toZipcode;
            this.toState = fromState;
            this.toCountryCode = toCountryCode;
            this.subTotal = subTotal;
            this.weight = weight;
            this.width = width;
            this.height = height;
            this.length = length;
            this.weightDimensionUnit = weightDimensionUnit;
            this.sizeDimemsionUnit = sizeDimemsionUnit;
        }
        public static ShippingPackage GetShippingPackage(Cart cart, Address shippingAddress, string fromCountryCode, string fromState, string fromZipcode) {
            return GetShippingPackage(cart, shippingAddress.Country.CodeISO3166, shippingAddress.State, shippingAddress.Zipcode,
                fromCountryCode, fromState, fromZipcode);
        }
        
        public static ShippingPackage GetShippingPackage(Cart cart, string toCountryCode, string toState, string toZipcode,
            string fromCountryCode, string fromState, string fromZipcode) {
            return GetShippingPackage(null == cart? null : cart.CartItems, toCountryCode, toState, toZipcode, fromCountryCode, fromState, fromZipcode);
        }

        public static ShippingPackage GetShippingPackage(List<CartItem> cartItems, string toCountryCode, string toState, string toZipcode, 
            string fromCountryCode, string fromState, string fromZipcode) {
            decimal weight = 0, width = 0, height = 0, lenght = 0, amount = 0;
            bool isAllDownloadable = true;
            if ((null != cartItems) && (cartItems.Count > 0)) {
                foreach (CartItem item in cartItems) {
                    //Todo: Need to convert to the same measure unit
                    if (!item.Product.ShipType.IsDownloadable) {
                        amount += item.TotalPrice;
                        weight += (decimal)item.Quantity * item.Product.Weight ?? 0;
                        width += (decimal)item.Quantity * item.Product.Width ?? 0;
                        height += (decimal)item.Quantity * item.Product.Height ?? 0;
                        lenght += (decimal)item.Quantity * item.Product.Length ?? 0;
                        isAllDownloadable = false;
                    }
                }
            } else {
                isAllDownloadable = false;
            }
            return new ShippingPackage(isAllDownloadable, fromCountryCode, fromState, fromZipcode, toCountryCode, toState, toZipcode,
                amount, weight, width, height, lenght, "", "");
        }
    }
}
