//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Common;
using System.Data.SqlClient;
using System.Web.Caching;
using System.Web;
using Microsoft.Practices.EnterpriseLibrary.Data;

namespace XShan.DotShoppingCart.Common.Object {
    public class SideBox : ILoadFromDataRow {
        private int sideBoxId, sortOrder;
        private string title, parameters;
        private bool isLeftSide;
        private SideBoxType sideBoxType;

        public int SideBoxId {
            get { return sideBoxId; }
        }
        public int SortOrder {
            get { return sortOrder; }
        }
        public string Title {
            get { return title; }
        }
        public string Parameters {
            get { return parameters; }
        }
        public bool IsLeftSide {
            get { return isLeftSide; }
        }
        public SideBoxType SideBoxType {
            get { return sideBoxType; }
        }

        public SideBox() {
        }

        public bool LoadFromDataRow(DataRow row) {
            sideBoxId = (int)row["sideBoxId"];
            title = row["title"] as string;
            parameters = row["parameters"] as string;
            isLeftSide = (bool)row["isLeftSide"];
            sortOrder = (int)row["sortOrder"];
            
            // SideBoxType_lkp
            if (row.Table.DataSet.Relations.Contains(Constant.DBRelation.SIDEBOX_SIDEBOXTYPE)) {
                sideBoxType = new RecordList<SideBoxType>(row.GetParentRows(Constant.DBRelation.SIDEBOX_SIDEBOXTYPE))[0];
            } else {
                throw new ApplicationException("SideBoxType data is expected when loading SideBox.");
            }

            return true;
        }

        public static List<SideBox> GetAll(bool leftSide) {
            List<SideBox> boxes = (List<SideBox>)HttpContext.Current.Items["SideBoxes"];
            if (null == boxes) {
                boxes = GetAll();
                HttpContext.Current.Items["SideBoxes"] = boxes;
            }
            List<SideBox> oneSideBoxes = new List<SideBox>();
            foreach (SideBox box in boxes) {
                if (box.IsLeftSide == leftSide)
                    oneSideBoxes.Add(box);
            }
            return oneSideBoxes;
        }

        private static List<SideBox> GetAll() {
            List<SideBox> boxes = null;
            string cacheKey = string.Format("{0}_SideBox_GetAll", SiteNavigation.GetHost());
            object o = Utils.Cache.Get(cacheKey);
            if (null == o) {
                Database db = DBController.CreateDatabase();
                DbCommand cmd = db.GetStoredProcCommand("DSC_SideBox_GetAll");
                SqlCacheDependency dep = DBController.GetSqlCacheDependency((SqlCommand)cmd);
                DataSet ds = db.ExecuteDataSet(cmd);
                SetOrderDBRelations(ds);
                boxes = new RecordList<SideBox>(ds.Tables[0]);
                Utils.Cache.Insert(cacheKey, boxes, dep);
            } else {
                boxes = (List<SideBox>)o;
            }
            return boxes;
        }

        public static void RemoveCache() {
            Utils.Cache.Remove(string.Format("{0}_SideBox_GetAll", SiteNavigation.GetHost()));
        }

        public static int Add(int sideBoxTypeId, bool isLeftSide, string title, string parameters) {
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_SideBox_Add", sideBoxTypeId, isLeftSide, title, parameters);
            return Convert.ToInt32(db.ExecuteScalar(cmd));
        }

        public static void Update(int sideBoxId, int sideBoxTypeId, bool isLeftSide, string title, string parameters, int sortOrder) {
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_SideBox_Update", sideBoxId, sideBoxTypeId, isLeftSide, title, parameters, sortOrder);
            db.ExecuteNonQuery(cmd);
        }

        public static void Delete(int sideBoxId) {
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_SideBox_Delete", sideBoxId);
            db.ExecuteNonQuery(cmd);
        }

        private static void SetOrderDBRelations(DataSet ds) {
            int index = 0;
            ds.Tables[index++].TableName = "SideBox";
            ds.Tables[index++].TableName = "SideBoxType";

            //To support SqlCacheDependency for DSC_SideBox_GetAll, no DISTINCT can be specified in the sproc. So have to loose the constrain here.
            ds.Relations.Add(Constant.DBRelation.SIDEBOX_SIDEBOXTYPE, ds.Tables["SideBoxType"].Columns["sideBoxTypeId"],
                ds.Tables["SideBox"].Columns["sideBoxTypeId"], false);
        }
    }
}
