//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Collections.Generic;
using System.Text;
using System.ComponentModel;
using System.Reflection;

namespace XShan.DotShoppingCart.Common.Object
{
    public class SortableBindingList<T> : BindingList<T>
    {
        private bool sorted;
        private PropertyDescriptor property;
        private ListSortDirection direction;

        public SortableBindingList(IList<T> list) : base(list) {
        }

        #region Sorting

        protected override bool SupportsSortingCore
        {
            get { return true; }
        }

        protected override void ApplySortCore(PropertyDescriptor property, ListSortDirection direction)
        {
            // Get list to sort
            List<T> items = this.Items as List<T>;

            // Apply and set the sort, if items to sort
            if (items != null)
            {
                this.property = property;
                this.direction = direction;
                PropertyComparer<T> pc = new PropertyComparer<T>(property, direction);
                items.Sort(pc);
                sorted = true;
            }
            else
            {
                sorted = false;
            }

            // Let bound controls know they should refresh their views
            this.OnListChanged(new ListChangedEventArgs(ListChangedType.Reset, -1));
        }

        protected override bool IsSortedCore
        {
            get { return sorted; }
        }

        protected override void RemoveSortCore()
        {
            sorted = false;
        }

        protected override PropertyDescriptor SortPropertyCore
        {
            get
            {
                return this.property;
            }
        }
        protected override ListSortDirection SortDirectionCore
        {
            get
            {
                return this.direction;
            }
        }

        #endregion
    }
}
