//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Common;
using System.Data.SqlClient;
using System.Web.Caching;
using Microsoft.Practices.EnterpriseLibrary.Data;

namespace XShan.DotShoppingCart.Common.Object {
    public class Tab : ILoadFromDataRow {
        private int tabId, sortOrder;
        private string name, link;

        public int TabId {
            get { return tabId; }
        }
        public int SortOrder {
            get { return sortOrder; }
        }
        public string Name {
            get { return name; }
        }
        public string Link {
            get { return link; }
        }

        public Tab() {
        }

        public bool LoadFromDataRow(DataRow row) {
            tabId = (int)row["tabId"];
            name = row["name"] as string;
            link = (string)row["link"];
            sortOrder = (int)row["sortOrder"];
            return true;
        }

        public static List<Tab> GetAll() {
            List<Tab> tabs = null;
            string cacheKey = string.Format("{0}_Tab_GetAll", SiteNavigation.GetHost());
            object o = Utils.Cache.Get(cacheKey);
            if (null == o) {
                Database db = DBController.CreateDatabase();
                DbCommand cmd = db.GetStoredProcCommand("DSC_Tab_GetAll");
                SqlCacheDependency dep = DBController.GetSqlCacheDependency((SqlCommand)cmd);
                DataSet ds = db.ExecuteDataSet(cmd);
                tabs = new RecordList<Tab>(ds.Tables[0]);
                Utils.Cache.Insert(cacheKey, tabs, dep);
            } else {
                tabs = (List<Tab>)o;
            }
            return tabs;
        }

        public static int Add(string name, string link) {
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_Tab_Add", name, link);
            return Convert.ToInt32(db.ExecuteScalar(cmd));
        }

        public static void Update(int tabId, string name, string link, int sortOrder) {
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_Tab_Update", tabId, name, link, sortOrder);
            db.ExecuteNonQuery(cmd);
        }

        public static void Delete(int tabId) {
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("DSC_Tab_Delete", tabId);
            db.ExecuteNonQuery(cmd);
        }

    }
}
