//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Collections.Generic;
using System.Text;
using System.Diagnostics;
using System.IO;

namespace XShan.DotShoppingCart.Common {
    public class RunCmd {
        private StringBuilder output;

        public void RunProcess(string filename, string arguments) {
            output = new StringBuilder();
            Process p = new Process();
            p.StartInfo.FileName = filename;
            p.StartInfo.Arguments = arguments;
            p.StartInfo.CreateNoWindow = true;
            p.StartInfo.UseShellExecute = false;
            p.StartInfo.RedirectStandardOutput = true;
            p.StartInfo.RedirectStandardError = true;
            p.OutputDataReceived += new DataReceivedEventHandler(CatchOutputHandler);
            p.ErrorDataReceived += new DataReceivedEventHandler(CatchOutputHandler);

            p.Start();
            p.BeginOutputReadLine();
            p.BeginErrorReadLine();
            p.WaitForExit();

            if (0 != p.ExitCode) {
                ApplicationException ex = new ApplicationException(string.Format("\"{0} {1}\" returned ({2})", filename, arguments, p.ExitCode));
                ex.Data.Add("Console Output", output);
                throw ex;
            }
        }

        /// <summary>
        /// Send output to log
        /// </summary>
        /// <param name="sender">
        /// Process sending the output
        /// </param>
        /// <param name="e">
        /// Data from the process
        /// </param>
        private void CatchOutputHandler(object sender, DataReceivedEventArgs e) {
            if (null != e.Data)
                output.Append(e.Data);
        }
    }
}
