//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

//===============================================================================
// XShan Corporation DotShoppingCart
// Copyright  XShan Corporation. All rights reserved.
//===============================================================================

using System;
using System.Collections.Generic;
using System.Text;
using System.Text.RegularExpressions;
using System.Web;
using XShan.DotShoppingCart.Common.Configuration;

namespace XShan.DotShoppingCart.Common
{
    public class SiteNavigation {
        private const string slash = @"/";
        public static bool UseSSL = !IsTestHost() && (string.IsNullOrEmpty(Constant.DSC.FixedHostName) ||
            ((StoreConfigurationSection)SqlConfigurationController.GetSection(StoreConfigurationSection.SectionName)).OwnSSL);
        private const string homePage = "default.aspx";
        private const string cartPage = "cart.aspx";
        private const string searchPage = "search.aspx";
        private const string productImagesPage = "productImages.aspx";
        private const string itemAddedToCartPage = "ItemAddedToCart.aspx";
        private const string shippingEstimatorPage = "ShippingEstimator.aspx";
        private const string commonJSFile = "JS/DSCCommon.js";
        private const string cvvHelpPage = "CVVHelp.aspx";
        private const string productsPage = "Products.aspx";
        private const string rssPage = "Rss.aspx";
        private const string productReviewAllPage = "ProductReviewAll.aspx";

        //Secure pages
        private const string loginPage = "login.aspx";
        private const string registerPage = "register.aspx";
        private const string passwordRecoveryPage = "passwordrecovery.aspx";
        private const string myAccountPage = "myAccount.aspx";
        private const string orderDetailPage = "OrderDetail.aspx";
        private const string checkoutPage = "Checkout.aspx";
        private const string checkoutCompletePage = "CheckoutComplete.aspx";
        private const string paypalPDTHandlerPage = "PaypalPDTHandler.aspx";
        private const string invoicePage = "Invoice.aspx";
        private const string googleCheckoutMerchantCalculationHandler = "GoogleCheckoutMerchantCalculationHandler.aspx";
        private const string rateProductPage = "RateProduct.aspx";
        private const string tellFriendPage = "TellFriend.aspx";
        private const string askQuestionPage = "AskQuestion.aspx";
        private const string updateAlertPage = "UpdateAlert.aspx";

        //Admin pages
        private const string uploadFilesPage = "Controls/UploadFiles.aspx";
        private const string adminPage = "Admin/Default.aspx";
        private const string adminProductsPage = "Admin/Catalog/Products.aspx";
        private const string productEditPage = "Admin/Catalog/ProductEdit.aspx";
        private const string attributesPage = "Admin/Catalog/Attributes.aspx";
        private const string categoriesPage = "Admin/Catalog/Categories.aspx";
        private const string addProductWizardPage = "Admin/Catalog/AddProductWizard.aspx";
        private const string productReviewsPage = "Admin/Catalog/ProductReviews.aspx";
        private const string ordersPage = "Admin/Order/Orders.aspx";
        private const string orderEditPage = "Admin/Order/OrderEdit.aspx";
        private const string packingSlipPage = "Admin/Order/PackingSlip.aspx";
        private const string userEditPage = "Admin/User/UserEdit.aspx";
        private const string userTrackDetailPage = "Admin/Report/UserTrackDetail.aspx";
        private const string storeTaxPage = "Admin/Store/Tax.aspx";
        private const string taxRegionEditPage = "Admin/Store/TaxRegionEdit.aspx";
        private const string storeShippingPage = "Admin/Store/Shipping.aspx";
        private const string shippingRegionEditPage = "Admin/Store/ShippingRegionEdit.aspx";
      

        //DSC pages
        private const string dscHomePage = "http://www.dotshoppingcart.com";
        private const string dscHelpPage = "Custom/dotshoppingcart/OnlineHelp/";

        //Static pages
        private const string error404Page = "FileNotFound.htm";

        public static bool IsShadowSite {
            get {
                if (null == HttpContext.Current)
                    return false;

                return (0 == string.Compare(HttpContext.Current.Request.Url.Host, Constant.DSC.ShadowServer, true)) ||
                    (0 == string.Compare(HttpContext.Current.Request.Url.Host, "store.egege.com", true));
            }
        }

        public static string GetHost() {
            if (!string.IsNullOrEmpty(Constant.DSC.FixedHostName))
                return Constant.DSC.FixedHostName;

            if (null == HttpContext.Current)
                return "localhost";

            //Shadow site
            string fullSite = IsShadowSite ? GetStore(HttpContext.Current.Request.Url.AbsolutePath).ToLower() :
                HttpContext.Current.Request.Url.Host.ToLower();
            return GetShortSiteName(fullSite);
        }

        public static string GetShortSiteName(string fullSite) {
            // strip www. and .com
            StringBuilder sb = new StringBuilder();
            foreach (string part in fullSite.Split('.')) {
                if ((part != "www") && (part != "com")) {
                    if (sb.Length > 0)
                        sb.Append(".");
                    sb.Append(part);
                }
            }
            return sb.ToString();
        }

        public static bool IsTestHost() {
            return (GetHost() == "localhost") || (GetHost() == "egege") ||
                (IsShadowSite && (HttpContext.Current.Request.Url.Host.ToLower() == "store.egege.com"));
        }

        private static string GetApplicationPath() {
            if (@"/" == HttpContext.Current.Request.ApplicationPath) //root
                return "";
            return HttpContext.Current.Request.ApplicationPath;
        }

        public static string ResolveUrl(string relativePathToApplicationRoot) {
            return GetApplicationPath() + @"/" + relativePathToApplicationRoot;
        }

        public static string GetRelativePathToApplicatonRoot(string fullPath) {
            string applicationPath = GetApplicationPath();
            if (0 == applicationPath.Length) //application path is root
                return RemoveHeadingSlash(fullPath);
            int index;
            if ((index = fullPath.IndexOf(applicationPath)) >= 0) {
                return RemoveHeadingSlash(fullPath.Substring(index + applicationPath.Length));
            }
            return fullPath;
        }

        private static string RemoveHeadingSlash(string path) {
            if (path.StartsWith(@"/"))
                return path.Substring(1);
            return path;
        }

        public static string ResolveAbsoluteUrl(string host, params string[] partialUrls) {
            StoreConfigurationSection section = (StoreConfigurationSection)SqlConfigurationController.GetSection(host, StoreConfigurationSection.SectionName);
            string url = Regex.Replace(section.URL, @"\/$", @""); //remove most right slash
            return url + @"/" + ConcatenatePartsToUrl(partialUrls);
        }

        public static string ResolveAbsoluteUrl(bool isSSL, params string[] partialUrls) {
            StoreConfigurationSection section = (StoreConfigurationSection)SqlConfigurationController.GetSection(StoreConfigurationSection.SectionName);
            List<string> urls = new List<string>(partialUrls);
            if (isSSL && (!section.OwnSSL)) {
                string url = string.Join(slash, partialUrls);
                string host = GetHost();
                if (IsShadowSite) {
                    //clean up partialUrls if it has shadow server path already
                    Match m = Regex.Match(url, string.Format(@"^\/{0}\/(?<rest>.*)", host), RegexOptions.IgnoreCase);
                    if (m.Success)
                        url = m.Groups["rest"].Value;
                } else {
                    //move from own domain to shared ssl domain and need to migrate cart
                    url += (url.IndexOf('?') >= 0 ? "&" : "?") + string.Format("cartid={0}", Utils.GetUserName());
                }
                // use the shared ssl like store.dotshoppingcart.com/host
                return CompleteHttpUrl(isSSL, string.Format(@"{0}/{1}", Constant.DSC.ShadowServer, host), url);
            }
            urls.Insert(0, HttpContext.Current.Request.Url.Host);
            return CompleteHttpUrl(isSSL, urls.ToArray());
        }

        public static string UnMapPath(string filespec) { //opposite of Server.MapPath
            string appPath = HttpContext.Current.Request.PhysicalApplicationPath;
            if (!filespec.StartsWith(appPath, StringComparison.OrdinalIgnoreCase))
                throw new ApplicationException(string.Format("{0} is not inside application path {1}.", filespec, appPath));
            string relativePath = RemoveHeadingSlash(filespec.Substring(appPath.Length).Replace('\\', '/'));
            return ResolveUrl(relativePath);
        }
        
        /// <summary>
        /// Rewrites an internal url like Product.aspx?id=1 to a nicely formatted URL 
        /// that can be used for site navigation. These rules are simple; if you want to
        /// do more complex rewriting, UrlRewriter.NET is a very nice option.
        /// </summary>
        public static string GetRewriterUrl(string page, params string[] names) {
            return string.Format("{0}/{1}.aspx", SiteNavigation.ResolveAbsoluteUrl(false, ResolveUrl(page)), ConcatenatePartsToUrl(names));
        }

        public static string GetHostRewriterUrl(string host, string page, params string[] names) {
            return string.Format("{0}/{1}.aspx", SiteNavigation.ResolveAbsoluteUrl(host, page), ConcatenatePartsToUrl(names));
        }

        public static string ConcatenatePartsToUrl(params string[] names) {
            StringBuilder sb = new StringBuilder();
            foreach (string name in names) {
                if (!string.IsNullOrEmpty(name)) {
                    if (0 == sb.Length) {
                        sb.Append(name);
                    } else {
                        sb.Append("/").Append(name);
                    }
                }
            }
            return sb.ToString();
        }

        private static string GetStore(string urlPath) {
            return GetFirstPath(urlPath);
        }

        public static string GetFirstPath(string urlPath) {
            Match m = Regex.Match(urlPath, @"^\/?(?<firstPath>[^\/]+)\/");
            if (m.Success)
                return m.Groups["firstPath"].Value;
            return string.Empty;
        }

        public static string Combine(string path1, string path2) {
            return path1 + slash + path2;
        }

        public static string CompleteHttpUrl(bool isSSL, params string[] partialUrls) {
            int port = HttpContext.Current.Request.Url.Port;

            if ((80 != port) && (443 != port))
                partialUrls[0] = string.Format("{0}:{1}", partialUrls[0], port);

            string path = string.Join(slash, partialUrls);
            path = Regex.Replace(path, @"\/+", @"/");

            //remove most right slash
            path = Regex.Replace(path, @"\/$", @"");

            return "http" + (isSSL ? "s" : "") + "://" + path;
        }

        public static string ResolveUrlInText(string text) {
            return text.Replace(@"~", GetApplicationPath());
        }

        public static string UpdateUrl(string url, Dictionary<string, string> queryStringReplacement) {
            return UpdateUrl(url, queryStringReplacement, null);
        }

        public static string UpdateUrl(string url, Dictionary<string, string> queryStringReplacement, ICollection<string> queryStringRemoval) {
            string header, queryString;
            int index = url.IndexOf('?');
            if (-1 == index) { // not found
                header = url;
                queryString = string.Empty;
            } else {
                header = url.Substring(0, index);
                queryString = url.Substring(index + 1);
            }
            Dictionary<string, bool> replaced = new Dictionary<string, bool>(StringComparer.OrdinalIgnoreCase);
            Dictionary<string, string> newQueryString = new Dictionary<string, string>(StringComparer.OrdinalIgnoreCase);
            foreach (string pair in queryString.Split('&')) {
                if (!string.IsNullOrEmpty(pair)) {
                    string[] parts = pair.Split('=');
                    if (parts.Length > 0) {
                        string key = parts[0];
                        if (queryStringReplacement.ContainsKey(key)) {
                            newQueryString[key] = queryStringReplacement[key];
                            replaced[key] = true;
                        } else
                            newQueryString[key] = parts.Length > 1 ? parts[1] : string.Empty;
                    }
                }
            }
            //add non replaced query string
            foreach (string key in queryStringReplacement.Keys) {
                if (!replaced.ContainsKey(key)) {
                    newQueryString[key] = queryStringReplacement[key];
                }
            }
            Dictionary<string, bool> removalKeys = new Dictionary<string, bool>(StringComparer.OrdinalIgnoreCase);
            if (null != queryStringRemoval) {
                foreach (string key in queryStringRemoval) {
                    removalKeys[key] = true;
                }
            }

            StringBuilder sb = new StringBuilder(header);
            bool first = true;
            foreach (string key in newQueryString.Keys) {
                if (!removalKeys.ContainsKey(key)) {
                    if (first) {
                        sb.Append("?");
                        first = false;
                    } else
                        sb.Append("&");
                    sb.Append(key);
                    if (!string.IsNullOrEmpty(newQueryString[key]))
                        sb.Append("=").Append(newQueryString[key]);
                }
            }
            return sb.ToString();
        }

        public static string HomePage {
            get { return SiteNavigation.ResolveAbsoluteUrl(false, ResolveUrl(homePage)); }
        }
        public static string CartPage {
            get { return SiteNavigation.ResolveAbsoluteUrl(false, ResolveUrl(cartPage)); }
        }
        public static string SearchPage {
            get { return SiteNavigation.ResolveAbsoluteUrl(false, ResolveUrl(searchPage)); }
        }
        public static string LoginPage {
            get { return SiteNavigation.ResolveAbsoluteUrl(UseSSL, ResolveUrl(loginPage)); }
        }
        public static string RegisterPage {
            get { return SiteNavigation.ResolveAbsoluteUrl(UseSSL, ResolveUrl(registerPage)); }
        }
        public static string PasswordRecoveryPage {
            get { return SiteNavigation.ResolveAbsoluteUrl(UseSSL, ResolveUrl(passwordRecoveryPage)); }
        }
        public static string MyAccountPage {
            get { return SiteNavigation.ResolveAbsoluteUrl(UseSSL, ResolveUrl(myAccountPage)); }
        }
        public static string OrderDetailPage {
            get { return SiteNavigation.ResolveAbsoluteUrl(UseSSL, ResolveUrl(orderDetailPage)); }
        }
        public static string ProductImagesPage {
            get { return SiteNavigation.ResolveAbsoluteUrl(false, ResolveUrl(productImagesPage)); }
        }
        public static string ItemAddedToCartPage {
            get { return SiteNavigation.ResolveAbsoluteUrl(false, ResolveUrl(itemAddedToCartPage)); }
        }
        public static string ShippingEstimatorPage {
            get { return SiteNavigation.ResolveAbsoluteUrl(false, ResolveUrl(shippingEstimatorPage)); }
        }
        public static string CommonJSFile {
            get { return ResolveUrl(commonJSFile); }
        }
        public static string CvvHelpPage {
            get { return SiteNavigation.ResolveAbsoluteUrl(false, ResolveUrl(cvvHelpPage)); }
        }
        public static string ProductsPage {
            get { return SiteNavigation.ResolveAbsoluteUrl(false, ResolveUrl(productsPage)); }
        }
        public static string RssPage {
            get { return SiteNavigation.ResolveAbsoluteUrl(false, ResolveUrl(rssPage)); }
        }
        public static string ProductReviewAllPage {
            get { return SiteNavigation.ResolveAbsoluteUrl(false, ResolveUrl(productReviewAllPage)); }
        }
        
        public static string CheckoutPage {
            get { return SiteNavigation.ResolveAbsoluteUrl(UseSSL, ResolveUrl(checkoutPage)); }
        }
        public static string CheckoutCompletePage {
            get { return SiteNavigation.ResolveAbsoluteUrl(UseSSL, ResolveUrl(checkoutCompletePage)); }
        }
        public static string PaypalPDTHandlerPage {
            get { return SiteNavigation.ResolveAbsoluteUrl(UseSSL, ResolveUrl(paypalPDTHandlerPage)); }
        }
        public static string InvoicePage {
            get { return SiteNavigation.ResolveAbsoluteUrl(UseSSL, ResolveUrl(invoicePage)); }
        }
        public static string PackingSlipPage {
            get { return SiteNavigation.ResolveAbsoluteUrl(UseSSL, ResolveUrl(packingSlipPage)); }
        }
        public static string GoogleCheckoutMerchantCalculationHandler {
            get { return SiteNavigation.ResolveAbsoluteUrl(UseSSL, ResolveUrl(googleCheckoutMerchantCalculationHandler)); }
        }
        public static string RateProductPage {
            get { return SiteNavigation.ResolveAbsoluteUrl(UseSSL, ResolveUrl(rateProductPage)); }
        }
        public static string TellFriendPage {
            get { return SiteNavigation.ResolveAbsoluteUrl(UseSSL, ResolveUrl(tellFriendPage)); }
        }
        public static string AskQuestionPage {
            get { return SiteNavigation.ResolveAbsoluteUrl(UseSSL, ResolveUrl(askQuestionPage)); }
        }
        public static string UpdateAlertPage {
            get { return SiteNavigation.ResolveAbsoluteUrl(UseSSL, ResolveUrl(updateAlertPage)); }
        }
        
        public static string AdminPage {
            get { return SiteNavigation.ResolveAbsoluteUrl(UseSSL, ResolveUrl(adminPage)); }
        }
        public static string UploadFilesPage {
            get { return SiteNavigation.ResolveAbsoluteUrl(false, ResolveUrl(uploadFilesPage)); }
        }
        public static string AdminProductsPage {
            get { return SiteNavigation.ResolveAbsoluteUrl(false, ResolveUrl(adminProductsPage)); }
        }
        public static string ProductEditPage {
            get { return SiteNavigation.ResolveAbsoluteUrl(false, ResolveUrl(productEditPage)); }
        }
        public static string AttributesPage {
            get { return SiteNavigation.ResolveAbsoluteUrl(false, ResolveUrl(attributesPage)); }
        }
        public static string CategoriesPage {
            get { return SiteNavigation.ResolveAbsoluteUrl(false, ResolveUrl(categoriesPage)); }
        }
        public static string AddProductWizardPage {
            get { return SiteNavigation.ResolveAbsoluteUrl(false, ResolveUrl(addProductWizardPage)); }
        }
        public static string ProductReviewsPage {
            get { return SiteNavigation.ResolveAbsoluteUrl(false, ResolveUrl(productReviewsPage)); }
        }
        public static string OrdersPage {
            get { return SiteNavigation.ResolveAbsoluteUrl(UseSSL, ResolveUrl(ordersPage)); }
        }
        public static string OrderEditPage {
            get { return SiteNavigation.ResolveAbsoluteUrl(UseSSL, ResolveUrl(orderEditPage)); }
        }
        public static string UserEditPage {
            get { return SiteNavigation.ResolveAbsoluteUrl(UseSSL, ResolveUrl(userEditPage)); }
        }
        public static string UserTrackDetailPage {
            get { return SiteNavigation.ResolveAbsoluteUrl(UseSSL, ResolveUrl(userTrackDetailPage)); }
        }
        public static string StoreTaxPage {
            get { return SiteNavigation.ResolveAbsoluteUrl(UseSSL, ResolveUrl(storeTaxPage)); }
        }
        public static string TaxRegionEditPage {
            get { return SiteNavigation.ResolveAbsoluteUrl(UseSSL, ResolveUrl(taxRegionEditPage)); }
        }
        public static string StoreShippingPage {
            get { return SiteNavigation.ResolveAbsoluteUrl(UseSSL, ResolveUrl(storeShippingPage)); }
        }
        public static string ShippingRegionEditPage {
            get { return SiteNavigation.ResolveAbsoluteUrl(UseSSL, ResolveUrl(shippingRegionEditPage)); }
        }
        public static string Error404Page {
            get { return SiteNavigation.ResolveAbsoluteUrl(false, ResolveUrl(error404Page)); }
        }

        public static string DscHomePage {
            get { return dscHomePage; }
        }

        public static string DscOnlineHelp {
            get { return IsTestHost() ? ResolveUrl(dscHelpPage) : dscHomePage + "/" + dscHelpPage; }
        }
    }
}
