//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Collections.Generic;
using System.Security.Cryptography;
using System.Data;
using System.Data.Common;
using Microsoft.Practices.EnterpriseLibrary.Data;
using XShan.DotShoppingCart.Common.Object;

namespace XShan.DotShoppingCart.Common {
    public class ZenCartMigration {
        public static bool ValidatePW(string pw, string pwHash) {
            string[] parts = pwHash.Split(':');
            string hash = parts[0];
            string salt = parts[1];

            string saledPW = salt + pw;
            byte[] data = new byte[saledPW.Length];
            char[] pwArray = saledPW.ToCharArray();
            for (int i = 0; i < saledPW.Length; i++) {
                byte b = (byte)pwArray[i];
                data[i] = b;
            }
            MD5 md5 = new MD5CryptoServiceProvider();
            byte[] result = md5.ComputeHash(data);
            return ComparePWHash(result, hash);
        }

        private static bool ComparePWHash(byte[] result, string hash) {
            hash = hash.ToLower();
            //check length is right
            if (result.Length * 2 != hash.Length)
                return false;

            for (int i = 0; i < result.Length; i++) {
                if (result[i] != HexCharsToByte(hash[2 * i], hash[2 * i + 1]))
                    return false;
            }
            return true;
        }

        private static byte HexCharsToByte(char high, char low) {
            byte h = HexCharToNumber(high);
            byte l = HexCharToNumber(low);
            return (byte)(h * 16 + l);
        }

        private static byte HexCharToNumber(char c) {
            switch (c) {
                case '0':
                    return 0;
                case '1':
                    return 1;
                case '2':
                    return 2;
                case '3':
                    return 3;
                case '4':
                    return 4;
                case '5':
                    return 5;
                case '6':
                    return 6;
                case '7':
                    return 7;
                case '8':
                    return 8;
                case '9':
                    return 9;
                case 'a':
                    return 10;
                case 'b':
                    return 11;
                case 'c':
                    return 12;
                case 'd':
                    return 13;
                case 'e':
                    return 14;
                case 'f':
                    return 15;
            }
            throw new ApplicationException(string.Format("Wrong Hex char {0} passed. Expected 0 to f.", c));
        }
    }

    public class ZenUser : ILoadFromDataRow {
        private string userName, passwordHash;

        public string UserName {
            get { return userName; }
        }
        public string PasswordHash {
            get { return passwordHash; }
        }
        public ZenUser() {
        }

        public bool LoadFromDataRow(DataRow row) {
            userName = (string)row["userName"];
            passwordHash = (string)row["passwordHash"];
            return true;
        }

        public static void DeleteUser(string userName) {
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("ZEN_User_Delete", userName);
            db.ExecuteNonQuery(cmd);
        }

        public static ZenUser GetUser(string userName) {
            Database db = DBController.CreateDatabase();
            DbCommand cmd = db.GetStoredProcCommand("ZEN_User_Get", userName);
            DataSet ds = db.ExecuteDataSet(cmd);
            RecordList<ZenUser> users = new RecordList<ZenUser>(ds.Tables[0]);
            if (users.Count == 0)
                return null;

            return users[0];
        }
    }
}
