//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.Text;
using XShan.DotShoppingCart.Common;

public partial class Admin_Report_SaleReport : DSCPage {
    protected void Page_Load(object sender, EventArgs e) {
        if (!IsPostBack) {
            ddlPaymentType.DataSource = DBHelper.ExecuteSQL("DSC_CheckoutPayment_Type_GetAll");
            ddlPaymentType.DataBind();
            BindControls();
        }
    }

    private void BindControls() {
        DataSet ds = DBHelper.ExecuteSQL("DSC_Sale_GetReport", dateRange.From, dateRange.To,
            string.IsNullOrEmpty(ddlPaymentType.SelectedValue) ? null : ddlPaymentType.SelectedValue);
        decimal[] totals = null;
        if ((null != ds) && (ds.Tables.Count > 0)) {
            // the first two columns are Order Number and Date
            DataTable dt = ds.Tables[0];
            // remove any columns after the first two columns
            for (int i = gvwReport.Columns.Count - 1; i >= 2; i--) {
                gvwReport.Columns.RemoveAt(i);
            }
            // add columns after the first two columns
            if (dt.Columns.Count > 2) {
                for (int i = 2; i < dt.Columns.Count; i++) {
                    BoundField field = new BoundField();
                    field.HeaderText = dt.Columns[i].ColumnName;
                    field.DataField = dt.Columns[i].ColumnName;
                    field.DataFormatString = "{0:C}";
                    field.HtmlEncode = false;
                    gvwReport.Columns.Add(field);
                }
                //calculate totals
                totals = new decimal[dt.Columns.Count - 2];
                for (int j = 2; j < dt.Columns.Count; j++) {
                    totals[j - 2] = 0;
                }
                for (int i = 0; i < dt.Rows.Count; i++) {
                    for (int j = 2; j < dt.Columns.Count; j++) {
                        decimal value;
                        if (decimal.TryParse(dt.Rows[i][j].ToString(), out value)) {
                            totals[j - 2] += value;
                        }
                    }
                }
            }
        } else {
            ds = null; // make sure dataset is null
        }
        gvwReport.DataSource = ds;
        gvwReport.DataBind();

        if (null != totals) {
            gvwReport.FooterRow.Cells[0].Text = "Total";
            gvwReport.FooterRow.Cells[1].Text = ds.Tables[0].Rows.Count.ToString();
            for (int j = 2; j < gvwReport.FooterRow.Cells.Count; j++) {
                gvwReport.FooterRow.Cells[j].Text = totals[j - 2].ToString("C");
            }
        }
        btnExport.Enabled = gvwReport.Rows.Count > 0;
    }

    protected void btnSearch_Click(object sender, EventArgs e) {
        if (IsValid) {
            BindControls();
        }
    }

    protected void btnExport_Click(object sender, EventArgs e) {
        if (IsValid) {
            // Clear response content & headers
            //        Response.Clear();
            //        Response.ClearContent();
            //        Response.ClearHeaders();

            // Add header
            Response.ContentType = "Application/x-msexcel";
            Response.AddHeader("content-disposition", "attachment;filename=SaleReport.csv");
            //        Response.Charset = string.Empty;

            Response.Write(ToCSV(gvwReport));
            Response.End();
        }
    }

    private static string ToCSV(GridView gv) {
        StringBuilder sb = new StringBuilder();

        if (gv.Columns.Count > 0) {
            foreach (TableCell cell in gv.HeaderRow.Cells) {
                //append the column name followed by the separator
                sb.Append(cell.Text).Append(',');
            }
            sb.Append("\r\n");

            //loop thru each row of the datatable
            foreach (GridViewRow row in gv.Rows) {
                foreach (TableCell cell in row.Cells) {
                    sb.Append(cell.Text).Append(',');
                }
                sb.Append("\r\n");
            }

            foreach (TableCell cell in gv.FooterRow.Cells) {
                //append the column name followed by the separator
                sb.Append(cell.Text).Append(',');
            }
            sb.Append("\r\n");
        }

        return sb.ToString();
    }
}
