//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.Xml;

using XShan.DotShoppingCart.Common;
using XShan.DotShoppingCart.Common.Configuration;

public partial class Admin_Store_Controls_Colors : ValidatableUserControl {
    private string validationGroup;
    public override string ValidationGroup {
        set { validationGroup = value; }
    }

    private string errorMessagePrefix;
    public override string ErrorMessagePrefix {
        set { errorMessagePrefix = value; }
    }

    private string theme {
        get { return (string)ViewState["theme"]; }
        set { ViewState["theme"] = value; }
    }

    protected void Page_Load(object sender, EventArgs e) {
        if (!IsPostBack) {
            lstTemplates.Attributes.Add("onchange", "SetImage(this);");

            UIConfigurationSection section = UIConfigurationSection.GetSection();
            rptColors.DataSource = section.Colors;
            rptColors.DataBind();

            this.theme = UIConfigurationSection.GetSection().ParentThemes;
            LoadColorTemplate(theme);
        }
        foreach (RepeaterItem item in rptColors.Items) {
            TextBox txtColor = (TextBox)item.FindControl("txtColor");
            ScriptManager.RegisterStartupScript(this, typeof(Admin_Store_Controls_Colors), txtColor.ClientID,
                string.Format("InitColorPreview('{0}');", txtColor.ClientID), true);
        }
    }

    protected void rptColors_ItemDataBound(object sender, RepeaterItemEventArgs e) {
        RequiredFieldValidator rvfColor = (RequiredFieldValidator)e.Item.FindControl("rvfColor");
        if (!string.IsNullOrEmpty(validationGroup))
            rvfColor.ValidationGroup = validationGroup;
        rvfColor.ErrorMessage = errorMessagePrefix + ((ColorConfigurationElement)e.Item.DataItem).Name + " is a required field.";

        TextBox txtColor = (TextBox)e.Item.FindControl("txtColor");
        txtColor.Attributes.Add("onchange", string.Format("InitColorPreview('{0}')", txtColor.ClientID));
        txtColor.Attributes.Add("onfocus", "ShowColorPicker(this)");
        txtColor.Attributes.Add("onblur", "HideColorPicker(this)");
        txtColor.Attributes.Add("colorName", string.Format("{0}", ((ColorConfigurationElement)e.Item.DataItem).Name));
        txtColor.Attributes.Add("spanColorPreview", string.Format("spColor_{0}", ((ColorConfigurationElement)e.Item.DataItem).Name));
    }

    public void SaveTo(UIConfigurationSection section) {
        foreach (RepeaterItem item in rptColors.Items) {
            Label lblColorName = (Label)item.FindControl("lblColorName");
            TextBox txtColor = (TextBox)item.FindControl("txtColor");
            section.Colors.Get(lblColorName.Text).Value = txtColor.Text;
        }
    }

    public void LoadFromTheme(string theme) {
        this.theme = theme;
        LoadColors(null);
        LoadColorTemplate(theme);
    }

    private void LoadColors(string colorTemplate) {
        XmlDocument themeConfig = WebUtils.LoadThemeConfigXml(this.theme);
        foreach (RepeaterItem item in rptColors.Items) {
            Label lblColorName = (Label)item.FindControl("lblColorName");
            TextBox txtColor = (TextBox)item.FindControl("txtColor");
            string xpath = string.Format("ColorTemplates/ColorTemplate[{0}]/Color[@name='{1}']", 
                string.IsNullOrEmpty(colorTemplate) ? "1" : "@name='" + colorTemplate + "'", lblColorName.Text);
            //load the first ColorTemplate if colorTemplate is null
            txtColor.Text = themeConfig.DocumentElement.SelectSingleNode(xpath).InnerText;
        }
    }

    protected void btnSelectColor_Click(object sender, EventArgs e) {
        LoadColors(lstTemplates.SelectedItem.Text);
    }

    private void LoadColorTemplate(string theme) {
        lstTemplates.Items.Clear();
        XmlDocument themeConfig = WebUtils.LoadThemeConfigXml(theme);
        foreach (XmlNode node in themeConfig.DocumentElement.SelectNodes("ColorTemplates/ColorTemplate")) {
            ListItem item = new ListItem(node.Attributes["name"].Value, WebUtils.GetThemeThumbnailImageUrl(theme, node.Attributes["thumbnail"].Value));
            lstTemplates.Items.Add(item);
        }
        lstTemplates.SelectedIndex = 0;
    }
}
