//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Configuration;
using System.Collections.Generic;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using XShan.DotShoppingCart.Common;
using XShan.DotShoppingCart.Common.Object;

public partial class Admin_Controls_ConfigureCondition : System.Web.UI.UserControl {
    private List<Condition> initialConditions = null;

    public List<Condition> InitialConditions {
        get { return initialConditions; }
        set { initialConditions = value; }
    }

    public List<Condition> Conditions {
        get { return (List<Condition>)ViewState["Conditions"]; }
        set { ViewState["Conditions"] = value; }
    }

    public string AddButtonText {
        set { btnAdd.Text = value; }
    }

    protected bool HasCondition {
        get { return null != Conditions; }
    }

    protected void Page_PreRender(object sender, EventArgs e) {
        if (null != initialConditions) {
            Conditions = initialConditions;
            BindControls();
        }
        ddlAddOperator.DataSource = Utils.GetEnumNameValueList(typeof(ConditionOperator));
        ddlAddOperator.DataBind();
    }

    private void BindControls() {
        gvwCondition.DataSource = Conditions;
        gvwCondition.DataBind();
    }


    protected void gvwCondition_RowDataBound(object sender, GridViewRowEventArgs e) {
        if (e.Row.RowType == DataControlRowType.DataRow) {
            DropDownList ddlOperator = (DropDownList)e.Row.FindControl("ddlOperator");
            if (null != ddlOperator) {
                ddlOperator.DataSource = Utils.GetEnumNameValueList(typeof(ConditionOperator));
                ddlOperator.DataBind();
            }

            Condition condition = (Condition)e.Row.DataItem;
            DropDownList ddlProperty = (DropDownList)e.Row.FindControl("ddlProperty");
            if (null != ddlProperty)
                WebUtils.SetDropDownListSelected(ddlProperty, condition.Property);
        }
    }

    protected void gvwCondition_RowEditing(object sender, GridViewEditEventArgs e) {
        gvwCondition.EditIndex = e.NewEditIndex;
        pnlAdd.Visible = false;
        BindControls();
    }

    protected void gvwCondition_RowUpdating(object sender, GridViewUpdateEventArgs e) {
        DropDownList ddlProperty = (DropDownList)gvwCondition.Rows[e.RowIndex].FindControl("ddlProperty");
        DropDownList ddlOperator = (DropDownList)gvwCondition.Rows[e.RowIndex].FindControl("ddlOperator");
        TextBox txtValue = (TextBox)gvwCondition.Rows[e.RowIndex].FindControl("txtValue");

        Condition condition = Conditions[e.RowIndex];
        condition.Property = ddlProperty.SelectedValue;
        condition.ConditionOperator = (ConditionOperator)int.Parse(ddlOperator.SelectedValue);
        condition.Value = txtValue.Text;

        gvwCondition.EditIndex = -1;
        pnlAdd.Visible = true;
        BindControls();
    }

    protected void gvwCondition_RowCancelingEdit(object sender, GridViewCancelEditEventArgs e) {
        gvwCondition.EditIndex = -1;
        pnlAdd.Visible = true;
        BindControls();
    }

    protected void gvwCondition_RowDeleting(object sender, GridViewDeleteEventArgs e) {
        Conditions.RemoveAt(e.RowIndex);
        BindControls();
    }

    protected void btnAdd_Click(object sender, EventArgs e) {
        if (null == Conditions)
            Conditions = new List<Condition>();
        Conditions.Add(new Condition(ddlProperty.SelectedValue, (ConditionOperator)int.Parse(ddlAddOperator.SelectedValue), txtValue.Text));
        BindControls();

        //reset add form
        ddlProperty.SelectedIndex = ddlAddOperator.SelectedIndex = 0;
        txtValue.Text = string.Empty;
    }
}
