//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Configuration;
using System.Collections.Generic;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using XShan.DotShoppingCart.Common.Configuration;
using Common = XShan.DotShoppingCart.Common;
using XShan.DotShoppingCart.Common;
using XShan.DotShoppingCart.Common.Object;

public partial class Admin_Controls_ProviderConfiguration : System.Web.UI.UserControl {
    private DSCProvider provider;
    private string sectionName;

    public DSCProvider Provider {
        get { return provider; }
        set { provider = value; }
    }
    public string SectionName {
        get { return sectionName; }
        set { sectionName = value; }
    }
    private Dictionary<string, ProviderAttribute> savedAttributes {
        get { return (Dictionary<string, ProviderAttribute>)ViewState["savedAttributes"]; }
        set { ViewState["savedAttributes"] = value; }
    }

    public Dictionary<string, string> GetSettings(bool saveUploadedFile) {
        Dictionary<string, string> settings = new Dictionary<string, string>();
        foreach (RepeaterItem item in rptAttributes.Items) {
            HiddenField hidName = (HiddenField)item.FindControl("hidName");
            Panel pnlValue = (Panel)item.FindControl("pnlValue");
            Control c = pnlValue.FindControl("chkValue");
            if (null != c)
                settings.Add(hidName.Value, ((CheckBox)c).Checked.ToString());
            else if (null != (c = pnlValue.FindControl("txtValue")))
                settings.Add(hidName.Value, ((TextBox)c).Text);
            else if (null != (c = pnlValue.FindControl("fulValue"))) {
                FileUpload ful = (FileUpload)c;
                if (saveUploadedFile && ful.HasFile) {
                    HttpPostedFile uploadedFile = ful.PostedFile;
                    int binaryId = Binary.Add(Common.Utils.GetData(uploadedFile.InputStream), ful.FileName);
                    settings.Add(hidName.Value, binaryId.ToString());
                }
            } 
            else if (null != (c = pnlValue.FindControl("cusValue"))) {
                CustomUserControl customerControl = (CustomUserControl)c;
                settings.Add(hidName.Value, customerControl.ConfiguredValue);
            }
            //else error?

            //Todo: need to block empty shipping method and validate sort order value
        }
        return settings;
    }

    public Dictionary<string, string> GetSettings() {
        return GetSettings(false);
    }

    protected void Page_Load(object sender, EventArgs e) {
        if (IsPostBack && (null != savedAttributes)) {
            //create dynamic controls
            foreach (RepeaterItem item in rptAttributes.Items) {
                HiddenField hidName = (HiddenField)item.FindControl("hidName");
                Panel pnlValue = (Panel)item.FindControl("pnlValue");
                ProviderAttribute pa = savedAttributes[hidName.Value];
                TextBox tb;
                switch (pa.Type) {
                    case ConfigurationValueType.Boolean:
                        CheckBox cb = new CheckBox();
                        cb.ID = "chkValue";
                        pnlValue.Controls.Add(cb);
                        break;
                    case ConfigurationValueType.String:
                        tb = new TextBox();
                        tb.ID = "txtValue";
                        pnlValue.Controls.Add(tb);
                        break;
                    case ConfigurationValueType.Password:
                        tb = new TextBox();
                        tb.TextMode = TextBoxMode.Password;
                        tb.ID = "txtValue";
                        pnlValue.Controls.Add(tb);
                        break;
                    case ConfigurationValueType.File:
                        Label l = new Label();
                        l.ID = "lblUploaded";
                        pnlValue.Controls.Add(l);
                        FileUpload fu = new FileUpload();
                        fu.ID = "fulValue";
                        pnlValue.Controls.Add(fu);
                        break;
                    case ConfigurationValueType.CustomType:
                        //Todo: the custom type should be contained in the provider. 
                        //I put it as a user control as a temporary solution.
                        CustomUserControl c = (CustomUserControl)LoadControl(pa.ControlType);
                        c.ID = "cusValue";
                        pnlValue.Controls.Add(c);
                        break;
                }
            }
        }
    }

    public override void DataBind() {
        base.DataBind();

        if (null != provider) {
            ServiceConfigurationSection scs = (ServiceConfigurationSection)SqlConfigurationController.GetSection(sectionName);
            ProviderSettings ps = (null == scs) ? null : scs.Providers[provider.Name];

            Dictionary<string, ProviderAttribute> attributesNameMap = new Dictionary<string, ProviderAttribute>();
            foreach (ProviderAttribute attribute in provider.GetConfigurationSettings()) {
                string configuredValue = (null == ps) ? null : ps.Parameters[attribute.Name];
                attribute.Value = configuredValue;
                attributesNameMap.Add(attribute.Name, attribute);
            }
            rptAttributes.DataSource = attributesNameMap.Values;
            rptAttributes.DataBind();
            savedAttributes = attributesNameMap;
        }
    }

    protected void rptAttributes_ItemDataBound(object sender, RepeaterItemEventArgs e) {
        ProviderAttribute pa = (ProviderAttribute)e.Item.DataItem;
        HiddenField hidName = (HiddenField)e.Item.FindControl("hidName");
        hidName.Value = pa.Name;
        Panel pnlValue = (Panel)e.Item.FindControl("pnlValue");
        TextBox tb;
        switch (pa.Type) {
            case ConfigurationValueType.Boolean:
                CheckBox cb = new CheckBox();
                cb.ID = "chkValue";
                cb.Checked = string.IsNullOrEmpty(pa.Value) ? false : bool.Parse(pa.Value);
                pnlValue.Controls.Add(cb);
                break;
            case ConfigurationValueType.String:
                tb = new TextBox();
                tb.ID = "txtValue";
                tb.Text = pa.Value;
                tb.Width = new Unit(400);
                pnlValue.Controls.Add(tb);
                break;
            case ConfigurationValueType.Password:
                tb = new TextBox();
                tb.TextMode = TextBoxMode.Password;
                tb.ID = "txtValue";
                tb.Text = pa.Value;
                tb.Width = new Unit(400);
                pnlValue.Controls.Add(tb);
                break;
            case ConfigurationValueType.File:
                string binaryId = pa.Value;
                Label l = new Label();
                l.ID = "lblUploaded";
                if (!string.IsNullOrEmpty(binaryId))
                    l.Text = string.Format("Uploaded ({0}) ", binaryId);
                pnlValue.Controls.Add(l);
                FileUpload fu = new FileUpload();
                fu.ID = "fulValue";
                fu.Width = new Unit(325);
                pnlValue.Controls.Add(fu);
                break;
            case ConfigurationValueType.CustomType:
                //Todo: the custom type should be contained in the provider. 
                //I put it as a user control as a temporary solution.
                CustomUserControl c = (CustomUserControl)LoadControl(pa.ControlType);
                c.ID = "cusValue";
                c.ConfiguredValue = pa.Value;
                pnlValue.Controls.Add(c);
                c.DataBind();
                break;
        }
    }
}
