//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using XShan.DotShoppingCart.Common;
using XShan.DotShoppingCart.Common.Configuration;

public partial class Admin_Store_Controls_SideBoxes : ValidatableUserControl {
    public override string ValidationGroup {
        set {
            base.ValidationGroup = value;
            ntbLeftWidth.ValidationGroup = value;
            ntbRightWidth.ValidationGroup = value;
        }
    }

    public override string ErrorMessagePrefix {
        set {
            base.ErrorMessagePrefix = value;
            ntbLeftWidth.ErrorMessagePrefix = value + "Left SideBoxes Width ";
            ntbRightWidth.ErrorMessagePrefix = value + "Right SideBoxes Width ";
        }
    }

    protected void Page_Load(object sender, EventArgs e) {
        if (!IsPostBack) {
            UIConfigurationSection section = UIConfigurationSection.GetSection();

            chkLeft.Checked = lblLeftWidth.Enabled = ntbLeftWidth.Required = ntbLeftWidth.Enabled = section.LayoutPanels.Contains("leftPanel");
            if (chkLeft.Checked)
                ntbLeftWidth.Text = section.LayoutPanels.Get("leftPanel").Width;

            chkRight.Checked = lblRightWidth.Enabled = ntbRightWidth.Required = ntbRightWidth.Enabled = section.LayoutPanels.Contains("rightPanel");
            if (chkRight.Checked)
                ntbRightWidth.Text = section.LayoutPanels.Get("rightPanel").Width;
        }
    }

    public void SaveTo(UIConfigurationSection section) {
        if (chkLeft.Checked) {
            if (section.LayoutPanels.Contains("leftPanel"))
                section.LayoutPanels.Get("leftPanel").Width = ntbLeftWidth.Text;
            else
                section.LayoutPanels.Add(new LayoutPanelConfigurationElement("leftPanel", ntbLeftWidth.Text));
        } else {
            if (section.LayoutPanels.Contains("leftPanel"))
                section.LayoutPanels.Remove("leftPanel");
        }

        if (chkRight.Checked) {
            if (section.LayoutPanels.Contains("rightPanel"))
                section.LayoutPanels.Get("rightPanel").Width = ntbRightWidth.Text;
            else
                section.LayoutPanels.Add(new LayoutPanelConfigurationElement("rightPanel", ntbRightWidth.Text));
        } else {
            if (section.LayoutPanels.Contains("rightPanel"))
                section.LayoutPanels.Remove("rightPanel");
        }
    }

    protected void chkLeft_CheckedChanged(object sender, EventArgs e) {
        lblLeftWidth.Enabled = ntbLeftWidth.Required = ntbLeftWidth.Enabled = chkLeft.Checked;
    }

    protected void chkRight_CheckedChanged(object sender, EventArgs e) {
        lblRightWidth.Enabled = ntbRightWidth.Required = ntbRightWidth.Enabled = chkRight.Checked;
    }
}
