//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using XShan.DotShoppingCart.Common;
using XShan.DotShoppingCart.Common.Configuration;

public class ThemeChangedEventArgs : EventArgs {
    public string ThemeNameSelected;

    public ThemeChangedEventArgs(string themeName) {
        ThemeNameSelected = themeName;
    }
}
public delegate void ThemeChangedEventHandler(object sender, ThemeChangedEventArgs e);

public partial class Admin_Store_Controls_Theme : System.Web.UI.UserControl {
    public event ThemeChangedEventHandler ThemeChanged = null;

    protected void Page_Load(object sender, EventArgs e) {
        if (!IsPostBack) {
            lstThemes.DataBind();
        }
    }

    public void SaveTo(UIConfigurationSection section) {
        section.ParentThemes = lstThemes.SelectedItem.Text;
    }

    protected void lstThemes_DataBound(object sender, EventArgs e) {
        UIConfigurationSection section = UIConfigurationSection.GetSection();
        foreach (ListItem item in lstThemes.Items) {
            if (item.Text == section.ParentThemes) {
                item.Selected = true;
                imgTheme.ImageUrl = item.Value;
                OnThemeChanged(new ThemeChangedEventArgs(item.Text));
                break;
            }
        }
    }

    protected void lstThemes_SelectedIndexChanged(object sender, EventArgs e) {
        imgTheme.ImageUrl = lstThemes.SelectedValue;
        OnThemeChanged(new ThemeChangedEventArgs(lstThemes.SelectedItem.Text));
    }

    protected virtual void OnThemeChanged(ThemeChangedEventArgs e) {
        if (null != ThemeChanged) {
            ThemeChanged(this, e);
        }
    }

}
