//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Configuration;
using System.Collections.Generic;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using XShan.DotShoppingCart.Common;
using XShan.DotShoppingCart.Common.Configuration;
using XShan.DotShoppingCart.Shipping;

public partial class Admin_Configuration_Shipping : DSCPage {
    protected void Page_Load(object sender, EventArgs e) {
        if (!IsPostBack) {
            InitControls();
        }
    }

    private void InitControls() {
        List<ShippingProvider> providers = new List<ShippingProvider>();
        ShippingServiceConfigurationSection scs = (ShippingServiceConfigurationSection)SqlConfigurationController.GetSection(ShippingServiceConfigurationSection.SectionName);
        foreach (Type t in Utils.GetProviders("*Shipping*.dll", typeof(ShippingProvider))) {
            object classInstance = Activator.CreateInstance(t);
            providers.Add((ShippingProvider)classInstance);
        }
        //Todo: need to order the providers based on sortOrder and also put unconfigured providers to the bottom
        rptShippingProviders.DataSource = providers;
        rptShippingProviders.DataBind();
    }

    protected void btnUpdateShipping_Click(object sender, EventArgs e) {
        ShippingServiceConfigurationSection scs = (ShippingServiceConfigurationSection)SqlConfigurationController.GetSection(ShippingServiceConfigurationSection.SectionName);
        if (null == scs)
            scs = new ShippingServiceConfigurationSection();

        foreach (RepeaterItem item in rptShippingProviders.Items) {
            Admin_Controls_ProviderConfiguration providerConfiguration = (Admin_Controls_ProviderConfiguration)
                item.FindControl("providerConfiguration");
            Dictionary<string, string> settings = providerConfiguration.GetSettings();

            Label lblName = (Label)item.FindControl("lblName");
            HiddenField hidType = (HiddenField)item.FindControl("hidType");

            ProviderSettings ps = scs.Providers[lblName.Text];
            if (null == ps) {
                ps = new ProviderSettings(lblName.Text, hidType.Value);
                scs.Providers.Add(ps);
            }

            foreach (string key in settings.Keys) {
                //need to change all invalid values to 0
                int sortOrder;
                if (("sortOrder" == key) && (!int.TryParse(settings[key], out sortOrder))) {
                    scs.Providers[lblName.Text].Parameters[key] = "0";
                } else if (!string.IsNullOrEmpty(settings[key]))
                    scs.Providers[lblName.Text].Parameters[key] = settings[key];
            }
        }
        SqlConfigurationController.SaveSection(ShippingServiceConfigurationSection.SectionName, scs);
        tlbUpdateProviderStatus.ShowText("Saved.");
    }
}
