//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.IO;
using System.Xml;

using XShan.DotShoppingCart.Common;
using XShan.DotShoppingCart.Common.Object;
using XShan.DotShoppingCart.Common.Configuration;

public partial class Admin_Store_UI : DSCPage {
    protected void Page_Load(object sender, EventArgs e) {
        if (!IsPostBack) {
            string msg = Utils.GetParameter("msg", null);
            if (!string.IsNullOrEmpty(msg))
                tlbStatus.ShowText(msg);

            tbcUI.ActiveTabIndex = Utils.GetIntParameter("ti", 0);
        }
        // workaround for the bug http://www.codeplex.com/AtlasControlToolkit/WorkItem/View.aspx?WorkItemId=8255
        if (!string.IsNullOrEmpty(hidActiveTab.Value))
            tbcUI.ActiveTabIndex = int.Parse(hidActiveTab.Value);
    }

    protected void btnSave_Click(object sender, EventArgs e) {
        if (IsValid) {
            UIConfigurationSection section = UIConfigurationSection.GetSection();
            dscTheme.SaveTo(section);
            sideBoxes.SaveTo(section);
            logo.SaveTo(section);
            colors.SaveTo(section);
            productLists.SaveTo(section);
            CleanUpCachedFiles();

            SqlConfigurationController.SaveSection(UIConfigurationSection.SectionName, section);
            if (!string.IsNullOrEmpty(hidHeaderParagraph.Value))
                Paragraph.Update(Constant.UI.HeaderParagraphName, hidHeaderParagraph.Value);

            DbTemplate.Update(Constant.UI.ProductSummaryTemplateName, hidProductSummary.Value);

            Response.Redirect(string.Format(@"{0}?ti={1}&msg=Saved", Request.Url.AbsolutePath, tbcUI.ActiveTabIndex));
        }
    }

    private void CleanUpCachedFiles() {
        //skin files
        foreach (string themeFile in new string[] { Constant.UI.OverrideThemeStypeSheetTemplateName, Constant.UI.OverrideThemeSkinTemplateName }) {
            string filespec = Request.PhysicalApplicationPath + Path.Combine(Path.Combine("App_Themes", SiteNavigation.GetHost()), themeFile);
            if (File.Exists(filespec))
                File.Delete(filespec);
        }

        //dynamic image files
        foreach (string file in Directory.GetFiles(WebUtils.GetImagePath())) {
            File.Delete(file);
        }
    }

    protected void dscTheme_ThemeChanged(object sender, ThemeChangedEventArgs e) {
        XmlDocument oldThemeConfig = WebUtils.LoadThemeConfigXml(UIConfigurationSection.GetSection().ParentThemes);
        XmlElement oldHeaderConfig = (XmlElement)oldThemeConfig.DocumentElement.SelectSingleNode("HeaderParagraph");
        string oldContent = Paragraph.Load(Constant.UI.HeaderParagraphName).Text.Trim();
        cbeSaveConfirm.Enabled = (!oldContent.Equals(oldHeaderConfig.InnerText.Trim(), StringComparison.OrdinalIgnoreCase)) &&
            (!oldContent.Equals(hidHeaderParagraph.Value.Trim(), StringComparison.OrdinalIgnoreCase));

        XmlDocument themeConfig = WebUtils.LoadThemeConfigXml(e.ThemeNameSelected);
        LoadHeaderParagraphFromThemeDefault(themeConfig);
        LoadProductSummaryFromThemeDefault(themeConfig);
        colors.LoadFromTheme(e.ThemeNameSelected);
    }

    private void LoadHeaderParagraphFromThemeDefault(XmlDocument themeConfig) {
        XmlElement headerConfig = (XmlElement)themeConfig.DocumentElement.SelectSingleNode("HeaderParagraph");
        hidHeaderParagraph.Value = headerConfig.InnerText;
    }

    private void LoadProductSummaryFromThemeDefault(XmlDocument themeConfig) {
        XmlElement headerConfig = (XmlElement)themeConfig.DocumentElement.SelectSingleNode("ProductSummaryTemplate");
        hidProductSummary.Value = headerConfig.InnerText;
    }

}
