//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Configuration;
using System.Collections.Generic;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using Microsoft.Practices.EnterpriseLibrary.ExceptionHandling;

using XShan.DotShoppingCart.Common;
using XShan.DotShoppingCart.Common.Object;
using XShan.DotShoppingCart.OrderTotal;
using XShan.DotShoppingCart.Payment;
using XShan.DotShoppingCart.Common.Configuration;

public partial class Checkout : DSCSecurePage {
    private Address shippingAddress {
        get { return (Address)Session["shippingAddress"]; }
        set { Session["shippingAddress"] = value; }
    }
    private CreditCard creditCard {
        get { return (CreditCard)ViewState["creditCard"]; }
        set { ViewState["creditCard"] = value; }
    }
    private PaypalPaymentInfo paypalPaymentInfo {
        get { return (PaypalPaymentInfo)ViewState["paypalPaymentInfo"]; }
        set { ViewState["paypalPaymentInfo"] = value; }
    }
    private CheckoutPaymentTypeEnum checkoutPaymentType {
        get { return (CheckoutPaymentTypeEnum)ViewState["checkoutPaymentType"]; }
        set { ViewState["checkoutPaymentType"] = value; }
    }

    private PaypalExpressPaymentProvider paypalExpressProvider;
    private PaypalExpressPaymentProvider PaypalExpressProvider {
        get {
            if (null == paypalExpressProvider)
                paypalExpressProvider = PaypalExpressPaymentProvider.GetProvider();
            return paypalExpressProvider;
        }
    }

    private PaypalStandardPaymentProvider paypalStandardProvider;
    private PaypalStandardPaymentProvider PaypalStandardProvider {
        get {
            if (null == paypalStandardProvider)
                paypalStandardProvider = PaypalStandardPaymentProvider.GetProvider();
            return paypalStandardProvider;
        }
    }
    

    protected void Page_Load(object sender, EventArgs e) {
        ValidateCheckoutPrerequisite();
        this.Master.LeftCell.Visible = false;
        this.Master.RightCell.Visible = false;
        pnlResult.Visible = false;

        if (!User.Identity.IsAuthenticated)
            Response.Redirect(SiteNavigation.LoginPage + "?ReturnUrl=Checkout.aspx");

        if (!IsPostBack) {
            string canceled = Utils.GetParameter("canceled", null);
            if (string.IsNullOrEmpty(canceled)) {
                string token = Utils.GetParameter("token", null);
                if (!string.IsNullOrEmpty(token))
                    ProcessPaypalExpressOrderConfirmation(token);
            }
            prgReturnPolicy.ParagraphName = Constant.UI.ReturnPolicyParagraphName;
        }
    }

    protected void Page_PreRender(object sender, EventArgs e) {
        pnlPaypalCheckout.Visible = (wzsSubmitOrder != wzdCheckout.ActiveStep) && (null != PaypalExpressProvider) && PaypalExpressProvider.Enabled;
        btnPaypalStandard.Visible = (null != PaypalStandardProvider) && PaypalStandardProvider.Enabled;
        if (wzsSubmitOrder == wzdCheckout.ActiveStep) {
            adShippingAddress.Address = shippingAddress;
            adShippingAddress.DataBind();
            paymentSummary.CheckoutPaymentType = checkoutPaymentType;
            paymentSummary.CreditCard = creditCard;
            orderTotal.OrderTotals = GetOrderTotal();
            dvSelectPaymentMethod.Visible = false;
            pnlPaypalStandardPrompt.Visible = (CheckoutPaymentTypeEnum.PaypalStandard == checkoutPaymentType);
        }
    }

    private List<OrderTotal> GetOrderTotal() {
        Cart cart = Cart.Get();
        List<OrderTotal> totals = OrderTotalService.GetOrderTotals(cart, TaxLocation.GetTaxLocation(shippingAddress));
        return totals;
    }

    protected void addressManager_Selected(object sender, AddressSelectedEventArgs e) {
        shippingAddress = e.AddressSelected;
        wzdCheckout.MoveTo(wzsBilling);
    }

    protected void creditCardPaymentMethod_Selected(object sender, CreditCardSelectedEventArgs e) {
        creditCard = e.CreditCardSelected;
        checkoutPaymentType = CheckoutPaymentTypeEnum.CreditCard;
        wzdCheckout.MoveTo(wzsSubmitOrder);
    }

    protected void btnChangeShipping_Click(object sender, EventArgs e) {
        wzdCheckout.MoveTo(wzsShipping);
    }

    protected void btnChangePayment_Click(object sender, EventArgs e) {
        wzdCheckout.MoveTo(wzsBilling);
    }

    protected void btnChangeOrder_Click(object sender, EventArgs e) {
        Response.Redirect(SiteNavigation.CartPage);
    }

    protected void btnSubmitOrder_Click(object sender, EventArgs e) {
        if (!IsValid)
            return;

        ShippingMethod shippingMethod = (ShippingMethod)Session["ShippingMethod"];
        List<OrderTotal> orderTotals = GetOrderTotal();

        PaymentTransaction transaction = null;
        if (CheckoutPaymentTypeEnum.PaypalExpress == checkoutPaymentType) {
            try {
                transaction = PaypalExpressProvider.DoExpressCheckout(paypalPaymentInfo.Token, paypalPaymentInfo.PayerId, orderTotals[orderTotals.Count - 1].Amount, true);
            } catch (PaymentExecption ex) {
                pnlResult.Visible = true;
                lblResult.Text = "PayPal is currently having issues accepting payment. Please use other payment methods.";
                wzdCheckout.MoveTo(wzsShipping);

                ExceptionPolicy.HandleException(ex, "Unhandled Policy");
                return;
            }
        }

        string orderNumber = null;
        try {
            int? initialOrderStatusId = null;
            if (CheckoutPaymentTypeEnum.PaypalStandard == checkoutPaymentType)
                initialOrderStatusId = Constant.DB.OrderStatusPaypalStandardAwaitingPayment;
            orderNumber = Order.Add(Utils.GetUserName(), WebUtils.GetDiscountRate(), shippingMethod.Name, shippingAddress, checkoutPaymentType, creditCard,
                orderTotals, initialOrderStatusId);
            if (null != transaction)
                transaction.Add(orderNumber);
        } catch (Exception ex) {
            if (ex.Message.Contains("enough in stock")) { //out of stock
                Response.Redirect(SiteNavigation.CartPage);
            }
            if (CheckoutPaymentTypeEnum.PaypalExpress == checkoutPaymentType) {
                //It was authorized when doing Express checkout. Need to send notification to admin for this issue and make order as complete.
                ExceptionPolicy.HandleException(ex, "Unhandled Policy"); //Todo: need to use other policy
            } else {
                throw;
            }
        }

        if (CheckoutPaymentTypeEnum.PaypalStandard == checkoutPaymentType) {
            try {
                Response.Redirect(PaypalStandardProvider.GetUploadOrderUrl(orderNumber));
            } catch (PaymentExecption ex) {
                pnlResult.Visible = true;
                lblResult.Text = "PayPal is currently having issues accepting payment. Please use other payment methods.";

                ExceptionPolicy.HandleException(ex, "Unhandled Policy");
            }
            return;
        }

        Response.Redirect(SiteNavigation.CheckoutCompletePage);
    }

    protected void cvdShippingMethod_ServerValidate(object source, ServerValidateEventArgs args) {
        args.IsValid = null != Session["ShippingMethod"];
    }

    protected void lbtChangeIndexClick(object sender, EventArgs e) {
        LinkButton lbt = (LinkButton)sender;
        if (lbt.ID.StartsWith("lbtShipping")) {
            wzdCheckout.MoveTo(wzsShipping);
        } else {
            wzdCheckout.MoveTo(wzsBilling);
        }
    }

    private void ValidateCheckoutPrerequisite() {
        Cart cart = Cart.Get();
        if ((null == cart) || cart.IsEmpty() || (!cart.ValidateStock()) ||
            (cart.InstockSubTotal < WebUtils.GetMinOrderAmount())) {
            Response.Redirect(SiteNavigation.CartPage);
        }
    }

    protected void btnExpressCheck_Click(object sender, EventArgs e) {
        if (PaypalExpressProvider.Enabled) {
            try {
                string url = PaypalExpressProvider.SetExpressCheckout(Membership.GetUser().Email,
                    Cart.Get().SubTotal, SiteNavigation.CheckoutPage, 
                    SiteNavigation.CheckoutPage + "?canceled=1", true);
                Response.Redirect(url);
            } catch (PaymentExecption ex) {
                pnlResult.Visible = true;
                lblResult.Text = "PayPal is currently having issues accepting payment. Please use other payment methods.";

                ExceptionPolicy.HandleException(ex, "Unhandled Policy");
            }
        }
    }

    private void ProcessPaypalExpressOrderConfirmation(string token) {
        PaypalPayer payer = PaypalExpressProvider.GetExpressCheckout(token);
        if (!payer.IsPayerValid) //User cancelled paypal checkout
            return;
        if (payer.IsCountryValid) {
            shippingAddress = payer.Address;
            paypalPaymentInfo = payer.PaypalPaymentInfo;
            checkoutPaymentType = CheckoutPaymentTypeEnum.PaypalExpress;
            wzdCheckout.MoveTo(wzsSubmitOrder);
        } else {
            pnlResult.Visible = true;
            lblResult.Text = string.Format("{0} is the country from your PayPal shipping address. We currently don't ship to that country. Please contact us or use another shipping address.",
                payer.PaypalCountryName);
        }
    }

    protected void btnPaypalStandard_Click(object sender, EventArgs e) {
        checkoutPaymentType = CheckoutPaymentTypeEnum.PaypalStandard;
        wzdCheckout.MoveTo(wzsSubmitOrder);
    }
}
