//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.Text.RegularExpressions;

using XShan.DotShoppingCart.Common;
using XShan.DotShoppingCart.Common.Object;

public partial class Controls_CreditCardInput : System.Web.UI.UserControl {
    private string validationGroup;
    private CreditCard creditCard;
    private bool creditCardNumberValid;

    private string plainCardNumber {
        get { return (string)ViewState["plainCardNumber"]; }
        set { ViewState["plainCardNumber"] = value; }
    }
    private string maskedCardNumber {
        get { return (string)ViewState["maskedCardNumber"]; }
        set { ViewState["maskedCardNumber"] = value; }
    }

    public string ValidationGroup {
        get { return validationGroup; }
        set { validationGroup = value; }
    }
    public bool ShowSaveCheckBox {
        get { return pnlSaveCard.Visible; }
        set { pnlSaveCard.Visible = value; }
    }

    public int CardTypeId {
        get { return int.Parse(ddlCardType.SelectedValue); }
    }
    public string CardholderName {
        get { return txtCardholderName.Text; }
    }
    public string CardNumber {
        get { return plainCardNumber; }
    }
    public string CVV2 {
        get { return txtCVV2.Text; }
    }
    public string ExpireYear {
        get { return ddlExpireYear.SelectedValue; }
    }
    public string ExpireMonth {
        get { return ddlExpireMonth.SelectedValue; }
    }
    public string Phone {
        get { return txtTelephone.Text; }
    }
    public CheckBox SaveCheckBox {
        get { return chkSave; }
    }
    
    public CreditCard InitialCreditCardToDisplay {
        set {
            maskedCardNumber = txtCardNumber.Text = value.MaskedCardNumber;
            plainCardNumber = value.CardNumber;
            txtCardholderName.Text = value.CardholderName;
            txtCVV2.Text = value.CVV2;
            txtTelephone.Text = value.Phone;
            creditCard = value;
        }
    }

    protected void Page_Load(object sender, EventArgs e) {
        if (ddlCardType.Items.Count > 0) {
            if (maskedCardNumber != txtCardNumber.Text) {
                //use the new card number from UI
                creditCardNumberValid = IsCreditCardValid(txtCardNumber.Text, (CreditCartTypeEnum)CardTypeId);
                if (creditCardNumberValid) {
                    plainCardNumber = txtCardNumber.Text;
                    maskedCardNumber = txtCardNumber.Text = CreditCard.GetMaskedCardNumber(plainCardNumber);
                }
            } else {
                creditCardNumberValid = IsCreditCardValid(plainCardNumber, (CreditCartTypeEnum)CardTypeId);
            }
        }
    }

    protected void Page_PreRender(object sender, EventArgs e) {
        if (null != creditCard) {
            WebUtils.SetDropDownListSelected(ddlCardType, creditCard.CreditCardType.CreditCardTypeId.ToString());
            WebUtils.SetDropDownListSelected(ddlExpireMonth, creditCard.ExpireMonth);
            WebUtils.SetDropDownListSelected(ddlExpireYear, creditCard.ExpireYear);
        }
        
        if (!string.IsNullOrEmpty(validationGroup)) {
            foreach (Control control in Controls) {
                if (control is BaseValidator) {
                    ((BaseValidator)control).ValidationGroup = validationGroup;
                }
            }
        }
    }

    public void Clear() {
        ddlCardType.SelectedIndex = ddlExpireMonth.SelectedIndex = ddlExpireYear.SelectedIndex = 0;
        txtCardNumber.Text = txtCardholderName.Text = txtCVV2.Text = txtTelephone.Text = string.Empty;
    }

    protected void cvdExpiration_ServerValidate(object source, ServerValidateEventArgs args) {
        //Expiration date is to use the last day of the month so we add 1 month
        args.IsValid = new DateTime(int.Parse(ExpireYear), int.Parse(ExpireMonth), 1).AddMonths(1) >= DateTime.Today;
    }

    protected void cvdCreditCardNumber_ServerValidate(object source, ServerValidateEventArgs args) {
        args.IsValid = creditCardNumberValid;
    }

    protected bool IsCreditCardValid(string cardNumber, CreditCartTypeEnum cardType) {
        bool valid = false;
        // VISA -- 4 -- 13 and 16 length
        if (Regex.IsMatch(cardNumber, @"^(4)\d+$") && (CreditCartTypeEnum.Visa == cardType))
            valid = (13 == cardNumber.Length) || (16 == cardNumber.Length);

        // MasterCard -- 51 through 55 -- 16 length
        else if (Regex.IsMatch(cardNumber, @"^(51|52|53|54|55)\d+$") && (CreditCartTypeEnum.MasterCard == cardType))
            valid = 16 == cardNumber.Length;

        // AMEX -- 34 or 37 -- 15 length
        else if (Regex.IsMatch(cardNumber, @"^(34|37)\d+$") && (CreditCartTypeEnum.Amex == cardType))
            valid = 15 == cardNumber.Length;

            // Discover -- 6011 -- 16 length
        else if (Regex.IsMatch(cardNumber, @"^(6011)\d+$") && (CreditCartTypeEnum.Discover == cardType))
            valid = 16 == cardNumber.Length;

        return valid;
    }
}
