//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Configuration;
using System.Collections.Generic;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using XShan.DotShoppingCart.Common;
using XShan.DotShoppingCart.Common.Object;

public partial class Controls_LayoutPanels_CategoryList : SideBoxUserControl {
    protected string categoryPath;

    protected void Page_PreRender(object sender, EventArgs e) {
        if (!IsPostBack) {
            Category[] categories;
            bool isCategoryPage = 0 == string.Compare(SiteNavigation.GetRelativePathToApplicatonRoot(Request.Url.AbsolutePath), "Category.aspx", true);
            string categoryPath = isCategoryPage ? Utils.GetParameter("n", null) : null;
            if (string.IsNullOrEmpty(categoryPath)) {
                // root path
                categories = Category.GetCategories(0, 2);
            } else {
                Category current = Category.GetCategoryByCategoryPath(categoryPath);
                categories = new Category[] { current };
                // add root category to ease navigation
                rptRootCategoryies.DataSource = GetRootCategories(current);
                rptRootCategoryies.DataBind();
            }

            rptCategories.DataSource = categories;
            rptCategories.DataBind();

            if (categories.Length > 0) {
                categoryPath = SiteNavigation.GetRewriterUrl("Category", categories[0].ParentFullPath, categories[0].Name);
                if (categories[0].PriceRanges != null) {
                    pnlNarrowByPrice.Visible = true;
                    rptPriceRange.DataSource = categories[0].PriceRanges;
                    rptPriceRange.DataBind();
                }
                if (categories[0].ManufacturerCounts != null) {
                    pnlNarrowByManufacturer.Visible = true;
                    rptManufacturer.DataSource = categories[0].ManufacturerCounts;
                    rptManufacturer.DataBind();
                }
                
            }

        }
    }

    private List<Category> GetRootCategories(Category excludedCategory) {
        List<Category> categories = new List<Category>();
        foreach (Category c in Category.GetCategories(0, 2)) {
            if (excludedCategory.CategoryId != c.CategoryId)
                categories.Add(c);
        }
        return categories;
    }

}
