//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using XShan.DotShoppingCart.Common;
using XShan.DotShoppingCart.Common.Object;

public partial class Controls_LayoutPanels_SideColumn : System.Web.UI.UserControl {
    private bool isLeftSide = true;

    public bool IsLeftSide {
        get { return isLeftSide; }
        set { isLeftSide = value; }
    }

    protected void Page_Load(object sender, EventArgs e) {
        if (!IsPostBack) {
            rptSideBoxes.DataSource = SideBox.GetAll(isLeftSide);
            rptSideBoxes.DataBind();
        } else {
            LoadDynamicControls();
        }
    }

    private void LoadDynamicControls() {
        foreach (RepeaterItem item in rptSideBoxes.Items) {
            HiddenField hidSideBoxVirtualPath = (HiddenField)item.FindControl("hidSideBoxVirtualPath");
            Panel pnlSideBox = (Panel)item.FindControl("pnlSideBox");
            if (null != pnlSideBox)
                pnlSideBox.Controls.Add(LoadControl(hidSideBoxVirtualPath.Value));
            Panel pnlUpdateParameters = (Panel)item.FindControl("pnlUpdateParameters");
            if (null != pnlUpdateParameters)
                pnlUpdateParameters.Controls.Add(LoadControl(hidSideBoxVirtualPath.Value));
        }
    }

    protected void Page_PreRender(object sender, EventArgs e) {
        if (!IsPostBack) {
            if (WebUtils.IsPageEditorEnable()) {
                pnlShowAdd.Visible = true;
            }
        }
    }

    protected void rptSideBoxes_ItemDataBound(object sender, RepeaterItemEventArgs e) {
        SideBox sideBox = (SideBox)e.Item.DataItem;
        Panel pnlSideBox = (Panel)e.Item.FindControl("pnlSideBox");
        SideBoxUserControl userControl = (SideBoxUserControl)LoadControl(sideBox.SideBoxType.VirtualPath);
        userControl.Parameters = sideBox.Parameters;
        pnlSideBox.Controls.Add(userControl);

        if (WebUtils.IsPageEditorEnable()) {
            Panel pnlShowUpdate = (Panel)e.Item.FindControl("pnlShowUpdate");
            pnlShowUpdate.Visible = true;

            if (userControl.Editable) {
                Button btnEdit = (Button)e.Item.FindControl("btnEdit");
                btnEdit.Visible = true;

                TextBox txtTitle = (TextBox)e.Item.FindControl("txtTitle");
                txtTitle.Text = sideBox.Title;

                //Load Update Parameters content
                Panel pnlUpdateParameters = (Panel)e.Item.FindControl("pnlUpdateParameters");
                userControl = (SideBoxUserControl)LoadControl(sideBox.SideBoxType.VirtualPath); //Load the same control for the second time but with EditMode enabled
                userControl.EditMode = true;
                userControl.Parameters = sideBox.Parameters;
                pnlUpdateParameters.Controls.Add(userControl);
            }

        }
    }

    protected void ActionCommand(object sender, CommandEventArgs e) {
        HiddenField hidSideBoxId;
        TextBox txtTitle;
        Panel pnlUpdateParameters;
        SideBoxUserControl userControl;
        switch (e.CommandName) {
            case "Add":
                txtTitle = (TextBox)((Button)sender).NamingContainer.FindControl("txtTitle");
                SideBox.Add(int.Parse(ddlSideBoxTypes.SelectedValue), isLeftSide, txtTitle.Text, null);
                break;
            case "Delete":
                hidSideBoxId = (HiddenField)((Button)sender).NamingContainer.FindControl("hidSideBoxId");
                pnlUpdateParameters = (Panel)((Button)sender).NamingContainer.FindControl("pnlUpdateParameters");
                userControl = (SideBoxUserControl)pnlUpdateParameters.Controls[0]; //only one control
                userControl.DeleteContent();
                SideBox.Delete(int.Parse(hidSideBoxId.Value));
                break;
            case "Save":
                hidSideBoxId = (HiddenField)((Button)sender).NamingContainer.FindControl("hidSideBoxId");
                HiddenField hidSortOrder = (HiddenField)((Button)sender).NamingContainer.FindControl("hidSortOrder");
                HiddenField hidSideBoxTypeId = (HiddenField)((Button)sender).NamingContainer.FindControl("hidSideBoxTypeId");
                pnlUpdateParameters = (Panel)((Button)sender).NamingContainer.FindControl("pnlUpdateParameters");
                txtTitle = (TextBox)((Button)sender).NamingContainer.FindControl("txtTitle");
                userControl = (SideBoxUserControl)pnlUpdateParameters.Controls[0]; //only one control
                string parameters = userControl.SaveContent();
                SideBox.Update(int.Parse(hidSideBoxId.Value), int.Parse(hidSideBoxTypeId.Value), isLeftSide, txtTitle.Text, parameters, int.Parse(hidSortOrder.Value));
                break;
        }
        SideBox.RemoveCache();
        WebUtils.ReloadPage();
    }
}
