//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Configuration;
using System.Collections.Generic;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using XShan.DotShoppingCart.Common;
using XShan.DotShoppingCart.Common.Configuration;
using XShan.DotShoppingCart.Common.Object;

public partial class Controls_ProductList : System.Web.UI.UserControl {
    private ProductListType type = ProductListType.Featured;
    public ProductListType Type {
        get { return type; }
        set { type = value; }
    }

    private string manufacturer = null;
    public string Manufacturer {
        get { return manufacturer; }
        set { manufacturer = value; }
    }

    private decimal? priceFrom = null;
    public decimal? PriceFrom {
        get { return priceFrom; }
        set { priceFrom = value; }
    }

    private decimal? priceTo = null;
    public decimal? PriceTo {
        get { return priceTo; }
        set { priceTo = value; }
    }

    private int pageNumber = 1;
    public int PageNumber {
        get { return pageNumber; }
        set { pageNumber = value; }
    }

    private ProductSortBy sortby = ProductSortBy.FeaturedItem;
    public ProductSortBy Sortby {
        get { return sortby; }
        set { sortby = value; }
    }

    private int totalNumber;
    public int TotalNumber {
        get { return totalNumber; }
        set { totalNumber = value; }
    }

    private int productItemsPerPage = UIConfigurationSection.GetSection().CategoryProductCount;
    public int ProductItemsPerPage {
        get { return productItemsPerPage; }
        set { productItemsPerPage = value; }
    }

    private bool enableCache = false;
    public bool EnableCache {
        get { return enableCache; }
        set { enableCache = value; }
    }

    public int ProductCount {
        get { return dlProducts.Items.Count; }
    }

    protected void Page_Load(object sender, EventArgs e) {
        List<Product> products;
        if (!IsPostBack) {
            if (enableCache) {
                string cacheKey = string.Format("{0}_ProductList_{1}_{2}_{3}_{4}_{5}_{6}_{7}_{8}", SiteNavigation.GetHost(), type, productItemsPerPage, pageNumber, sortby, manufacturer, priceFrom, priceTo,
                    ((StoreConfigurationSection)SqlConfigurationController.GetSection(StoreConfigurationSection.SectionName)).ShowStock);
                object o = Cache[cacheKey];
                if (null == o) {
                    products = LoadProducts();
                    Cache.Insert(cacheKey, products, null, DateTime.Now.AddHours(Constant.UI.StaticCacheTimeout), System.Web.Caching.Cache.NoSlidingExpiration);
                } else
                    products = (List<Product>)o;
            } else {
                products = LoadProducts();
            }
            dlProducts.RepeatColumns = UIConfigurationSection.GetSection().ProductListColumns;
            dlProducts.DataSource = products;
            dlProducts.DataBind();
        }
    }

    private List<Product> LoadProducts() {
        return Product.GetProducts(type, productItemsPerPage, (pageNumber - 1) * productItemsPerPage, sortby, manufacturer, priceFrom, priceTo,
                ((StoreConfigurationSection)SqlConfigurationController.GetSection(StoreConfigurationSection.SectionName)).ShowStock, out totalNumber);
    }
}
