//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using XShan.DotShoppingCart.Common;
using XShan.DotShoppingCart.Common.Object;
using XShan.DotShoppingCart.Payment;

public class CreditCardSelectedEventArgs : EventArgs {
    public CreditCard CreditCardSelected;

    public CreditCardSelectedEventArgs(CreditCard selected) {
        CreditCardSelected = selected;
    }
}
public delegate void PaymentMethodSelectEventHandler(object sender, CreditCardSelectedEventArgs e);

public partial class Controls_SelectCreditcardPaymentMethod : System.Web.UI.UserControl {
    public event PaymentMethodSelectEventHandler Selected = null;

    protected void Page_PreRender(object sender, EventArgs e) {
        if (CreditCardPaymentService.GetProvider() is NullCreditCardPaymentProvider)
            pnlCreditCardPayment.Visible = false;
        else {
            gvwExistingCreditCards.SelectedIndex = -1;
            gvwExistingCreditCards.DataSource = CreditCard.Get();
            gvwExistingCreditCards.DataBind();
        }
    }

    protected void gvwExistingCreditCards_RowDataBound(object sender, GridViewRowEventArgs e) {
        if (e.Row.RowType == DataControlRowType.DataRow) {
            CreditCard creditCard = (CreditCard)e.Row.DataItem;
            DropDownList ddlExpireMonth = (DropDownList)e.Row.FindControl("ddlExpireMonth");
            WebUtils.SetDropDownListSelected(ddlExpireMonth, creditCard.ExpireMonth);
            DropDownList ddlExpireYear = (DropDownList)e.Row.FindControl("ddlExpireYear");
            WebUtils.SetDropDownListSelected(ddlExpireYear, creditCard.ExpireYear);
        }
    }

    protected void gvwExistingCreditCards_SelectedIndexChanging(object sender, GridViewSelectEventArgs e) {
        int creditCardId = (int)gvwExistingCreditCards.DataKeys[e.NewSelectedIndex]["CreditCardId"];
        CreditCard creditCard = CreditCard.Get(creditCardId);
        //Check if expiration date was changed
        DropDownList ddlExpireMonth = (DropDownList)gvwExistingCreditCards.Rows[e.NewSelectedIndex].FindControl("ddlExpireMonth");
        DropDownList ddlExpireYear = (DropDownList)gvwExistingCreditCards.Rows[e.NewSelectedIndex].FindControl("ddlExpireYear");
        if ((creditCard.ExpireMonth != ddlExpireMonth.SelectedValue) || (creditCard.ExpireYear != ddlExpireYear.SelectedValue)) {
            CreditCard.Update(creditCard.CreditCardId, creditCard.CreditCardType.CreditCardTypeId, creditCard.CardNumber,
                creditCard.CardholderName, ddlExpireYear.SelectedValue, ddlExpireMonth.SelectedValue, creditCard.CVV2, creditCard.Phone);
            creditCard = CreditCard.Get(creditCardId);
        }

        OnSelected(new CreditCardSelectedEventArgs(creditCard));
    }

    protected void btnPayWithNewCard_Click(object sender, EventArgs e) {
        if (Page.IsValid) {
            CreditCard creditCard = null;
            if (creditCardInput.SaveCheckBox.Checked) {
                int creditCardId = CreditCard.Add(creditCardInput.CardTypeId, creditCardInput.CardNumber, creditCardInput.CardholderName,
                    creditCardInput.ExpireYear, creditCardInput.ExpireMonth, creditCardInput.CVV2, creditCardInput.Phone);
                creditCard = CreditCard.Get(creditCardId);
                creditCardInput.SaveCheckBox.Checked = false;
            } else {
                creditCard = new CreditCard(creditCardInput.CardTypeId, creditCardInput.CardNumber, creditCardInput.CardholderName,
                    creditCardInput.ExpireYear, creditCardInput.ExpireMonth, creditCardInput.CVV2, creditCardInput.Phone);
            }
            OnSelected(new CreditCardSelectedEventArgs(creditCard));
        }
    }

    protected virtual void OnSelected(CreditCardSelectedEventArgs e) {
        if (null != Selected) {
            Selected(this, e);
        }
    }
}
