//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using XShan.DotShoppingCart.Common;
using XShan.DotShoppingCart.Common.Object;
using XShan.DotShoppingCart.Common.Configuration;

public partial class _Default : DSCPage{
    private string pageName;
    private bool isHomepage = true;
    private DbPage dbPage;
    private DbPage DbPage {
        get {
            if (null == dbPage)
                dbPage = DbPage.Load(pageName);
            return dbPage;
        }
    }

    protected void Page_Load(object sender, EventArgs e) {
        pageName = Utils.GetParameter("n", "home");
        isHomepage = string.Compare(pageName, "home", true) == 0;
        EnableViewState = pnlShowAdd.Visible = WebUtils.IsPageEditorEnable();

        if (!IsPostBack) {
            UIConfigurationSection uiSection = UIConfigurationSection.GetSection();
            StoreConfigurationSection storeSection = (StoreConfigurationSection)SqlConfigurationController.GetSection(StoreConfigurationSection.SectionName);
            string wholesale = Utils.GetParameter("wholesale", "");
            if ("0" == wholesale) { // reset to retail
                WebUtils.ClearDiscountGroupFromSession();
                HttpContext.Current.Session["registerRole"] = null;
            } else if ("1" == wholesale) {
                string wholesaleRoleName = storeSection.WholesaleRoleName;
                DSCRole role = null;
                if ((!string.IsNullOrEmpty(wholesaleRoleName)) && (null != (role = DSCRole.Get(wholesaleRoleName)))) {
                    WebUtils.WriteDiscountGroupToSessionByRole(role);
                    HttpContext.Current.Session["registerRole"] = wholesaleRoleName;
                }
            }

            BindParagraphs();
            pnlFeatured.Visible = isHomepage && (uiSection.FeaturedProductCountInHomepage > 0);
            pdlFeatured.ProductItemsPerPage = uiSection.FeaturedProductCountInHomepage;
            this.Master.SiteMapPath.Visible = false;
            if (isHomepage) {
                if (!string.IsNullOrEmpty(storeSection.HomepageTitle))
                    Title = storeSection.HomepageTitle;
            } else {
                //SiteMap.SiteMapResolve += new SiteMapResolveEventHandler(ExpandPagePaths);
                Title = Title.Replace("Home", pageName);
            }
        }
    }

    private SiteMapNode ExpandPagePaths(Object sender, SiteMapResolveEventArgs e) {
        SiteMap.SiteMapResolve -= new SiteMapResolveEventHandler(ExpandPagePaths);
        SiteMapNode currentNode = SiteMap.CurrentNode.Clone(true);
        currentNode.Title = pageName;
        return currentNode;
    }

    private void BindParagraphs() {
        if (null == DbPage)
            pnlEmptyPage.Visible = true;
        else {
            rptParagraph.DataSource = DbPage.Paragraphs;
            rptParagraph.DataBind();
        }
    }

    protected void rptParagraph_ItemDataBound(object sender, RepeaterItemEventArgs e) {
        Panel pnlShowEdit = (Panel)e.Item.FindControl("pnlShowEdit");
        pnlShowEdit.Visible = WebUtils.IsPageEditorEnable();
    }

    protected void ParagraphCommand(object sender, CommandEventArgs e) {
        switch (e.CommandName) {
            case "Delete":
                Paragraph.Delete(int.Parse(e.CommandArgument.ToString()));
                break;
            case "Save":
                Controls_HtmlEditor edtParagraphLocal = (Controls_HtmlEditor)((Button)sender).NamingContainer.FindControl("edtParagraph");
                HiddenField hidSortOrder = (HiddenField)((Button)sender).NamingContainer.FindControl("hidSortOrder");
                Paragraph.Update(int.Parse(e.CommandArgument.ToString()), edtParagraphLocal.Text, int.Parse(hidSortOrder.Value));
                break;
            case "Add":
                Paragraph.Add(pageName, edtParagraph.Text);
                break;
        }
        WebUtils.ReloadPage();
    }
}
