<%@ Application Language="C#" %>
<%@ Import namespace="XShan.DotShoppingCart.Common" %>
<%@ Import namespace="XShan.DotShoppingCart.Common.Object" %>
<%@ Import namespace="XShan.DotShoppingCart.OrderPipeline" %>
<%@ Import namespace="Microsoft.Practices.EnterpriseLibrary.ExceptionHandling" %>

<script runat="server">

    void Application_Start(object sender, EventArgs e) 
    {
        OrderPipelineController.Start();
    }
    
    void Application_End(object sender, EventArgs e) 
    {
        OrderPipelineController.Stop();
    }
        
    void Application_Error(object sender, EventArgs e) 
    {
        if (Utils.IsProductionServer()) {
            Exception ex = Server.GetLastError();
            if (null != ex) {
                string[] matchingStrings = new string[] 
                {
                    "The state information is invalid for this page and might be corrupted" //Invalid viewstate
                };
                foreach (string matchingString in matchingStrings) {
                    System.Text.RegularExpressions.Regex ignore = new Regex(matchingString, RegexOptions.IgnoreCase);
                    if ((ex is HttpException) && ignore.IsMatch(ex.Message))
                        return;
                }
                
                //handle exception here
                ex.Data.Add("Url", Request.Url.AbsoluteUri); 
                ex.Data.Add("RawUrl", Request.RawUrl);
                ex.Data.Add("UseAgent", Request.UserAgent);
                ex.Data.Add("UrlReferrer", Request.UrlReferrer);
                ex.Data.Add("IPAddress", Request.UserHostAddress);

                bool rethrow = ExceptionPolicy.HandleException(ex, "Unhandled Policy");
                if (!rethrow)
                    Server.ClearError();
            }
        }
    }

    void Session_Start(object sender, EventArgs e) {
    }

    void Session_End(object sender, EventArgs e) 
    {
        // Code that runs when a session ends. 
        // Note: The Session_End event is raised only when the sessionstate mode
        // is set to InProc in the Web.config file. If session mode is set to StateServer 
        // or SQLServer, the event is not raised.

    }
    
    protected void Application_BeginRequest(Object sender, EventArgs e) {
        //make sure that it ends with aspx.  This is some quick validation on the path. 
        //This will shortcut processing for images and other files (WebResource.axd, for example). 
        Match m = Regex.Match(Request.Path, @"^(?<start>.*?)(?<base>Category|Product|Page)\/(?<end>.*)\.aspx$", RegexOptions.IgnoreCase);
        if (m.Success) {
            string queryString = Request.QueryString.ToString();
            if (!string.IsNullOrEmpty(queryString))
                queryString = "&" + queryString;
            
            string basePart = m.Groups["base"].Value;
            if (0 == string.Compare(basePart, "Page", true))
                basePart = "Default";
            string newPath = string.Format("{0}{1}.aspx?n={2}{3}", m.Groups["start"].Value, basePart, m.Groups["end"].Value.Replace("/", ":"), queryString);
            Context.RewritePath(newPath, false);
        }
    }

    public void Profile_ProfileAutoSaving(object sender, ProfileAutoSaveEventArgs args) {
        string cartid = Request.QueryString["cartid"];
        if (!string.IsNullOrEmpty(cartid)) {
            //migrate the cart
            Cart.Migrate(cartid, Profile.UserName);
        }
    }

    public void Profile_OnMigrateAnonymous(object sender, ProfileMigrateEventArgs args) {
        ProfileCommon anonymousProfile = Profile.GetProfile(args.AnonymousID);
        Cart.Migrate(anonymousProfile.UserName, Profile.UserName);

        ProfileManager.DeleteProfile(args.AnonymousID);
        AnonymousIdentificationModule.ClearAnonymousIdentifier();
    }
</script>
