//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Configuration;
using System.Collections.Generic;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.IO;
using GCheckout.MerchantCalculation;
using GCheckout.Util;
using DSC = XShan.DotShoppingCart.Common.Object;
using XShan.DotShoppingCart.Common;
using XShan.DotShoppingCart.Tax;
using XShan.DotShoppingCart.Shipping;
using XShan.DotShoppingCart.Common.Configuration;

public partial class GoogleCheckoutMerchantCalculationHandler : System.Web.UI.Page {
    protected void Page_Load(object sender, EventArgs e) {
        string requestXml;

        int nid = Utils.GetIntParameter("nid", 0);
        if (nid > 0) { //process notification from db
            requestXml = DSC.GoogleCheckoutNotification.Get(nid).Message;
        } else {
            // Extract the XML from the request.
            Stream RequestStream = Request.InputStream;
            StreamReader RequestStreamReader = new StreamReader(RequestStream);
            requestXml = RequestStreamReader.ReadToEnd();
            RequestStream.Close();
            if (string.IsNullOrEmpty(requestXml))
                return;
            DSC.GoogleCheckoutNotification.Add(requestXml);
        }
        Process(requestXml);
    }

    private void Process(string requestXml) {
        // Process the incoming XML.
        CallbackProcessor P = new CallbackProcessor(new DSCRules());
        byte[] ResponseXML = P.Process(requestXml);
        Response.BinaryWrite(ResponseXML);
    }
}

public class DSCRules : CallbackRules {
    /// <summary>
    /// Example showing how Tax is calculated for a callback
    /// </summary>
    /// <param name="ThisOrder">The Order to perform the calculation</param>
    /// <param name="Address">contains a possible shipping address for an order.
    /// This address should be used to calculate taxes and shipping costs 
    /// for the order.</param>
    /// <param name="ShippingRate">The cost of shipping the order.</param>
    /// <returns></returns>
    public override decimal GetTaxResult(Order order, AnonymousAddress gAddress, decimal rate) {
        decimal subTotal = 0;
        foreach (OrderLine line in order) {
            subTotal += line.UnitPrice * line.Quantity;
        }
        //Todo: need to include shipping in tax
        return TaxService.GetProvider().GetTaxRate(new DSC.TaxLocation(gAddress.CountryCode, gAddress.Region, gAddress.PostalCode)) * subTotal;
    }

    /// <summary>
    /// Example showing how shipping is calculated for a callback
    /// </summary>
    /// <param name="ShipMethodName">Identifies a shipping method for which
    /// costs need to be calculated.</param>
    /// <param name="ThisOrder">The Order to perform the calculation</param>
    /// <param name="Address">contains a possible shipping address for an order.
    /// This address should be used to calculate taxes and shipping costs 
    /// for the order.</param>
    /// <returns></returns>
    public override ShippingResult GetShippingResult(string methodName, Order order, AnonymousAddress gAddress) {
        ShippingResult ret = new ShippingResult();
        ret.Shippable = false;
        ret.ShippingRate = 0;

        List<DSC.CartItem> cartItems = new List<DSC.CartItem>();
        foreach (OrderLine line in order) {
            string sku = line.MerchantPrivateDataNodes[0].InnerText;
            string attributeIds = line.MerchantPrivateDataNodes[1].InnerText;
            int quantity = line.Quantity;
            DSC.CartItem cartItem = new DSC.CartItem(sku, attributeIds, quantity);
            cartItem.Product = DSC.Product.Load(sku);
            if (null != cartItem.Product)
                cartItems.Add(cartItem);
            // else bad sku and need to find a way to signal failure.
        }

        StoreConfigurationSection storeSection = (StoreConfigurationSection)SqlConfigurationController.GetSection(StoreConfigurationSection.SectionName);
        List<DSC.ShippingMethod> methods = ShippingService.GetShippingMethods(DSC.ShippingPackage.GetShippingPackage(cartItems,
            gAddress.CountryCode, gAddress.Region, gAddress.PostalCode, storeSection.LocationCountry, storeSection.LocationState, storeSection.LocationZipcode));

        foreach (DSC.ShippingMethod shippingMethod in methods) {
            if (shippingMethod.Name == methodName) {
                ret.Shippable = true;
                ret.ShippingRate = shippingMethod.Price;
                break;
            }
        }
        return ret;
    }
}
