//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Configuration;
using System.Collections.Generic;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using XShan.DotShoppingCart.Common;
using XShan.DotShoppingCart.Common.Object;

public partial class ProductPage : DSCPage {
    private Product product;

    protected void Page_Load(object sender, EventArgs e) {
        this.Master.LeftCell.Visible = false;
        this.Master.RightCell.Visible = false;

        string productSku = Utils.GetParameter("n", null);
        if (string.IsNullOrEmpty(productSku))
            throw new ApplicationException("n is required parameter");

        product = Product.Load(productSku);
        if (null == product)
            Response.Redirect(SiteNavigation.Error404Page);

        ProductDetail1.Product = product;
        ProductAction1.Product = product;
        ProductDescriptor1.Descriptors = product.ProductDescriptors;
        prvReview.Product = product;
        prvReview.DataBind();

        ProductAction1.AddingToCart += new ProductActionClickEventHandler(ProductAction1_AddingToCart);

        if (!IsPostBack) {
            int count = Utils.GetIntParameter("add", 0);
            if ((count > 0) && (!product.HasRequiredAttribute))
                AddToCart(count, new List<int>());
        }
    }

    void ProductAction1_AddingToCart(object sender, EventArgs e) {
        List<int> selectedAttributeValueIds = ProductDetail1.SelectedAttributeValueIds;
        if (null == selectedAttributeValueIds) {
            lblNotEnoughStock.Visible = true;
            return;
        }
        AddToCart(ProductAction1.Quantity, selectedAttributeValueIds);
    }

    private void AddToCart(int count, List<int> selectedAttributeValueIds) {
        int quantity = product.GetStockQuantity(count, selectedAttributeValueIds);
        if (0 == quantity)
            lblNotEnoughStock.Visible = true;
        else {
            int cartId = Cart.AddItem(Utils.GetUserName(), product.ProductId,
                Utils.GetSorted(selectedAttributeValueIds),
                quantity);
            Response.Redirect(string.Format("{0}?cartitemid={1}&quantity={2}", SiteNavigation.ItemAddedToCartPage, cartId, count));
        }
    }
}
