//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Configuration;
using System.Collections.Generic;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using XShan.DotShoppingCart.Common;
using XShan.DotShoppingCart.Common.Configuration;
using XShan.DotShoppingCart.Common.Object;

public partial class Products : DSCPage {
    private ProductListType type;
    private string manufacturer;
    private decimal? priceFrom, priceTo;
    private int totalNumber, pageNumber;
    private ProductSortBy sortby;
    private List<Product> products;

    protected void Page_Load(object sender, EventArgs e) {
        type = (ProductListType)Utils.GetIntParameter("type", (int)ProductListType.Featured);
        manufacturer = Utils.GetParameter("manufacturer", null);
        priceFrom = Utils.GetNullableDecimalParameter("pricefrom");
        priceTo = Utils.GetNullableDecimalParameter("priceto");
        pageNumber = Utils.GetIntParameter("page", 1);
        sortby = (ProductSortBy)Utils.GetIntParameter("sortby", 0);

        Page.Title = ((StoreConfigurationSection)SqlConfigurationController.GetSection(StoreConfigurationSection.SectionName)).Name + string.Format(" - {0} Products", type);

        if (!IsPostBack) {
            lblTitle.Text = string.Format("{0} Products", type);
            UIConfigurationSection uiSection = UIConfigurationSection.GetSection();
            dlProducts.RepeatColumns = uiSection.ProductListColumns;

            products = Product.GetProducts(type, uiSection.CategoryProductCount, (pageNumber - 1) * uiSection.CategoryProductCount, sortby, manufacturer, priceFrom, priceTo,
                ((StoreConfigurationSection)SqlConfigurationController.GetSection(StoreConfigurationSection.SectionName)).ShowStock, out totalNumber);
            BindControls();
        }
    }

    private void BindControls() {
        dlProducts.DataSource = products;
        dlProducts.DataBind();
        if (0 == totalNumber) {
            plrTop.Visible = plrBottom.Visible = false;
            pnlEmpty.Visible = true;
        } else {
            plrTop.PageNumber = plrBottom.PageNumber = pageNumber;
            plrTop.TotalNumber = plrBottom.TotalNumber = totalNumber;
        }
    }
}
