//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.IO;
using System.Text;
using System.Data.Common;
using Microsoft.Practices.EnterpriseLibrary.Data;
using XShan.DotShoppingCart.Common;
using XShan.DotShoppingCart.Common.Configuration;

public partial class Rss : System.Web.UI.Page {
    protected StoreConfigurationSection storeSection;

    protected void Page_Load(object sender, EventArgs e) {
        Response.ContentType = "text/xml";
        Response.Expires = 0;

        storeSection = (StoreConfigurationSection)SqlConfigurationController.GetSection(StoreConfigurationSection.SectionName);
        StringBuilder sb = new StringBuilder();
        sb.AppendLine("<rss version=\"2.0\" xmlns:dc=\"http://purl.org/dc/elements/1.1/\">");
        sb.AppendLine("  <channel>");
        sb.AppendLine("     <title>" + storeSection.Name + "</title>"); 
        sb.AppendLine("     <link>" + storeSection.URL + "</link>"); 
        sb.AppendLine("     <description>" + storeSection.MetaTagDescription + "</description>"); 
        sb.AppendLine("     <language>ENU</language>");
        sb.AppendLine("     <lastBuildDate>" + DateTime.Now.ToString() + "</lastBuildDate>");
        sb.AppendLine("     <generator>DotShoppingCart</generator>");
        sb.AppendLine("     <docs>" + SiteNavigation.RssPage + "</docs>");
        sb.AppendLine("     <copyright>Copyright &#169; 2007 " + storeSection.Name + "</copyright>");
        sb.AppendLine("     <managingEditor>" + storeSection.SaleEmailAddress + " (" + storeSection.Name + ")</managingEditor>");
        sb.AppendLine("     <webMaster>" + storeSection.SaleEmailAddress + " (" + storeSection.Name + ")</webMaster>");
        sb.AppendLine("     <ttl>1440</ttl>");
        sb.AppendLine("     <image>");
        sb.AppendLine("    <url>" + storeSection.URL + FileController.GetStoreLogoUrl() + "</url>");
        sb.AppendLine("    <title>" + storeSection.Name + "</title>");
        sb.AppendLine("    <link>" + storeSection.URL + "</link>");
	    sb.AppendLine("    </image>");

        Database db = DBController.CreateDatabase();
        DbCommand cmd = db.GetStoredProcCommand("DSC_Product_Export_Summary", 0, DateTime.Now.AddMonths(-2)); // new means less than 2 months
        DataSet ds = db.ExecuteDataSet(cmd);
        string[] columns = new string[14];

        foreach (DataRow row in ds.Tables[0].Rows) {
            string category = (string)row["categoryName"];
            string pCategory = row["parentCategoryName"] as string;
            string mainCategory = string.IsNullOrEmpty(pCategory) ? category : pCategory;
            string link = SiteNavigation.GetRewriterUrl("Product", (string)row["sku"]);
            string imgUrl = SiteNavigation.ResolveAbsoluteUrl(false, FileController.GetImageUrl(DBHelper.ToNullableInt(row["defaultImageId"]), 600, 500));
            string price = ((decimal)row["price"]).ToString("C");
            sb.AppendLine("  <item>");
            sb.AppendLine("    <title>" + mainCategory + " : " + (string)row["productName"] + "</title>");
            sb.AppendLine("    <guid isPermaLink=\"true\" >" + link + "</guid>");
            sb.AppendLine("    <link>" + link + "</link>");
            sb.AppendLine("    <description>" +
                "<![CDATA[<p style=\"text-align: center\">" +
                "<a href=\"" + link + "\">" +
                "<img alt=\"click here for detail\" src=\"" + imgUrl + "\" /></a><br /><br />" +
                Server.HtmlEncode(row["shortDescription"] as string) + "<br /><b>" + price + "</b><br /></p>]]></description>");
            sb.AppendLine("    <dc:date>" + ((DateTime)row["timeCreated"]).ToString() + "</dc:date>");//2005-04-28T20:47Z
            sb.AppendLine("    <pubDate>" + ((DateTime)row["timeCreated"]).ToString() + "</pubDate>");
            sb.AppendLine("    <author>" + storeSection.SaleEmailAddress + " (" + storeSection.Name + ")</author>");
            sb.AppendLine("  </item>");
        }
        sb.AppendLine("  </channel>");
        sb.AppendLine("</rss>");
        Response.Write(sb.ToString());
    }
}
